/* Automatically generated by GNU msgfmt.  Do not modify!  */
package org.postgresql.translation;
public class messages_tr extends java.util.ResourceBundle {
  private static final java.lang.String[] table;
  static {
    java.lang.String[] t = new java.lang.String[686];
    t[0] = "";
    t[1] = "Project-Id-Version: jdbc-tr\nReport-Msgid-Bugs-To: \nPO-Revision-Date: 2009-05-31 21:47+0200\nLast-Translator: Devrim GÜNDÜZ <devrim@gunduz.org>\nLanguage-Team: Turkish <pgsql-tr-genel@PostgreSQL.org>\nLanguage: tr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Generator: KBabel 1.3.1\nX-Poedit-Language: Turkish\nX-Poedit-Country: TURKEY\n";
    t[2] = "Connection has been closed automatically because a new connection was opened for the same PooledConnection or the PooledConnection has been closed.";
    t[3] = "PooledConnection kapatıldığı için veya aynı PooledConnection için yeni bir bağlantı açıldığı için geçerli bağlantı otomatik kapatıldı.";
    t[10] = "Failed to create object for: {0}.";
    t[11] = "{0} için nesne oluşturma hatası.";
    t[16] = "Unsupported Types value: {0}";
    t[17] = "Geçersiz Types değeri: {0}";
    t[20] = "{0} function doesn''t take any argument.";
    t[21] = "{0} fonksiyonu parametre almaz.";
    t[24] = "Currently positioned after the end of the ResultSet.  You cannot call deleteRow() here.";
    t[25] = "Şu an ResultSet sonucundan sonra konumlandı. deleteRow() burada çağırabilirsiniz.";
    t[28] = "end() called without a matching start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[29] = "Eşleşen bir start() çağrısı olmadan end() çağrıldı. end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[30] = "Connection attempt timed out.";
    t[31] = "Bağlantı denemesi zaman aşımına uğradı.";
    t[32] = "Can''t infer the SQL type to use for an instance of {0}. Use setObject() with an explicit Types value to specify the type to use.";
    t[33] = "{0}''nin örneği ile kullanılacak SQL tip bulunamadı. Kullanılacak tip belirtmek için kesin Types değerleri ile setObject() kullanın.";
    t[36] = "Connection is already associated with an active XA branch. End the current branch before starting a new one. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[37] = "Bağlantı zaten etkin bir XA dalı ile ilişkilendirilmiş. Yenisini başlatmadan önce mevcut dalı sonlandırın. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[38] = "Where: {0}";
    t[39] = "Where: {0}";
    t[42] = "ResultSet not positioned properly, perhaps you need to call next.";
    t[43] = "ResultSet doğru konumlanmamıştır, next işlemi çağırmanız gerekir.";
    t[44] = "Error during one-phase commit. commit xid={0}";
    t[45] = "One-phase commit sırasında hata. commit xid={0}";
    t[48] = "The server''s DateStyle parameter was changed to {0}. The JDBC driver requires DateStyle to begin with ISO for correct operation.";
    t[49] = "Sunucunun DateStyle parametresi {0} olarak değiştirildi. JDBC sürücüsü doğru işlemesi için DateStyle tanımının ISO işle başlamasını gerekir.";
    t[58] = "Custom type maps are not supported.";
    t[59] = "Özel tip eşleştirmeleri desteklenmiyor.";
    t[60] = "Error preparing transaction. prepare xid={0}";
    t[61] = "Transaction hazırlama hatası. prepare xid={0}";
    t[62] = "commit() called before end(). commit xid={0}, state={1}";
    t[63] = "end() çağrılmadan önce commit() çağrıldı. commit xid={0}, state={1}";
    t[72] = "No results were returned by the query.";
    t[73] = "Sorgudan hiç bir sonuç dönmedi.";
    t[76] = "Cannot tell if path is open or closed: {0}.";
    t[77] = "Pathın açık mı kapalı olduğunu tespit edilemiyor: {0}.";
    t[80] = "2nd phase commit cannot be issued while an XA branch is active on this connection. commit xid={0}, currentXid={1}, state={2}";
    t[81] = "Bu bağlantıda bir XA dalı etkinken 2. faz commit çağrılamaz. commit xid={0}, currentXid={1}, state={2}";
    t[82] = "Returning autogenerated keys by column index is not supported.";
    t[83] = "Kolonların indexlenmesi ile otomatik olarak oluşturulan anahtarların döndürülmesi desteklenmiyor.";
    t[88] = "The fastpath function {0} is unknown.";
    t[89] = "{0} fastpath fonksiyonu bilinmemektedir.";
    t[92] = "Cannot retrieve the id of a named savepoint.";
    t[93] = "Adlandırılmış savepointin id değerine erişilemiyor.";
    t[100] = "The column index is out of range: {0}, number of columns: {1}.";
    t[101] = "Sütun gçstergesi kapsam dışıdır: {0}, sütun sayısı: {1}.";
    t[104] = "Protocol error.  Session setup failed.";
    t[105] = "Protokol hatası.  Oturum kurulumu başarısız oldu.";
    t[108] = "Suspend/resume not implemented";
    t[109] = "Suspend/resume desteklenmiyor";
    t[110] = "Unable to find server array type for provided name {0}.";
    t[111] = "Belirtilen {0} adı için sunucu array tipi bulunamadı.";
    t[112] = "free() was called on this LOB previously";
    t[113] = "Bu LOB'da free() daha önce çağırıldı";
    t[114] = "Unknown XML Result class: {0}";
    t[115] = "Bilinmeyen XML Sonuç sınıfı: {0}.";
    t[116] = "Unable to translate data into the desired encoding.";
    t[117] = "Veri, istenilen dil kodlamasına çevrilemiyor.";
    t[126] = "Prepare called before end(). prepare xid={0}, state={1}";
    t[127] = "end() çağrılmadan önce prepare çağrıldı. prepare xid={0}, state={1}";
    t[130] = "ResultSet is not updateable.  The query that generated this result set must select only one table, and must select all primary keys from that table. See the JDBC 2.1 API Specification, section 5.6 for more details.";
    t[131] = "ResultSet değiştirilemez. Bu sonucu üreten sorgu tek bir tablodan sorgulamalı ve tablonun tüm primary key alanları belirtmelidir. Daha fazla bilgi için bk. JDBC 2.1 API Specification, section 5.6.";
    t[136] = "Unable to create SAXResult for SQLXML.";
    t[137] = "SQLXML için SAXResult yaratılamadı.";
    t[138] = "Cannot retrieve the name of an unnamed savepoint.";
    t[139] = "Adı verilmemiş savepointin id değerine erişilemiyor.";
    t[142] = "The array index is out of range: {0}, number of elements: {1}.";
    t[143] = "Dizin göstergisi kapsam dışıdır: {0}, öğe sayısı: {1}.";
    t[144] = "Cannot cast an instance of {0} to type {1}";
    t[145] = "{0} tipi {1} tipine dönüştürülemiyor";
    t[152] = "Error during recover. flag={0}";
    t[153] = "Kurtarma sırasında hata. flag={0}";
    t[158] = "Bad value for type {0} : {1}";
    t[159] = "{0} veri tipi için geçersiz değer : {1}";
    t[160] = "An unexpected result was returned by a query.";
    t[161] = "Sorgu beklenmeyen bir sonuç döndürdü.";
    t[162] = "Expected command status BEGIN, got {0}.";
    t[163] = "BEGIN komut durumunu beklenirken {0} alındı.";
    t[166] = "Unable to load the class {0} responsible for the datatype {1}";
    t[167] = "{1} veri tipinden sorumlu {0} sınıfı yüklenemedi";
    t[168] = "Cannot change transaction isolation level in the middle of a transaction.";
    t[169] = "Transaction ortasında geçerli transactionun transaction isolation level özellği değiştirilemez.";
    t[174] = "The server''s standard_conforming_strings parameter was reported as {0}. The JDBC driver expected on or off.";
    t[175] = "İstemcinin client_standard_conforming_strings parametresi {0} olarak raporlandı. JDBC sürücüsü on ya da off olarak bekliyordu.";
    t[178] = "Invalid stream length {0}.";
    t[179] = "Geçersiz akım uzunluğu {0}.";
    t[180] = "Unable to decode xml data.";
    t[181] = "XML verisinin kodu çözülemedi.";
    t[184] = "Results cannot be retrieved from a CallableStatement before it is executed.";
    t[185] = "CallableStatement çalıştırılmadan sonuçlar ondan alınamaz.";
    t[186] = "This statement has been closed.";
    t[187] = "Bu komut kapatıldı.";
    t[188] = "Error loading default settings from driverconfig.properties";
    t[189] = "driverconfig.properties dosyasından varsayılan ayarları yükleme hatası";
    t[190] = "Invalid flags {0}";
    t[191] = "Geçersiz seçenekler {0}";
    t[196] = "Failed to convert binary xml data to encoding: {0}.";
    t[197] = "xml verisinin şu dil kodlamasına çevirilmesi başarısız oldu: {0}";
    t[204] = "Conversion to type {0} failed: {1}.";
    t[205] = "{0} veri tipine dönüştürme hatası: {1}.";
    t[206] = "DataSource has been closed.";
    t[207] = "DataSource kapatıldı.";
    t[208] = "Connection has been closed.";
    t[209] = "Bağlantı kapatıldı.";
    t[210] = "A CallableStatement was executed with nothing returned.";
    t[211] = "CallableStatement çalıştırma sonucunda veri getirilmedi.";
    t[212] = "Your security policy has prevented the connection from being attempted.  You probably need to grant the connect java.net.SocketPermission to the database server host and port that you wish to connect to.";
    t[213] = "Güvenlik politikanız bağlantının kurulmasını engelledi. java.net.SocketPermission'a veritabanına ve de bağlanacağı porta bağlantı izni vermelisiniz.";
    t[218] = "Unexpected command status: {0}.";
    t[219] = "Beklenmeyen komut durumu: {0}.";
    t[220] = "Cannot reference a savepoint after it has been released.";
    t[221] = "Bırakıldıktan sonra savepoint referans edilemez.";
    t[222] = "Error opening transaction. start xid={0}";
    t[223] = "Transaction açma hatası. start xid={0}";
    t[228] = "The authentication type {0} is not supported. Check that you have configured the pg_hba.conf file to include the client''s IP address or subnet, and that it is using an authentication scheme supported by the driver.";
    t[229] = "{0} yetkinlendirme tipi desteklenmemektedir. pg_hba.conf dosyanızı istemcinin IP adresini ya da subnetini içerecek şekilde ayarlayıp ayarlamadığınızı ve sürücü tarafından desteklenen yetkilendirme yöntemlerinden birisini kullanıp kullanmadığını kontrol ediniz.";
    t[242] = "Internal Position: {0}";
    t[243] = "Internal Position: {0}";
    t[244] = "This statement does not declare an OUT parameter.  Use '{' ?= call ... '}' to declare one.";
    t[245] = "Bu komut OUT parametresi bildirmemektedir.  Bildirmek için '{' ?= call ... '}' kullanın.";
    t[256] = "Location: File: {0}, Routine: {1}, Line: {2}";
    t[257] = "Yer: Dosya: {0}, Yordam: {1}, Satır: {2}";
    t[258] = "Unknown type {0}.";
    t[259] = "Bilinmeyen tip {0}.";
    t[260] = "Ran out of memory retrieving query results.";
    t[261] = "Sorgu sonuçları alınırken bellek yetersiz.";
    t[264] = "Zero bytes may not occur in string parameters.";
    t[265] = "String parametrelerinde sıfır bayt olamaz.";
    t[266] = "{0} function takes four and only four argument.";
    t[267] = "{0} fonksiyonunu yalnız dört parametre alabilir.";
    t[268] = "Truncation of large objects is only implemented in 8.3 and later servers.";
    t[269] = "Large objectlerin temizlenmesi 8.3 ve sonraki sürümlerde kodlanmıştır.";
    t[270] = "Invalid character data was found.  This is most likely caused by stored data containing characters that are invalid for the character set the database was created in.  The most common example of this is storing 8bit data in a SQL_ASCII database.";
    t[271] = "Geçersiz karakterler bulunmuştur. Bunun sebebi, verilerde veritabanın desteklediği dil kodlamadaki karakterlerin dışında bir karaktere rastlamasıdır. Bunun en yaygın örneği 8 bitlik veriyi SQL_ASCII veritabanında saklamasıdır.";
    t[278] = "This PooledConnection has already been closed.";
    t[279] = "Geçerli PooledConnection zaten önceden kapatıldı.";
    t[280] = "Cannot call cancelRowUpdates() when on the insert row.";
    t[281] = "Insert edilmiş kaydın üzerindeyken cancelRowUpdates() çağırılamaz.";
    t[284] = "Cannot rollback prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. rollback xid={0}, transactionState={1}";
    t[285] = "Bu bağlantıda bir yerel transaction sürerken hazırlanmış transaction rollback edilemez. Önce yerel transaction''ı commit veya rollback edin. rollback xid={0}, transactionState={1}";
    t[288] = "PostgreSQL LOBs can only index to: {0}";
    t[289] = "PostgreSQL LOB göstergeleri sadece {0} referans edebilir";
    t[290] = "Provided InputStream failed.";
    t[291] = "Sağlanmış InputStream başarısız.";
    t[298] = "Unexpected error writing large object to database.";
    t[299] = "Large object veritabanına yazılırken beklenmeyan hata.";
    t[300] = "Fetch size must be a value greater than or equal to 0.";
    t[301] = "Fetch boyutu sıfır veya daha büyük bir değer olmalıdır.";
    t[310] = "Invalid protocol state requested. Attempted transaction interleaving is not supported. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[311] = "Transaction interleaving desteklenmiyor. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[312] = "Transaction was already prepared on this connection. prepare xid={0}, preparedXid={1}";
    t[313] = "Transaction bu bağlantıda zaten hazırlanmış. prepare xid={0}, preparedXid={1}";
    t[314] = "The parameter index is out of range: {0}, number of parameters: {1}.";
    t[315] = "Dizin göstergisi kapsam dışıdır: {0}, öğe sayısı: {1}.";
    t[316] = "Not on the insert row.";
    t[317] = "Insert kaydı değil.";
    t[320] = "{0} function takes two and only two arguments.";
    t[321] = "{0} fonksiyonunu sadece iki parametre alabilir.";
    t[322] = "Cannot change transaction read-only property in the middle of a transaction.";
    t[323] = "Transaction ortasında geçerli transactionun read-only özellği değiştirilemez.";
    t[330] = "Unsupported value for stringtype parameter: {0}";
    t[331] = "strinftype parametresi için destekleneyen değer: {0}";
    t[332] = "Unknown Response Type {0}.";
    t[333] = "Bilinmeyen yanıt tipi {0}";
    t[334] = "This SQLXML object has not been initialized, so you cannot retrieve data from it.";
    t[335] = "Bu SQLXML nesnesi ilklendirilmemiş; o yüzden ondan veri alamazsınız.";
    t[336] = "An error occurred while setting up the SSL connection.";
    t[337] = "SSL bağlantısı ayarlanırken bir hata oluştu.";
    t[344] = "Invalid UUID data.";
    t[345] = "Geçersiz UUID verisi.";
    t[354] = "Zero bytes may not occur in identifiers.";
    t[355] = "Belirteçlerde sıfır bayt olamaz.";
    t[360] = "A connection could not be made using the requested protocol {0}.";
    t[361] = "İstenilen protokol ile bağlantı kurulamadı {0}";
    t[362] = "You must specify at least one column value to insert a row.";
    t[363] = "Bir satır eklemek için en az bir sütun değerini belirtmelisiniz.";
    t[364] = "Method {0} is not yet implemented.";
    t[365] = "{0} yöntemi henüz kodlanmadı.";
    t[368] = "Unknown ResultSet holdability setting: {0}.";
    t[369] = "ResultSet tutabilme ayarı geçersiz: {0}.";
    t[374] = "Cannot 2nd phase commit prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. commit xid={0}, transactionState={1}";
    t[375] = "Bu bağlantıda bir yerel transaction sürerken hazırlanmış transaction 2. faz commit edilemez. Önce yerel transaction''ı commit veya rollback edin. commit xid={0}, transactionState={1}";
    t[376] = "wasNull cannot be call before fetching a result.";
    t[377] = "wasNull sonuç çekmeden önce çağırılamaz.";
    t[378] = "Returning autogenerated keys is not supported.";
    t[379] = "Otomatik üretilen değerlerin getirilmesi desteklenememktedir.";
    t[380] = "Cannot update the ResultSet because it is either before the start or after the end of the results.";
    t[381] = "ResultSet, sonuçların ilk kaydından önce veya son kaydından sonra olduğu için güncelleme yapılamamaktadır.";
    t[384] = "Unable to bind parameter values for statement.";
    t[385] = "Komut için parametre değerlei bağlanamadı.";
    t[390] = "Unable to create StAXResult for SQLXML";
    t[391] = "SQLXML için StAXResult yaratılamadı";
    t[394] = "Unknown XML Source class: {0}";
    t[395] = "Bilinmeyen XML Kaynak Sınıfı: {0}";
    t[396] = "LOB positioning offsets start at 1.";
    t[397] = "LOB bağlangıç adresi 1Den başlıyor";
    t[402] = "This SQLXML object has already been initialized, so you cannot manipulate it further.";
    t[403] = "Bu SQLXML nesnesi daha önceden ilklendirilmiştir; o yüzden daha fazla müdahale edilemez.";
    t[404] = "Transaction isolation level {0} not supported.";
    t[405] = "Transaction isolation level {0} desteklenmiyor.";
    t[406] = "{0} function takes two or three arguments.";
    t[407] = "{0} fonksiyonu yalnız iki veya üç argüman alabilir.";
    t[412] = "Conversion of interval failed";
    t[413] = "Interval dönüştürmesi başarısız.";
    t[414] = "A CallableStatement function was executed and the out parameter {0} was of type {1} however type {2} was registered.";
    t[415] = "CallableStatement çalıştırıldı, ancak {2} tipi kaydedilmesine rağmen döndürme parametresi {0} ve tipi {1} idi.";
    t[416] = "Transaction control methods setAutoCommit, commit, rollback and setSavepoint are not allowed while an XA transaction is active.";
    t[417] = "XA transaction etkinken setAutoCommit, commit, rollback ve setSavepoint transaction kontrol metotlarına izin verilmez.";
    t[422] = "Statement has been closed.";
    t[423] = "Komut kapatıldı.";
    t[424] = "Fastpath call {0} - No result was returned and we expected an integer.";
    t[425] = "Fastpath call {0} - Integer beklenirken hiçbir sonuç getirilmedi.";
    t[428] = "Something unusual has occurred to cause the driver to fail. Please report this exception.";
    t[429] = "Sıradışı bir durum sürücünün hata vermesine sebep oldu. Lütfen bu durumu geliştiricilere bildirin.";
    t[430] = "This ResultSet is closed.";
    t[431] = "ResultSet kapalıdır.";
    t[432] = "Unknown Types value.";
    t[433] = "Geçersiz Types değeri.";
    t[434] = "Operation requires a scrollable ResultSet, but this ResultSet is FORWARD_ONLY.";
    t[435] = "İşlem, kaydırılabilen ResultSet gerektirir, ancak bu ResultSet FORWARD_ONLYdir.";
    t[450] = "No function outputs were registered.";
    t[451] = "Hiçbir fonksiyon çıktısı kaydedilmedi.";
    t[454] = "Conversion of money failed.";
    t[455] = "Money dönüştürmesi başarısız.";
    t[460] = "xid must not be null";
    t[461] = "xid null olamaz";
    t[462] = "The SSLSocketFactory class provided {0} could not be instantiated.";
    t[463] = "SSLSocketFactory {0} ile örneklenmedi.";
    t[466] = "Large Objects may not be used in auto-commit mode.";
    t[467] = "Auto-commit biçimde large object kullanılamaz.";
    t[468] = "{0} function takes one and only one argument.";
    t[469] = "{0} fonksiyonunu yalnız tek bir parametre alabilir.";
    t[470] = "Unable to convert DOMResult SQLXML data to a string.";
    t[471] = "DOMResult SQLXML verisini diziye dönüştürülemedi.";
    t[474] = "Cannot call updateRow() when on the insert row.";
    t[475] = "Insert  kaydı üzerinde updateRow() çağırılamaz.";
    t[478] = "Can''t use relative move methods while on the insert row.";
    t[479] = "Insert kaydı üzerinde relative move method kullanılamaz.";
    t[482] = "ResultSets with concurrency CONCUR_READ_ONLY cannot be updated.";
    t[483] = "Eş zamanlama CONCUR_READ_ONLY olan ResultSet''ler değiştirilemez";
    t[484] = "Unable to find name datatype in the system catalogs.";
    t[485] = "Sistem kataloglarında name veri tipi bulunamıyor.";
    t[486] = "Bind message length {0} too long.  This can be caused by very large or incorrect length specifications on InputStream parameters.";
    t[487] = "Bind mesaj uzunluğu ({0}) fazla uzun. Bu durum InputStream yalnış uzunluk belirtimlerden kaynaklanabilir.";
    t[488] = "Can''t use query methods that take a query string on a PreparedStatement.";
    t[489] = "PreparedStatement ile sorgu satırı alan sorgu yöntemleri kullanılamaz.";
    t[490] = "A CallableStatement was executed with an invalid number of parameters";
    t[491] = "CallableStatement geçersiz sayıda parametre ile çalıştırıldı.";
    t[500] = "Cannot call deleteRow() when on the insert row.";
    t[501] = "Insert  kaydı üzerinde deleteRow() çağırılamaz.";
    t[502] = "A CallableStatement was declared, but no call to registerOutParameter(1, <some type>) was made.";
    t[503] = "CallableStatement bildirildi ancak registerOutParameter(1, < bir tip>) tanıtımı yapılmadı.";
    t[508] = "Currently positioned before the start of the ResultSet.  You cannot call deleteRow() here.";
    t[509] = "Şu an ResultSet başlangcıından önce konumlandı. deleteRow() burada çağırabilirsiniz.";
    t[510] = "{0} function takes three and only three arguments.";
    t[511] = "{0} fonksiyonunu sadece üç parametre alabilir.";
    t[518] = "Query timeout must be a value greater than or equals to 0.";
    t[519] = "Sorgu zaman aşımı değer sıfır veya sıfırdan büyük bir sayı olmalıdır.";
    t[520] = "There are no rows in this ResultSet.";
    t[521] = "Bu ResultSet içinde kayıt bulunamadı.";
    t[524] = "Heuristic commit/rollback not supported. forget xid={0}";
    t[525] = "Heuristic commit/rollback desteklenmiyor. forget xid={0}";
    t[528] = "Provided Reader failed.";
    t[529] = "Sağlanmış InputStream başarısız.";
    t[530] = "Internal Query: {0}";
    t[531] = "Internal Query: {0}";
    t[532] = "The JVM claims not to support the {0} encoding.";
    t[533] = "JVM, {0} dil kodlamasını desteklememektedir.";
    t[544] = "The column name {0} was not found in this ResultSet.";
    t[545] = "Bu ResultSet içinde {0} sütun adı bulunamadı.";
    t[546] = "Error rolling back transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[547] = "Transaction rollback hatası. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[560] = "No value specified for parameter {0}.";
    t[561] = "{0} parametresi için hiç bir değer belirtilmedi.";
    t[562] = "Can''t refresh the insert row.";
    t[563] = "Inser satırı yenilenemiyor.";
    t[566] = "The array index is out of range: {0}";
    t[567] = "Dizi göstergesi kapsam dışıdır: {0}";
    t[568] = "ClientInfo property not supported.";
    t[569] = "Clientinfo property'si desteklenememktedir.";
    t[570] = "Malformed function or procedure escape syntax at offset {0}.";
    t[571] = "{0} adresinde fonksiyon veya yordamda kaçış söz dizimi geçersiz.";
    t[578] = "Error committing prepared transaction. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[579] = "Hazırlanmış transaction commit hatası. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[586] = "This SQLXML object has already been freed.";
    t[587] = "Bu SQLXML nesnesi zaten boşaltılmış.";
    t[590] = "One-phase commit called for xid {0} but connection was prepared with xid {1}";
    t[591] = "One-phase commit xid {0} için çağrıldı, ancak bağlantı xid {1} ile hazırlanmıştı";
    t[602] = "One-phase commit with unknown xid. commit xid={0}, currentXid={1}";
    t[603] = "Bilinmeyen xid ile one-phase commit. commit xid={0}, currentXid={1}";
    t[606] = "Position: {0}";
    t[607] = "Position: {0}";
    t[612] = "Detail: {0}";
    t[613] = "Ayrıntı: {0}";
    t[616] = "The JVM claims not to support the encoding: {0}";
    t[617] = "JVM, {0} dil kodlamasını desteklememektedir.";
    t[618] = "Unable to determine a value for MaxIndexKeys due to missing system catalog data.";
    t[619] = "Sistem kataloğu olmadığından MaxIndexKeys değerini tespit edilememektedir.";
    t[620] = "Invalid fetch direction constant: {0}.";
    t[621] = "Getirme yönü değişmezi geçersiz: {0}.";
    t[622] = "Multiple ResultSets were returned by the query.";
    t[623] = "Sorgu tarafından birden fazla ResultSet getirildi.";
    t[626] = "The server does not support SSL.";
    t[627] = "Sunucu SSL desteklemiyor.";
    t[630] = "Server SQLState: {0}";
    t[631] = "Sunucu SQLState: {0}";
    t[632] = "Premature end of input stream, expected {0} bytes, but only read {1}.";
    t[633] = "Giriş akımında beklenmeyen dosya sonu, {0} bayt beklenirken sadece {1} bayt alındı.";
    t[636] = "Expected an EOF from server, got: {0}";
    t[637] = "Sunucudan EOF beklendi; ama {0} alındı.";
    t[638] = "Hint: {0}";
    t[639] = "İpucu: {0}";
    t[640] = "Interrupted while attempting to connect.";
    t[641] = "Bağlanırken kesildi.";
    t[642] = "The connection attempt failed.";
    t[643] = "Bağlantı denemesi başarısız oldu.";
    t[644] = "Too many update results were returned.";
    t[645] = "Çok fazla güncelleme sonucu döndürüldü.";
    t[650] = "Cannot convert an instance of {0} to type {1}";
    t[651] = "{0} instance, {1} tipine dönüştürülemiyor";
    t[652] = "Prepare must be issued on the connection that started the branch. Transaction interleaving is not supported. prepare xid={0}, currentXid={1}";
    t[653] = "Prepare, dalı başlatan bağlantı üzerinde çağrılmalıdır. Transaction interleaving desteklenmiyor. prepare xid={0}, currentXid={1}";
    t[660] = "One-phase commit must be issued on the connection that started the branch. commit xid={0}";
    t[661] = "One-phase commit, dalı başlatan bağlantı üzerinde çağrılmalıdır. commit xid={0}";
    t[664] = "The maximum field size must be a value greater than or equal to 0.";
    t[665] = "En büyük alan boyutu sıfır ya da sıfırdan büyük bir değer olmalı.";
    t[666] = "Interval {0} not yet implemented";
    t[667] = "{0} aralığı henüz kodlanmadı.";
    t[668] = "Parameter of type {0} was registered, but call to get{1} (sqltype={2}) was made.";
    t[669] = "{0} tipinde parametre tanıtıldı, ancak {1} (sqltype={2}) tipinde geri getirmek için çağrı yapıldı.";
    t[672] = "Current connection does not have an associated xid. prepare xid={0}";
    t[673] = "Mevcut bağlantının ilişkilendirilmiş bir xid''i yok. prepare xid={0}";
    t[674] = "Cannot establish a savepoint in auto-commit mode.";
    t[675] = "Auto-commit biçimde savepoint oluşturulamıyor.";
    t[676] = "A result was returned when none was expected.";
    t[677] = "Hiçbir sonuç kebklenimezken sonuç getirildi.";
    table = t;
  }
  public java.lang.Object handleGetObject (java.lang.String msgid) throws java.util.MissingResourceException {
    int hash_val = msgid.hashCode() & 0x7fffffff;
    int idx = (hash_val % 343) << 1;
    {
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
    int incr = ((hash_val % 341) + 1) << 1;
    for (;;) {
      idx += incr;
      if (idx >= 686)
        idx -= 686;
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
  }
  public java.util.Enumeration getKeys () {
    return
      new java.util.Enumeration() {
        private int idx = 0;
        { while (idx < 686 && table[idx] == null) idx += 2; }
        public boolean hasMoreElements () {
          return (idx < 686);
        }
        public java.lang.Object nextElement () {
          java.lang.Object key = table[idx];
          do idx += 2; while (idx < 686 && table[idx] == null);
          return key;
        }
      };
  }
  public java.util.ResourceBundle getParent () {
    return parent;
  }
}
