/* Automatically generated by GNU msgfmt.  Do not modify!  */
package org.postgresql.translation;
public class messages_fr extends java.util.ResourceBundle {
  private static final java.lang.String[] table;
  static {
    java.lang.String[] t = new java.lang.String[686];
    t[0] = "";
    t[1] = "Project-Id-Version: head-fr\nReport-Msgid-Bugs-To: \nPO-Revision-Date: 2007-07-27 12:27+0200\nLast-Translator: \nLanguage-Team:  <en@li.org>\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Generator: KBabel 1.11.4\nPlural-Forms:  nplurals=2; plural=(n > 1);\n";
    t[2] = "Connection has been closed automatically because a new connection was opened for the same PooledConnection or the PooledConnection has been closed.";
    t[3] = "La connexion a été fermée automatiquement car une nouvelle connexion a été ouverte pour la même PooledConnection ou la PooledConnection a été fermée.";
    t[10] = "Failed to create object for: {0}.";
    t[11] = "Échec à la création de l''objet pour : {0}.";
    t[16] = "Unsupported Types value: {0}";
    t[17] = "Valeur de type non supportée : {0}";
    t[20] = "{0} function doesn''t take any argument.";
    t[21] = "La fonction {0} n''accepte aucun argument.";
    t[24] = "Currently positioned after the end of the ResultSet.  You cannot call deleteRow() here.";
    t[25] = "Actuellement positionné après la fin du ResultSet. Vous ne pouvez pas appeler deleteRow() ici.";
    t[30] = "Connection attempt timed out.";
    t[31] = "La tentative de connexion a échoué dans le délai imparti.";
    t[32] = "Can''t infer the SQL type to use for an instance of {0}. Use setObject() with an explicit Types value to specify the type to use.";
    t[33] = "Impossible de déduire le type SQL à utiliser pour une instance de {0}. Utilisez setObject() avec une valeur de type explicite pour spécifier le type à utiliser.";
    t[36] = "Connection is already associated with an active XA branch. End the current branch before starting a new one. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[37] = "La connection est déjà associée à une branche XA active. Terminez la branche en cours avant d''en démarrer une nouvelle. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[38] = "Where: {0}";
    t[39] = "Où : {0}";
    t[42] = "ResultSet not positioned properly, perhaps you need to call next.";
    t[43] = "Le ResultSet n''est pas positionné correctement, vous devez peut-être appeler next().";
    t[44] = "Error during one-phase commit. commit xid={0}";
    t[45] = "Erreur pendant le commit à une phase. commit xid={0}";
    t[48] = "The server''s DateStyle parameter was changed to {0}. The JDBC driver requires DateStyle to begin with ISO for correct operation.";
    t[49] = "Le paramètre DateStyle du serveur a été changé pour {0}. Le pilote JDBC nécessite que DateStyle commence par ISO pour un fonctionnement correct.";
    t[58] = "Cannot change transaction read-only property in the middle of a transaction.";
    t[59] = "Impossible de changer la propriété read-only d''une transaction au milieu d''une transaction.";
    t[62] = "commit() called before end(). commit xid={0}, state={1}";
    t[63] = "commit() appelé avant end(). commit xid={0}, state={1}";
    t[72] = "No results were returned by the query.";
    t[73] = "Aucun résultat retourné par la requête.";
    t[76] = "Cannot tell if path is open or closed: {0}.";
    t[77] = "Impossible de dire si path est fermé ou ouvert : {0}.";
    t[80] = "2nd phase commit cannot be issued while an XA branch is active on this connection. commit xid={0}, currentXid={1}, state={2}";
    t[81] = "Le commit à deux phases ne peut être envoyé tant qu''une branche XA est active sur cette connection. commit xid={0}, currentXid={1}, state={2}";
    t[88] = "The fastpath function {0} is unknown.";
    t[89] = "La fonction fastpath {0} est inconnue.";
    t[92] = "Cannot retrieve the id of a named savepoint.";
    t[93] = "Impossible de retrouver l''identifiant d''un savepoint nommé.";
    t[100] = "The column index is out of range: {0}, number of columns: {1}.";
    t[101] = "L''indice de la colonne est hors limite : {0}, nombre de colonnes : {1}.";
    t[104] = "Protocol error.  Session setup failed.";
    t[105] = "Erreur de protocole. Ouverture de la session en échec.";
    t[108] = "Suspend/resume not implemented";
    t[109] = "Suspend/resume pas implémenté";
    t[112] = "free() was called on this LOB previously";
    t[113] = "free() a été appelée auparavant sur ce LOB";
    t[114] = "end() called without a matching start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[115] = "end() appelé sans start() correspondant. end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[116] = "Unable to translate data into the desired encoding.";
    t[117] = "Impossible de traduire les données dans l''encodage désiré.";
    t[126] = "Prepare called before end(). prepare xid={0}, state={1}";
    t[127] = "Préparation appelée avant end(). prepare xid={0}, state={1}";
    t[130] = "ResultSet is not updateable.  The query that generated this result set must select only one table, and must select all primary keys from that table. See the JDBC 2.1 API Specification, section 5.6 for more details.";
    t[131] = "Le ResultSet n''est pas modifiable. La requête qui a généré ce résultat doit sélectionner seulement une table, et doit sélectionner toutes les clés primaires de cette table. Voir la spécification de l''API JDBC 2.1, section 5.6 pour plus de détails.";
    t[138] = "Cannot retrieve the name of an unnamed savepoint.";
    t[139] = "Impossible de retrouver le nom d''un savepoint sans nom.";
    t[142] = "The array index is out of range: {0}, number of elements: {1}.";
    t[143] = "L''indice du tableau est hors limites : {0}, nombre d''éléments : {1}.";
    t[144] = "Cannot cast an instance of {0} to type {1}";
    t[145] = "Impossible de convertir une instance de {0} vers le type {1}";
    t[152] = "Error during recover. flag={0}";
    t[153] = "Erreur durant la restauration. flag={0}";
    t[158] = "Bad value for type {0} : {1}";
    t[159] = "Mauvaise valeur pour le type {0} : {1}";
    t[160] = "An unexpected result was returned by a query.";
    t[161] = "Un résultat inattendu a été retourné par une requête.";
    t[162] = "Expected command status BEGIN, got {0}.";
    t[163] = "Attendait le statut de commande BEGIN, obtenu {0}.";
    t[166] = "Unable to load the class {0} responsible for the datatype {1}";
    t[167] = "Incapable de charger la classe {0} responsable du type de données {1}";
    t[168] = "Cannot change transaction isolation level in the middle of a transaction.";
    t[169] = "Impossible de changer le niveau d''isolation des transactions au milieu d''une transaction.";
    t[174] = "The server''s standard_conforming_strings parameter was reported as {0}. The JDBC driver expected on or off.";
    t[175] = "Le paramètre serveur standard_conforming_strings a pour valeur {0}. Le driver JDBC attend on ou off.";
    t[178] = "Invalid stream length {0}.";
    t[179] = "Longueur de flux invalide {0}.";
    t[184] = "Results cannot be retrieved from a CallableStatement before it is executed.";
    t[185] = "Les résultats ne peuvent être récupérés à partir d''un CallableStatement avant qu''il ne soit exécuté.";
    t[186] = "This statement has been closed.";
    t[187] = "Ce statement a été fermé.";
    t[188] = "Error loading default settings from driverconfig.properties";
    t[189] = "Erreur de chargement des valeurs par défaut depuis driverconfig.properties";
    t[190] = "Invalid flags {0}";
    t[191] = "Drapeaux invalides {0}";
    t[196] = "xid must not be null";
    t[197] = "xid ne doit pas être nul";
    t[204] = "Conversion to type {0} failed: {1}.";
    t[205] = "La conversion vers le type {0} a échoué : {1}.";
    t[206] = "DataSource has been closed.";
    t[207] = "DataSource a été fermée.";
    t[208] = "Connection has been closed.";
    t[209] = "La connexion a été fermée.";
    t[210] = "A CallableStatement was executed with nothing returned.";
    t[211] = "Un CallableStatement a été exécuté mais n''a rien retourné.";
    t[218] = "Unexpected command status: {0}.";
    t[219] = "Statut de commande inattendu : {0}.";
    t[220] = "Cannot reference a savepoint after it has been released.";
    t[221] = "Impossible de référencer un savepoint après qu''il ait été libéré.";
    t[222] = "Error opening transaction. start xid={0}";
    t[223] = "Erreur à l''ouverture de la transaction. start xid={0}";
    t[228] = "The authentication type {0} is not supported. Check that you have configured the pg_hba.conf file to include the client''s IP address or subnet, and that it is using an authentication scheme supported by the driver.";
    t[229] = "Le type d''authentification {0} n''est pas supporté. Vérifiez que vous avez configuré le fichier pg_hba.conf pour inclure l''adresse IP du client ou le sous-réseau et qu''il utilise un schéma d''authentification supporté par le pilote.";
    t[242] = "Internal Position: {0}";
    t[243] = "Position interne : {0}";
    t[244] = "This statement does not declare an OUT parameter.  Use '{' ?= call ... '}' to declare one.";
    t[245] = "Cette requête ne déclare pas de paramètre OUT. Utilisez '{' ?= call ... '}' pour en déclarer un.";
    t[256] = "Location: File: {0}, Routine: {1}, Line: {2}";
    t[257] = "Localisation : Fichier : {0}, Routine : {1}, Ligne : {2}";
    t[258] = "Unknown type {0}.";
    t[259] = "Type inconnu : {0}.";
    t[260] = "Ran out of memory retrieving query results.";
    t[261] = "Ai manqué de mémoire en récupérant les résultats de la requête.";
    t[264] = "Zero bytes may not occur in string parameters.";
    t[265] = "Zéro octets ne devrait pas se produire dans les paramètres de type chaîne de caractères.";
    t[266] = "{0} function takes four and only four argument.";
    t[267] = "La fonction {0} n''accepte que quatre et seulement quatre arguments.";
    t[268] = "Truncation of large objects is only implemented in 8.3 and later servers.";
    t[269] = "Le troncage des large objects n''est implémenté que dans les serveurs 8.3 et supérieurs.";
    t[270] = "Invalid character data was found.  This is most likely caused by stored data containing characters that are invalid for the character set the database was created in.  The most common example of this is storing 8bit data in a SQL_ASCII database.";
    t[271] = "Des données de caractères invalides ont été trouvées. C''est probablement causé par le stockage de caractères invalides pour le jeu de caractères de création de la base. L''exemple le plus courant est le stockage de données 8bit dans une base SQL_ASCII.";
    t[278] = "This PooledConnection has already been closed.";
    t[279] = "Cette PooledConnection a déjà été fermée.";
    t[280] = "Cannot call cancelRowUpdates() when on the insert row.";
    t[281] = "Impossible d''appeler cancelRowUpdates() pendant l''insertion d''une ligne.";
    t[284] = "Cannot rollback prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. rollback xid={0}, transactionState={1}";
    t[285] = "Impossible d''annuler une transaction préparée tant qu''une transaction locale est en cours sur cette connection. Validez ou annulez d''abord la transaction locale. rollback xid={0}, transactionState={1}";
    t[288] = "PostgreSQL LOBs can only index to: {0}";
    t[289] = "Les LOB PostgreSQL peuvent seulement s''indicer à: {0}";
    t[290] = "Provided InputStream failed.";
    t[291] = "L''InputStream fourni a échoué.";
    t[298] = "Unexpected error writing large object to database.";
    t[299] = "Erreur inattendue pendant l''écriture de large object dans la base.";
    t[300] = "Fetch size must be a value greater than or equal to 0.";
    t[301] = "Fetch size doit être une valeur supérieur ou égal à 0.";
    t[310] = "Invalid protocol state requested. Attempted transaction interleaving is not supported. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[311] = "État de protocole demandé invalide. L''entrelacement de transactions n''est pas supporté. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[312] = "Transaction was already prepared on this connection. prepare xid={0}, preparedXid={1}";
    t[313] = "La transaction a déjà été préparée sur cette connection. prepare xid={0}, preparedXid={1}";
    t[314] = "The parameter index is out of range: {0}, number of parameters: {1}.";
    t[315] = "L''indice du paramètre est hors limites : {0}, nombre de paramètres : {1}.";
    t[316] = "Not on the insert row.";
    t[317] = "Pas sur la ligne en insertion.";
    t[320] = "{0} function takes two and only two arguments.";
    t[321] = "La fonction {0} n''accepte que deux et seulement deux arguments.";
    t[326] = "The JVM claims not to support the {0} encoding.";
    t[327] = "La JVM prétend ne pas supporter l''encodage {0}.";
    t[330] = "Unsupported value for stringtype parameter: {0}";
    t[331] = "Valeur non supportée pour les paramètre de type chaîne de caractères : {0}";
    t[332] = "Unknown Response Type {0}.";
    t[333] = "Type de réponse inconnu {0}.";
    t[336] = "An error occurred while setting up the SSL connection.";
    t[337] = "Une erreur s''est produite pendant l''établissement de la connexion SSL.";
    t[354] = "Zero bytes may not occur in identifiers.";
    t[355] = "Des octects à 0 ne devraient pas apparaître dans les identifiants.";
    t[360] = "A connection could not be made using the requested protocol {0}.";
    t[361] = "Aucune connexion n''a pu être établie en utilisant le protocole demandé {0}. ";
    t[362] = "You must specify at least one column value to insert a row.";
    t[363] = "Vous devez spécifier au moins une valeur de colonne pour insérer une ligne.";
    t[364] = "Method {0} is not yet implemented.";
    t[365] = "La fonction {0} n''est pas encore implémentée.";
    t[368] = "Unknown ResultSet holdability setting: {0}.";
    t[369] = "Paramètre holdability du ResultSet inconnu : {0}.";
    t[374] = "Cannot 2nd phase commit prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. commit xid={0}, transactionState={1}";
    t[375] = "Impossible de valider en deuxième phase une transaction préparée tant qu''une transaction locale est en cours sur cette connection. Validez ou annulez d''abord la transaction locale. commit xid={0}, transactionState={1}";
    t[376] = "wasNull cannot be call before fetching a result.";
    t[377] = "wasNull ne peut pas être appelé avant la récupération d''un résultat.";
    t[378] = "Returning autogenerated keys is not supported.";
    t[379] = "Le renvoi des clés automatiquement générées n''est pas supporté.";
    t[380] = "Cannot update the ResultSet because it is either before the start or after the end of the results.";
    t[381] = "Impossible de mettre à jour le ResultSet car c''est soit avant le début ou après la fin des résultats.";
    t[384] = "Unable to bind parameter values for statement.";
    t[385] = "Incapable de lier les valeurs des paramètres pour la commande.";
    t[390] = "Error preparing transaction. prepare xid={0}";
    t[391] = "Erreur en préparant la transaction. prepare xid={0}";
    t[396] = "LOB positioning offsets start at 1.";
    t[397] = "Les décalages de position des LOB commencent à 1.";
    t[404] = "Transaction isolation level {0} not supported.";
    t[405] = "Le niveau d''isolation de transaction {0} n''est pas supporté.";
    t[406] = "{0} function takes two or three arguments.";
    t[407] = "La fonction {0} n''accepte que deux ou trois arguments.";
    t[412] = "Conversion of interval failed";
    t[413] = "La conversion de l''intervalle a échoué";
    t[414] = "A CallableStatement function was executed and the out parameter {0} was of type {1} however type {2} was registered.";
    t[415] = "Une fonction CallableStatement a été exécutée et le paramètre en sortie {0} était du type {1} alors que le type {2} était prévu.";
    t[416] = "Transaction control methods setAutoCommit, commit, rollback and setSavepoint are not allowed while an XA transaction is active.";
    t[417] = "Les méthodes de contrôle de transaction setAutoCommit, commit, rollback et setSavepoint ne sont pas autorisées lorsqu''une transaction XA est active.";
    t[422] = "Statement has been closed.";
    t[423] = "Statement a été fermé.";
    t[424] = "Fastpath call {0} - No result was returned and we expected an integer.";
    t[425] = "Appel Fastpath {0} - Aucun résultat n''a été retourné et nous attendions un entier.";
    t[428] = "Something unusual has occurred to cause the driver to fail. Please report this exception.";
    t[429] = "Quelque chose d''inhabituel a provoqué l''échec du pilote. Veuillez faire un rapport sur cette erreur.";
    t[430] = "This ResultSet is closed.";
    t[431] = "Ce ResultSet est fermé.";
    t[432] = "Unknown Types value.";
    t[433] = "Valeur de Types inconnue.";
    t[434] = "Operation requires a scrollable ResultSet, but this ResultSet is FORWARD_ONLY.";
    t[435] = "L''opération nécessite un scrollable ResultSet, mais ce ResultSet est FORWARD_ONLY.";
    t[450] = "No function outputs were registered.";
    t[451] = "Aucune fonction outputs n''a été enregistrée.";
    t[454] = "Conversion of money failed.";
    t[455] = "La conversion de money a échoué.";
    t[462] = "The SSLSocketFactory class provided {0} could not be instantiated.";
    t[463] = "La classe SSLSocketFactory fournie {0} n''a pas pu être instanciée.";
    t[466] = "Large Objects may not be used in auto-commit mode.";
    t[467] = "Les Large Objects ne devraient pas être utilisés en mode auto-commit.";
    t[468] = "{0} function takes one and only one argument.";
    t[469] = "La fonction {0} n''accepte qu''un et un seul argument.";
    t[474] = "Cannot call updateRow() when on the insert row.";
    t[475] = "Impossible d''appeler updateRow() tant que l''on est sur la ligne insérée.";
    t[478] = "Can''t use relative move methods while on the insert row.";
    t[479] = "Impossible d''utiliser les fonctions de déplacement relatif pendant l''insertion d''une ligne.";
    t[482] = "ResultSets with concurrency CONCUR_READ_ONLY cannot be updated.";
    t[483] = "Les ResultSets avec la concurrence CONCUR_READ_ONLY ne peuvent être mis à jour.";
    t[484] = "Unable to find name datatype in the system catalogs.";
    t[485] = "Incapable de trouver le type de donnée name dans les catalogues systèmes.";
    t[486] = "Bind message length {0} too long.  This can be caused by very large or incorrect length specifications on InputStream parameters.";
    t[487] = "La longueur du message de liaison {0} est trop grande. Cela peut être causé par des spécification de longueur très grandes ou incorrectes pour les paramètres de type InputStream.";
    t[488] = "Can''t use query methods that take a query string on a PreparedStatement.";
    t[489] = "Impossible d''utiliser les fonctions de requête qui utilisent une chaîne de caractères sur un PreparedStatement.";
    t[500] = "Cannot call deleteRow() when on the insert row.";
    t[501] = "Impossible d''appeler deleteRow() pendant l''insertion d''une ligne.";
    t[502] = "A CallableStatement was declared, but no call to registerOutParameter(1, <some type>) was made.";
    t[503] = "Un CallableStatement a été déclaré, mais aucun appel à registerOutParameter(1, <un type>) n''a été fait.";
    t[508] = "Currently positioned before the start of the ResultSet.  You cannot call deleteRow() here.";
    t[509] = "Actuellement positionné avant le début du ResultSet. Vous ne pouvez pas appeler deleteRow() ici.";
    t[510] = "{0} function takes three and only three arguments.";
    t[511] = "La fonction {0} n''accepte que trois et seulement trois arguments.";
    t[518] = "Query timeout must be a value greater than or equals to 0.";
    t[519] = "Query timeout doit être une valeur supérieure ou égale à 0.";
    t[520] = "There are no rows in this ResultSet.";
    t[521] = "Il n''y pas pas de lignes dans ce ResultSet.";
    t[524] = "Heuristic commit/rollback not supported. forget xid={0}";
    t[525] = "Heuristic commit/rollback non supporté. forget xid={0}";
    t[528] = "Provided Reader failed.";
    t[529] = "Le Reader fourni a échoué.";
    t[530] = "Internal Query: {0}";
    t[531] = "Requête interne: {0}";
    t[532] = "An I/O error occurred while sending to the backend.";
    t[533] = "Une erreur d''entrée/sortie a eu lieu lors d''envoi vers le serveur.";
    t[544] = "The column name {0} was not found in this ResultSet.";
    t[545] = "Le nom de colonne {0} n''a pas été trouvé dans ce ResultSet.";
    t[546] = "Error rolling back transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[547] = "Erreur en annulant la transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[560] = "No value specified for parameter {0}.";
    t[561] = "Pas de valeur spécifiée pour le paramètre {0}.";
    t[562] = "Can''t refresh the insert row.";
    t[563] = "Impossible de rafraîchir la ligne insérée.";
    t[566] = "The array index is out of range: {0}";
    t[567] = "L''indice du tableau est hors limites : {0}";
    t[570] = "Malformed function or procedure escape syntax at offset {0}.";
    t[571] = "Syntaxe de fonction ou d''échappement de procédure malformée à l''indice {0}.";
    t[578] = "Error committing prepared transaction. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[579] = "Erreur en validant une transaction préparée. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[590] = "One-phase commit called for xid {0} but connection was prepared with xid {1}";
    t[591] = "Commit à une phase appelé pour xid {0} mais la connection a été préparée avec xid {1}";
    t[602] = "One-phase commit with unknown xid. commit xid={0}, currentXid={1}";
    t[603] = "Commit à une phase avec un xid inconnu. commit xid={0}, currentXid={1}";
    t[606] = "Position: {0}";
    t[607] = "Position : {0}";
    t[612] = "Detail: {0}";
    t[613] = "Détail : {0}";
    t[616] = "The JVM claims not to support the encoding: {0}";
    t[617] = "La JVM prétend ne pas supporter l''encodage: {0}";
    t[618] = "Unable to determine a value for MaxIndexKeys due to missing system catalog data.";
    t[619] = "Incapable de déterminer la valeur de MaxIndexKeys en raison de données manquante dans lecatalogue système.";
    t[620] = "Invalid fetch direction constant: {0}.";
    t[621] = "Constante de direction pour la récupération invalide : {0}.";
    t[622] = "Multiple ResultSets were returned by the query.";
    t[623] = "Plusieurs ResultSets ont été retournés par la requête.";
    t[626] = "The server does not support SSL.";
    t[627] = "Le serveur ne supporte pas SSL.";
    t[630] = "Server SQLState: {0}";
    t[631] = "SQLState serveur : {0}";
    t[632] = "Premature end of input stream, expected {0} bytes, but only read {1}.";
    t[633] = "Fin prématurée du flux en entrée, {0} octets attendus, mais seulement {1} lus.";
    t[636] = "Expected an EOF from server, got: {0}";
    t[637] = "Attendait une fin de fichier du serveur, reçu: {0}";
    t[638] = "Hint: {0}";
    t[639] = "Indice : {0}";
    t[640] = "Interrupted while attempting to connect.";
    t[641] = "Interrompu pendant l''établissement de la connexion.";
    t[642] = "The connection attempt failed.";
    t[643] = "La tentative de connexion a échoué.";
    t[644] = "Too many update results were returned.";
    t[645] = "Trop de résultats de mise à jour ont été retournés.";
    t[650] = "Cannot convert an instance of {0} to type {1}";
    t[651] = "Impossible de convertir une instance de type {0} vers le type {1}";
    t[652] = "Prepare must be issued on the connection that started the branch. Transaction interleaving is not supported. prepare xid={0}, currentXid={1}";
    t[653] = "Prepare doit être envoyé sur la connection qui a démarré la branche. L''entrelacement de transactions n''est pas supporté. prepare xid={0}, currentXid={1}";
    t[660] = "One-phase commit must be issued on the connection that started the branch. commit xid={0}";
    t[661] = "Le commit à une phase doit être envoyé sur la connection qui a démarré la branche. commit xid={0}";
    t[664] = "The maximum field size must be a value greater than or equal to 0.";
    t[665] = "La taille maximum des champs doit être une valeur supérieure ou égale à 0.";
    t[666] = "Interval {0} not yet implemented";
    t[667] = "L''interval {0} n''est pas encore implémenté";
    t[668] = "Parameter of type {0} was registered, but call to get{1} (sqltype={2}) was made.";
    t[669] = "Un paramètre de type {0} a été enregistré, mais un appel à get{1} (sqltype={2}) a été fait.";
    t[672] = "Current connection does not have an associated xid. prepare xid={0}";
    t[673] = "La connection courante n''a pas de xid associé. prepare xid={0}";
    t[674] = "Cannot establish a savepoint in auto-commit mode.";
    t[675] = "Impossible d''établir un savepoint en mode auto-commit.";
    t[676] = "A result was returned when none was expected.";
    t[677] = "Un résultat a été retourné alors qu''aucun n''était attendu.";
    table = t;
  }
  public java.lang.Object handleGetObject (java.lang.String msgid) throws java.util.MissingResourceException {
    int hash_val = msgid.hashCode() & 0x7fffffff;
    int idx = (hash_val % 343) << 1;
    {
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
    int incr = ((hash_val % 341) + 1) << 1;
    for (;;) {
      idx += incr;
      if (idx >= 686)
        idx -= 686;
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
  }
  public java.util.Enumeration getKeys () {
    return
      new java.util.Enumeration() {
        private int idx = 0;
        { while (idx < 686 && table[idx] == null) idx += 2; }
        public boolean hasMoreElements () {
          return (idx < 686);
        }
        public java.lang.Object nextElement () {
          java.lang.Object key = table[idx];
          do idx += 2; while (idx < 686 && table[idx] == null);
          return key;
        }
      };
  }
  public java.util.ResourceBundle getParent () {
    return parent;
  }
}
