/* Automatically generated by GNU msgfmt.  Do not modify!  */
package org.postgresql.translation;
public class messages_sr extends java.util.ResourceBundle {
  private static final java.lang.String[] table;
  static {
    java.lang.String[] t = new java.lang.String[686];
    t[0] = "";
    t[1] = "Project-Id-Version: PostgreSQL 8.1\nReport-Msgid-Bugs-To: \nPO-Revision-Date: 2009-05-26 11:13+0100\nLast-Translator: Bojan Škaljac <skaljac (at) gmail.com>\nLanguage-Team: Srpski <skaljac@gmail.com>\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Serbian\nX-Poedit-Country: YUGOSLAVIA\n";
    t[2] = "Connection has been closed automatically because a new connection was opened for the same PooledConnection or the PooledConnection has been closed.";
    t[3] = "Konekcija je zatvorena automatski zato što je nova konekcija otvorena za isti PooledConnection ili je PooledConnection zatvoren.";
    t[10] = "Failed to create object for: {0}.";
    t[11] = "Propao pokušaj kreiranja objekta za: {0}.";
    t[16] = "Unsupported Types value: {0}";
    t[17] = "Za tip nije podržana vrednost: {0}";
    t[20] = "{0} function doesn''t take any argument.";
    t[21] = "Funkcija {0} nema parametara.";
    t[24] = "Currently positioned after the end of the ResultSet.  You cannot call deleteRow() here.";
    t[25] = "Trenutna pozicija posle kraja ResultSet-a.  Ne možete pozvati deleteRow() na toj poziciji.";
    t[28] = "end() called without a matching start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[29] = "end() pozvan bez odgovarajućeg start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[30] = "Connection attempt timed out.";
    t[31] = "Isteklo je vreme za pokušaj konektovanja.";
    t[32] = "Can''t infer the SQL type to use for an instance of {0}. Use setObject() with an explicit Types value to specify the type to use.";
    t[33] = "Nije moguće zaključiti SQL tip koji bi se koristio sa instancom {0}. Koristite setObject() sa zadatim eksplicitnim tipom vrednosti.";
    t[36] = "Connection is already associated with an active XA branch. End the current branch before starting a new one. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[37] = "Konekcija je već pridružena aktivnoj XA grani. Završite trenutnu granu pre pokretanja nove. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[38] = "Where: {0}";
    t[39] = "Gde: {0}";
    t[42] = "ResultSet not positioned properly, perhaps you need to call next.";
    t[43] = "ResultSet nije pravilno pozicioniran, možda je potrebno da pozovete next.";
    t[44] = "Error during one-phase commit. commit xid={0}";
    t[45] = "Kreška prilikom commit-a iz jedne faze. commit xid={0}";
    t[48] = "The server''s DateStyle parameter was changed to {0}. The JDBC driver requires DateStyle to begin with ISO for correct operation.";
    t[49] = "Serverov DataStyle parametar promenjen u {0}. JDBC zahteva da DateStyle počinje sa ISO za uspešno završavanje operacije.";
    t[58] = "Custom type maps are not supported.";
    t[59] = "Mape sa korisnički definisanim tipovima nisu podržane.";
    t[60] = "Error preparing transaction. prepare xid={0}";
    t[61] = "Greška u pripremanju transakcije. prepare xid={0}";
    t[62] = "commit() called before end(). commit xid={0}, state={1}";
    t[63] = "commit() pozvan pre end(). commit xid={0}, state={1}";
    t[72] = "No results were returned by the query.";
    t[73] = "Nikakav rezultat nije vraćen od strane upita.";
    t[76] = "Cannot tell if path is open or closed: {0}.";
    t[77] = "Nije moguće utvrditi dali je putanja otvorena ili zatvorena: {0}.";
    t[80] = "2nd phase commit cannot be issued while an XA branch is active on this connection. commit xid={0}, currentXid={1}, state={2}";
    t[81] = "Dvofazni commit ne može biti izdat dok je XA grana aktivna na ovoj konekciji. commit xid={0}, currentXid={1}, state={2}";
    t[82] = "Returning autogenerated keys by column index is not supported.";
    t[83] = "Vraćanje autogenerisanih ključeva po kloloni nije podržano.";
    t[88] = "The fastpath function {0} is unknown.";
    t[89] = "Fastpath funkcija {0} je nepoznata.";
    t[92] = "Cannot retrieve the id of a named savepoint.";
    t[93] = "Nije moguće primiti id imena tačke snimanja.";
    t[100] = "The column index is out of range: {0}, number of columns: {1}.";
    t[101] = "Indeks kolone van osega: {0}, broj kolona: {1}.";
    t[104] = "Protocol error.  Session setup failed.";
    t[105] = "Greška protokola.  Zakazivanje sesije propalo.";
    t[108] = "Suspend/resume not implemented";
    t[109] = "Obustavljanje/nastavljanje nije implementirano";
    t[110] = "Unable to find server array type for provided name {0}.";
    t[111] = "Neuspešno nalaženje liste servera za zadato ime {0}.";
    t[112] = "free() was called on this LOB previously";
    t[113] = "free() je pozvan na ovom LOB-u prethodno";
    t[114] = "Unknown XML Result class: {0}";
    t[115] = "nepoznata XML klasa rezultata: {0}";
    t[116] = "Unable to translate data into the desired encoding.";
    t[117] = "Nije moguće prevesti podatke u odabrani encoding format.";
    t[126] = "Prepare called before end(). prepare xid={0}, state={1}";
    t[127] = "Prepare pozvan pre end(). prepare xid={0}, state={1}";
    t[130] = "ResultSet is not updateable.  The query that generated this result set must select only one table, and must select all primary keys from that table. See the JDBC 2.1 API Specification, section 5.6 for more details.";
    t[131] = "ResultSet nije moguće ažurirati. Upit koji je generisao ovaj razultat mora selektoati jedino tabelu,i mora selektovati sve primrne ključeve iz te tabele. Pogledajte API specifikaciju za JDBC 2.1, sekciju 5.6 za više detalja.";
    t[136] = "Unable to create SAXResult for SQLXML.";
    t[137] = "Nije moguće kreirati SAXResult za SQLXML.";
    t[138] = "Cannot retrieve the name of an unnamed savepoint.";
    t[139] = "Nije moguće izvaditi ime tačke snimanja koja nema ime.";
    t[142] = "The array index is out of range: {0}, number of elements: {1}.";
    t[143] = "Indeks niza je van opsega: {0}, broj elemenata: {1}.";
    t[144] = "Cannot cast an instance of {0} to type {1}";
    t[145] = "Nije moguće kastovati instancu {0} u tip {1}";
    t[152] = "Error during recover. flag={0}";
    t[153] = "Greška prilikom oporavljanja. flag={0}";
    t[158] = "Bad value for type {0} : {1}";
    t[159] = "Pogrešna vrednost za tip {0} : {1}";
    t[160] = "An unexpected result was returned by a query.";
    t[161] = "Nepredviđen rezultat je vraćen od strane upita.";
    t[162] = "Expected command status BEGIN, got {0}.";
    t[163] = "Očekivan status komande je BEGIN, a dobijeno je {0}.";
    t[166] = "Unable to load the class {0} responsible for the datatype {1}";
    t[167] = "Nije moguće učitati kalsu {0} odgovornu za tip podataka {1}";
    t[168] = "Cannot change transaction isolation level in the middle of a transaction.";
    t[169] = "Nije moguće izmeniti nivo izolacije transakcije u sred izvršavanja transakcije.";
    t[174] = "The server''s standard_conforming_strings parameter was reported as {0}. The JDBC driver expected on or off.";
    t[175] = "Serverov standard_conforming_strings parametar javlja {0}. JDBC drajver ocekuje on ili off.";
    t[178] = "Invalid stream length {0}.";
    t[179] = "Nevažeća dužina toka {0}.";
    t[180] = "Unable to decode xml data.";
    t[181] = "Neuspešno dekodiranje XML podataka.";
    t[184] = "Results cannot be retrieved from a CallableStatement before it is executed.";
    t[185] = "Razultat nemože da se primi iz CallableStatement pre nego što se on izvrši.";
    t[186] = "This statement has been closed.";
    t[187] = "Statement je zatvoren.";
    t[188] = "Error loading default settings from driverconfig.properties";
    t[189] = "Greška u čitanju standardnih podešavanja iz driverconfig.properties";
    t[190] = "Invalid flags {0}";
    t[191] = "Nevažeće zastavice {0}";
    t[196] = "Failed to convert binary xml data to encoding: {0}.";
    t[197] = "Neuspešno konvertovanje binarnih XML podataka u kodnu stranu: {0}.";
    t[204] = "Conversion to type {0} failed: {1}.";
    t[205] = "Konverzija u tip {0} propala: {1}.";
    t[206] = "DataSource has been closed.";
    t[207] = "DataSource je zatvoren.";
    t[208] = "Connection has been closed.";
    t[209] = "Konekcija je već zatvorena.";
    t[210] = "A CallableStatement was executed with nothing returned.";
    t[211] = "CallableStatement je izvršen ali ništa nije vrećeno kao rezultat.";
    t[212] = "Your security policy has prevented the connection from being attempted.  You probably need to grant the connect java.net.SocketPermission to the database server host and port that you wish to connect to.";
    t[213] = "Sigurnosna podešavanja su sprečila konekciju. Verovatno je potrebno da dozvolite konekciju klasi java.net.SocketPermission na bazu na serveru.";
    t[218] = "Unexpected command status: {0}.";
    t[219] = "Neočekivan komandni status: {0}.";
    t[220] = "Cannot reference a savepoint after it has been released.";
    t[221] = "Nije moguće referenciranje tačke snimanja nakon njenog oslobađanja.";
    t[222] = "Error opening transaction. start xid={0}";
    t[223] = "Greška prilikom otvaranja transakcije. start xid={0}";
    t[228] = "The authentication type {0} is not supported. Check that you have configured the pg_hba.conf file to include the client''s IP address or subnet, and that it is using an authentication scheme supported by the driver.";
    t[229] = "Tip autentifikacije {0} nije podržan. Proverite dali imate podešen pg_hba.conf fajl koji uključuje klijentovu IP adresu ili podmrežu, i da ta mreža koristi šemu autentifikacije koja je podržana od strane ovog drajvera.";
    t[242] = "Internal Position: {0}";
    t[243] = "Interna pozicija: {0}";
    t[244] = "This statement does not declare an OUT parameter.  Use '{' ?= call ... '}' to declare one.";
    t[245] = "Izraz ne deklariše izlazni parametar. Koristite '{' ?= poziv ... '}' za deklarisanje.";
    t[256] = "Location: File: {0}, Routine: {1}, Line: {2}";
    t[257] = "Lokacija: Fajl: {0}, Rutina: {1}, Linija: {2}";
    t[258] = "Unknown type {0}.";
    t[259] = "Nepoznat tip {0}.";
    t[260] = "Ran out of memory retrieving query results.";
    t[261] = "Nestalo je memorije prilikom preuzimanja rezultata upita.";
    t[264] = "Zero bytes may not occur in string parameters.";
    t[265] = "Nula bajtovji se ne smeju pojavljivati u string parametrima.";
    t[266] = "{0} function takes four and only four argument.";
    t[267] = "Funkcija {0} prima četiri i samo četiri parametra.";
    t[268] = "Truncation of large objects is only implemented in 8.3 and later servers.";
    t[269] = "Skraćivanje velikih objekata je implementirano samo u 8.3 i novijim serverima.";
    t[270] = "Invalid character data was found.  This is most likely caused by stored data containing characters that are invalid for the character set the database was created in.  The most common example of this is storing 8bit data in a SQL_ASCII database.";
    t[271] = "Pronađeni su nevažeći karakter podaci. Uzrok je najverovatnije to što pohranjeni podaci sadrže karaktere koji su nevažeći u setu karaktera sa kojima je baza kreirana.  Npr. Čuvanje 8bit podataka u SQL_ASCII bazi podataka.";
    t[278] = "This PooledConnection has already been closed.";
    t[279] = "PooledConnection je već zatvoren.";
    t[280] = "Cannot call cancelRowUpdates() when on the insert row.";
    t[281] = "Nije moguće pozvati cancelRowUpdates() prilikom ubacivanja redova.";
    t[284] = "Cannot rollback prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. rollback xid={0}, transactionState={1}";
    t[285] = "Nije moguće poništiti pripremljenu transakciju dok je lokalna transakcija u toku na ovoj konekciji. Prvo izvršite commit ili rollback lokalne transakcije. rollback xid={0}, transactionState={1}";
    t[288] = "PostgreSQL LOBs can only index to: {0}";
    t[289] = "PostgreSQL LOB mogu jedino da označavaju: {0}";
    t[290] = "Provided InputStream failed.";
    t[291] = "Pribaljeni InputStream zakazao.";
    t[298] = "Unexpected error writing large object to database.";
    t[299] = "Neočekivana greška prilikom upisa velikog objekta u bazu podataka.";
    t[300] = "Fetch size must be a value greater than or equal to 0.";
    t[301] = "Doneta veličina mora biti vrednost veća ili jednaka 0.";
    t[310] = "Invalid protocol state requested. Attempted transaction interleaving is not supported. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[311] = "Preplitanje transakcija nije implementirano. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[312] = "Transaction was already prepared on this connection. prepare xid={0}, preparedXid={1}";
    t[313] = "Transakcija je već pripremljena na ovoj konekciji. prepare xid={0}, preparedXid={1}";
    t[314] = "The parameter index is out of range: {0}, number of parameters: {1}.";
    t[315] = "Index parametra je van opsega: {0}, broj parametara je: {1}.";
    t[316] = "Not on the insert row.";
    t[317] = "Nije mod ubacivanja redova.";
    t[320] = "{0} function takes two and only two arguments.";
    t[321] = "Funkcija {0} prima dva i samo dva parametra.";
    t[322] = "Cannot change transaction read-only property in the middle of a transaction.";
    t[323] = "Nije moguće izmeniti read-only osobinu transakcije u sred izvršavanja transakcije.";
    t[330] = "Unsupported value for stringtype parameter: {0}";
    t[331] = "Vrednost za parametar tipa string nije podržana: {0}";
    t[332] = "Unknown Response Type {0}.";
    t[333] = "Nepoznat tip odziva {0}.";
    t[334] = "This SQLXML object has not been initialized, so you cannot retrieve data from it.";
    t[335] = "SQLXML objekat nije inicijalizovan tako da nije moguće preuzimati podatke iz njega.";
    t[336] = "An error occurred while setting up the SSL connection.";
    t[337] = "Greška se dogodila prilikom podešavanja SSL konekcije.";
    t[344] = "Invalid UUID data.";
    t[345] = "Nevažeća UUID podatak.";
    t[354] = "Zero bytes may not occur in identifiers.";
    t[355] = "Nula bajtovji se ne smeju pojavljivati u identifikatorima.";
    t[360] = "A connection could not be made using the requested protocol {0}.";
    t[361] = "Konekciju nije moguće kreirati uz pomoć protokola {0}.";
    t[362] = "You must specify at least one column value to insert a row.";
    t[363] = "Morate specificirati barem jednu vrednost za kolonu da bi ste ubacili red.";
    t[364] = "Method {0} is not yet implemented.";
    t[365] = "Metod {0} nije još impelemtiran.";
    t[368] = "Unknown ResultSet holdability setting: {0}.";
    t[369] = "Nepoznata ResultSet podešavanja za mogućnost držanja (holdability): {0}.";
    t[374] = "Cannot 2nd phase commit prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. commit xid={0}, transactionState={1}";
    t[375] = "Nije moguće izvršiti dvofazni commit pripremljene transakcije dok je lokalna transakcija u toku na ovoj konekciji. Prvo izvršite commit ili rollback lokalne transakcije. commit xid={0}, transactionState={1}";
    t[376] = "wasNull cannot be call before fetching a result.";
    t[377] = "wasNull nemože biti pozvan pre zahvatanja rezultata.";
    t[378] = "Returning autogenerated keys is not supported.";
    t[379] = "Vraćanje autogenerisanih ključeva nije podržano.";
    t[380] = "Cannot update the ResultSet because it is either before the start or after the end of the results.";
    t[381] = "Nije moguće ažurirati ResultSet zato što je ili početak ili kraj rezultata.";
    t[384] = "Unable to bind parameter values for statement.";
    t[385] = "Nije moguće naći vrednost vezivnog parametra za izjavu (statement).";
    t[390] = "Unable to create StAXResult for SQLXML";
    t[391] = "Nije moguće kreirati StAXResult za SQLXML";
    t[394] = "Unknown XML Source class: {0}";
    t[395] = "Nepoznata XML ulazna klasa: {0}";
    t[396] = "LOB positioning offsets start at 1.";
    t[397] = "LOB pozicija ofset počinje kod 1.";
    t[402] = "This SQLXML object has already been initialized, so you cannot manipulate it further.";
    t[403] = "SQLXML objekat je već inicijalizovan, tako da ga nije moguće dodatno menjati.";
    t[404] = "Transaction isolation level {0} not supported.";
    t[405] = "Nivo izolacije transakcije {0} nije podržan.";
    t[406] = "{0} function takes two or three arguments.";
    t[407] = "Funkcija {0} prima dva ili tri parametra.";
    t[412] = "Conversion of interval failed";
    t[413] = "Konverzija intervala propala.";
    t[414] = "A CallableStatement function was executed and the out parameter {0} was of type {1} however type {2} was registered.";
    t[415] = "CallableStatement funkcija je izvršena dok je izlazni parametar {0} tipa {1} a tip {2} je registrovan kao izlazni parametar.";
    t[416] = "Transaction control methods setAutoCommit, commit, rollback and setSavepoint are not allowed while an XA transaction is active.";
    t[417] = "Metode za kontrolu transakcije setAutoCommit, commit, rollback i setSavepoint nisu dozvoljene dok je XA transakcija aktivna.";
    t[422] = "Statement has been closed.";
    t[423] = "Statemen je već zatvoren.";
    t[424] = "Fastpath call {0} - No result was returned and we expected an integer.";
    t[425] = "Fastpath poziv {0} - Nikakav rezultat nije vraćen a očekivan je integer.";
    t[428] = "Something unusual has occurred to cause the driver to fail. Please report this exception.";
    t[429] = "Nešto neobično se dogodilo i drajver je zakazao. Molim prijavite ovaj izuzetak.";
    t[430] = "This ResultSet is closed.";
    t[431] = "ResultSet je zatvoren.";
    t[432] = "Unknown Types value.";
    t[433] = "Nepoznata vrednost za Types.";
    t[434] = "Operation requires a scrollable ResultSet, but this ResultSet is FORWARD_ONLY.";
    t[435] = "Operacija zahteva skrolabilan ResultSet,ali ovaj ResultSet je FORWARD_ONLY.";
    t[450] = "No function outputs were registered.";
    t[451] = "Nije registrovan nikakv izlaz iz funkcije.";
    t[454] = "Conversion of money failed.";
    t[455] = "Konverzija novca (money) propala.";
    t[460] = "xid must not be null";
    t[461] = "xid ne sme biti null";
    t[462] = "The SSLSocketFactory class provided {0} could not be instantiated.";
    t[463] = "SSLSocketFactory klasa koju pruža {0} se nemože instancirati.";
    t[466] = "Large Objects may not be used in auto-commit mode.";
    t[467] = "Veliki objekti (Large Object) se nemogu koristiti u auto-commit modu.";
    t[468] = "{0} function takes one and only one argument.";
    t[469] = "Funkcija {0} prima jedan i samo jedan parametar.";
    t[470] = "Unable to convert DOMResult SQLXML data to a string.";
    t[471] = "Nije moguće konvertovati DOMResult SQLXML podatke u string.";
    t[474] = "Cannot call updateRow() when on the insert row.";
    t[475] = "Nije moguće pozvati updateRow() prilikom ubacivanja redova.";
    t[478] = "Can''t use relative move methods while on the insert row.";
    t[479] = "Ne može se koristiti metod relativnog pomeranja prilikom ubacivanja redova.";
    t[482] = "ResultSets with concurrency CONCUR_READ_ONLY cannot be updated.";
    t[483] = "ResultSets sa osobinom CONCUR_READ_ONLY ne moeže biti ažuriran.";
    t[484] = "Unable to find name datatype in the system catalogs.";
    t[485] = "Nije moguće pronaći ime tipa podatka u sistemskom katalogu.";
    t[486] = "Bind message length {0} too long.  This can be caused by very large or incorrect length specifications on InputStream parameters.";
    t[487] = "Dužina vezivne poruke {0} prevelika.  Ovo je možda rezultat veoma velike ili pogrešne dužine specifikacije za InputStream parametre.";
    t[488] = "Can''t use query methods that take a query string on a PreparedStatement.";
    t[489] = "Ne možete da koristite metode za upit koji uzimaju string iz upita u PreparedStatement-u.";
    t[490] = "A CallableStatement was executed with an invalid number of parameters";
    t[491] = "CallableStatement je izvršen sa nevažećim brojem parametara";
    t[500] = "Cannot call deleteRow() when on the insert row.";
    t[501] = "Nije moguće pozvati deleteRow() prilikom ubacivanja redova.";
    t[502] = "A CallableStatement was declared, but no call to registerOutParameter(1, <some type>) was made.";
    t[503] = "CallableStatement jedeklarisan ali nije bilo poziva registerOutParameter (1, <neki_tip>).";
    t[508] = "Currently positioned before the start of the ResultSet.  You cannot call deleteRow() here.";
    t[509] = "Trenutna pozicija pre početka ResultSet-a.  Ne možete pozvati deleteRow() na toj poziciji.";
    t[510] = "{0} function takes three and only three arguments.";
    t[511] = "Funkcija {0} prima tri i samo tri parametra.";
    t[518] = "Query timeout must be a value greater than or equals to 0.";
    t[519] = "Tajm-aut mora biti vrednost veća ili jednaka 0.";
    t[520] = "There are no rows in this ResultSet.";
    t[521] = "U ResultSet-u nema redova.";
    t[524] = "Heuristic commit/rollback not supported. forget xid={0}";
    t[525] = "Heuristički commit/rollback nije podržan. forget xid={0}";
    t[528] = "Provided Reader failed.";
    t[529] = "Pribavljeni čitač (Reader) zakazao.";
    t[530] = "Internal Query: {0}";
    t[531] = "Interni upit: {0}";
    t[532] = "The JVM claims not to support the {0} encoding.";
    t[533] = "JVM tvrdi da ne podržava {0} encoding.";
    t[544] = "The column name {0} was not found in this ResultSet.";
    t[545] = "Ime kolone {0} nije pronadjeno u ResultSet.";
    t[546] = "Error rolling back transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[547] = "Greška prilikom poništavanja transakcije. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[560] = "No value specified for parameter {0}.";
    t[561] = "Nije zadata vrednost za parametar {0}.";
    t[562] = "Can''t refresh the insert row.";
    t[563] = "Nije moguće osvežiti ubačeni red.";
    t[566] = "The array index is out of range: {0}";
    t[567] = "Indeks niza je van opsega: {0}";
    t[568] = "ClientInfo property not supported.";
    t[569] = "ClientInfo property nije podržan.";
    t[570] = "Malformed function or procedure escape syntax at offset {0}.";
    t[571] = "Pogrešna sintaksa u funkciji ili proceduri na poziciji {0}.";
    t[578] = "Error committing prepared transaction. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[579] = "Greška prilikom potvrđivanja pripremljene transakcije. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[586] = "This SQLXML object has already been freed.";
    t[587] = "Ovaj SQLXML je već obrisan.";
    t[590] = "One-phase commit called for xid {0} but connection was prepared with xid {1}";
    t[591] = "One-phase commit pozvan za xid {0}, ali konekcija je pripremljena sa xid {1}";
    t[602] = "One-phase commit with unknown xid. commit xid={0}, currentXid={1}";
    t[603] = "One-phase commit sa nepoznatim xid. commit xid={0}, currentXid={1}";
    t[606] = "Position: {0}";
    t[607] = "Pozicija: {0}";
    t[612] = "Detail: {0}";
    t[613] = "Detalji: {0}";
    t[616] = "The JVM claims not to support the encoding: {0}";
    t[617] = "JVM tvrdi da ne podržava encoding: {0}";
    t[618] = "Unable to determine a value for MaxIndexKeys due to missing system catalog data.";
    t[619] = "Nije moguće odrediti vrednost za MaxIndexKezs zbog nedostatka podataka u sistemskom katalogu.";
    t[620] = "Invalid fetch direction constant: {0}.";
    t[621] = "Pogrešna konstanta za direkciju donošenja: {0}.";
    t[622] = "Multiple ResultSets were returned by the query.";
    t[623] = "Višestruki ResultSet-vi su vraćeni od strane upita.";
    t[626] = "The server does not support SSL.";
    t[627] = "Server ne podržava SSL.";
    t[630] = "Server SQLState: {0}";
    t[631] = "SQLState servera: {0}";
    t[632] = "Premature end of input stream, expected {0} bytes, but only read {1}.";
    t[633] = "Prevremen završetak ulaznog toka podataka,očekivano {0} bajtova, a pročitano samo {1}.";
    t[636] = "Expected an EOF from server, got: {0}";
    t[637] = "Očekivan EOF od servera, a dobijeno: {0}";
    t[638] = "Hint: {0}";
    t[639] = "Nagovest: {0}";
    t[640] = "Interrupted while attempting to connect.";
    t[641] = "Prekinut pokušaj konektovanja.";
    t[642] = "The connection attempt failed.";
    t[643] = "Pokušaj konektovanja propao.";
    t[644] = "Too many update results were returned.";
    t[645] = "Previše rezultata za ažuriranje je vraćeno.";
    t[650] = "Cannot convert an instance of {0} to type {1}";
    t[651] = "Nije moguće konvertovati instancu {0} u tip {1}";
    t[652] = "Prepare must be issued on the connection that started the branch. Transaction interleaving is not supported. prepare xid={0}, currentXid={1}";
    t[653] = "Prepare mora biti pozvan na konekciji koja je pokrenula granu. Preplitanje transakcija nije podržano. prepare xid={0}, currentXid={1}";
    t[660] = "One-phase commit must be issued on the connection that started the branch. commit xid={0}";
    t[661] = "One-phase commit mora biti izdat na konekciji koja je pokrenula granu. commit xid={0}";
    t[664] = "The maximum field size must be a value greater than or equal to 0.";
    t[665] = "Maksimalna vrednost veličine polja mora biti vrednost veća ili jednaka 0.";
    t[666] = "Interval {0} not yet implemented";
    t[667] = "Interval {0} još nije implementiran.";
    t[668] = "Parameter of type {0} was registered, but call to get{1} (sqltype={2}) was made.";
    t[669] = "Parametar tipa {0} je registrovan,ali poziv za get{1} (sql tip={2}) je izvršen.";
    t[672] = "Current connection does not have an associated xid. prepare xid={0}";
    t[673] = "Trenutna konekcija nema pridružen xid. prepare xid={0}";
    t[674] = "Cannot establish a savepoint in auto-commit mode.";
    t[675] = "U auto-commit modu nije moguće podešavanje tački snimanja.";
    t[676] = "A result was returned when none was expected.";
    t[677] = "Rezultat vraćen ali nikakav rezultat nije očekivan.";
    table = t;
  }
  public java.lang.Object handleGetObject (java.lang.String msgid) throws java.util.MissingResourceException {
    int hash_val = msgid.hashCode() & 0x7fffffff;
    int idx = (hash_val % 343) << 1;
    {
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
    int incr = ((hash_val % 341) + 1) << 1;
    for (;;) {
      idx += incr;
      if (idx >= 686)
        idx -= 686;
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
  }
  public java.util.Enumeration getKeys () {
    return
      new java.util.Enumeration() {
        private int idx = 0;
        { while (idx < 686 && table[idx] == null) idx += 2; }
        public boolean hasMoreElements () {
          return (idx < 686);
        }
        public java.lang.Object nextElement () {
          java.lang.Object key = table[idx];
          do idx += 2; while (idx < 686 && table[idx] == null);
          return key;
        }
      };
  }
  public java.util.ResourceBundle getParent () {
    return parent;
  }
}
