/* Automatically generated by GNU msgfmt.  Do not modify!  */
package org.postgresql.translation;
public class messages_bg extends java.util.ResourceBundle {
  private static final java.lang.String[] table;
  static {
    java.lang.String[] t = new java.lang.String[866];
    t[0] = "";
    t[1] = "Project-Id-Version: JDBC Driver for PostgreSQL 8.x\nReport-Msgid-Bugs-To: \nPO-Revision-Date: 2009-12-28 00:01+0100\nLast-Translator: <usun0v@mail.bg>\nLanguage-Team: <bg@li.org>\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Bulgarian\nX-Poedit-Country: BULGARIA\n";
    t[4] = "Unknown Response Type {0}.";
    t[5] = "Неизвестен тип на отговор {0}.";
    t[6] = "Tried to read from inactive copy";
    t[7] = "Опит за четене при неактивно копиране";
    t[8] = "Interrupted while attempting to connect.";
    t[9] = "Опита за осъществяване на връзка бе своевременно прекъснат. ";
    t[12] = "The SSLSocketFactory class provided {0} could not be instantiated.";
    t[13] = "Класът SSLSocketFactory връща {0} и не може да бъде инстанцииран.";
    t[16] = "Read from copy failed.";
    t[17] = "Четене от копието неуспешно.";
    t[18] = "Unknown type {0}.";
    t[19] = "Неизвестен тип {0}.";
    t[20] = "Missing expected error response to copy cancel request";
    t[21] = "Липсва очакван отговор при грешка да прекъсне копирането";
    t[26] = "Zero bytes may not occur in identifiers.";
    t[27] = "Не може да има нула байта в идентификаторите.";
    t[30] = "{0} function doesn''t take any argument.";
    t[31] = "Функцията {0} не може да приема аргументи.";
    t[32] = "Fastpath call {0} - No result was returned and we expected an integer.";
    t[33] = "Извикване на {0} - няма резултати и а бе очаквано цяло число.";
    t[34] = "ResultSet is not updateable.  The query that generated this result set must select only one table, and must select all primary keys from that table. See the JDBC 2.1 API Specification, section 5.6 for more details.";
    t[35] = "ResultSet не може да се обновява. Заявката генерираща този резултат трябва да селектира само една таблица, както и всички първични ключове в нея. За повече информация, вижте раздел 5.6 на JDBC 2.1 API Specification.";
    t[36] = "An error occurred while setting up the SSL connection.";
    t[37] = "Възникна грешка при осъществяване на SSL връзката.";
    t[42] = "Database connection failed when reading from copy";
    t[43] = "Неосъществена връзка към базата данни при четене от копие";
    t[44] = "Currently positioned before the start of the ResultSet.  You cannot call deleteRow() here.";
    t[45] = "В момента се намираме в началото на ResultSet. Тук не може да се изпълни deleteRow() метода.";
    t[46] = "Returning autogenerated keys is not supported.";
    t[47] = "Автоматично генерирани ключове не се поддържат.";
    t[50] = "The authentication type {0} is not supported. Check that you have configured the pg_hba.conf file to include the client''s IP address or subnet, and that it is using an authentication scheme supported by the driver.";
    t[51] = "Тип на удостоверяване {0} не се поддържа. Проверете дали сте конфигурирали pg_hba.conf файла, да включва IP адреса на клиента или подмрежата, и че се използва схема за удостоверяване, поддържана от драйвъра.";
    t[56] = "{0} function takes two and only two arguments.";
    t[57] = "Функцията {0} може да приеме два и само два аргумента.";
    t[64] = "Unable to find server array type for provided name {0}.";
    t[65] = "Не може да се намери типа на сървърен масив за зададеното име {0}.";
    t[66] = "Error preparing transaction. prepare xid={0}";
    t[67] = "Грешка при подготвяне на транзакция. prepare xid={0}";
    t[68] = "The maximum field size must be a value greater than or equal to 0.";
    t[69] = "Максималният размер на полето трябва да бъде стойност по-голяма или равна на 0.";
    t[72] = "Unable to create SAXResult for SQLXML.";
    t[73] = "Не може да се създаде SAXResult за SQLXML.";
    t[76] = "Tried to obtain lock while already holding it";
    t[77] = "Опит за получаване на заключване/резервация докато вече е получено";
    t[80] = "Something unusual has occurred to cause the driver to fail. Please report this exception.";
    t[81] = "Възникна неочаквана грешка с драйвъра. Моля докадвайте това изключение. ";
    t[88] = "No results were returned by the query.";
    t[89] = "Няма намерени резултати за заявката.";
    t[90] = "Database connection failed when canceling copy operation";
    t[91] = "Неосъществена връзка към базата данни при прекъсване на копирането";
    t[94] = "Operation requires a scrollable ResultSet, but this ResultSet is FORWARD_ONLY.";
    t[95] = "Операцията изисква резултатите да са scrollable, но този ResultSet е FORWARD_ONLY.";
    t[98] = "Invalid stream length {0}.";
    t[99] = "Невалидна дължина {0} на потока данни.";
    t[106] = "This copy stream is closed.";
    t[107] = "Потока за копиране на данните е затворен.";
    t[108] = "The column index is out of range: {0}, number of columns: {1}.";
    t[109] = "Индексът на колоната е извън стойностен обхват: {0}, брой колони: {1}.";
    t[114] = "This SQLXML object has not been initialized, so you cannot retrieve data from it.";
    t[115] = "Този SQLXML обект не е инициализиран, така че не могат да се извличат данни от него.";
    t[116] = "Premature end of input stream, expected {0} bytes, but only read {1}.";
    t[117] = "Преждевременен край на входящ поток на данни, очаквани {0} байта, но прочетени само {1}.";
    t[118] = "Your security policy has prevented the connection from being attempted.  You probably need to grant the connect java.net.SocketPermission to the database server host and port that you wish to connect to.";
    t[119] = "Връзката не бе осъществена, поради вашите настройки за сигурност. Може би трябва да предоставите java.net.SocketPermission права на сървъра и порта с базата данни, към който искате да се свържете.";
    t[122] = "Copying from database failed: {0}";
    t[123] = "Копирането от базата данни бе неуспешно: {0}";
    t[130] = "The server does not support SSL.";
    t[131] = "Сървърът не поддържа SSL.";
    t[132] = "Not on the insert row.";
    t[133] = "Не сме в редицата на въвеждане.";
    t[140] = "Unexpected command status: {0}.";
    t[141] = "Неочакван статус на команда: {0}.";
    t[142] = "A connection could not be made using the requested protocol {0}.";
    t[143] = "Не може да осъществи връзка, ползвайки искания протокол {0}.";
    t[148] = "Provided Reader failed.";
    t[149] = "Грешка с ползвания четец.";
    t[150] = "Error during recover. flag={0}";
    t[151] = "Грешка при възстановяване. flag={0}";
    t[152] = "Heuristic commit/rollback not supported. forget xid={0}";
    t[153] = "Евристичен commit или rollback не се поддържа. forget xid={0}";
    t[156] = "Interrupted while waiting to obtain lock on database connection";
    t[157] = "Прекъсване при чакане да получи заключване/резервация при връзка към базата данни";
    t[160] = "Invalid protocol state requested. Attempted transaction interleaving is not supported. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[161] = "Транзакция в транзакция не се поддържа за момента. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[162] = "Cannot update the ResultSet because it is either before the start or after the end of the results.";
    t[163] = "Не може да се обнови ResultSet, когато се намираме преди началото или след края на резултатите.";
    t[166] = "Invalid UUID data.";
    t[167] = "Невалидни UUID данни.";
    t[168] = "wasNull cannot be call before fetching a result.";
    t[169] = "wasNull не може да бьде изпълнен, преди наличието на резултата.";
    t[170] = "Cannot call cancelRowUpdates() when on the insert row.";
    t[171] = "Не може да се изпълни cancelRowUpdates() метода, когато се намираме при редицата на въвеждане.";
    t[174] = "Cannot rollback prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. rollback xid={0}, transactionState={1}";
    t[175] = "Не може да се направи rollback на подготвена транзакция, докато на тази връзка тече локална транзакция. Първо направете commit или rollback на локалната транзакция. rollback xid={0}, transactionState={1}";
    t[184] = "Can''t refresh the insert row.";
    t[185] = "Не може да обнови въведения ред.";
    t[186] = "This SQLXML object has already been freed.";
    t[187] = "Този SQLXML обект вече е освободен.";
    t[188] = "Prepare must be issued on the connection that started the branch. Transaction interleaving is not supported. prepare xid={0}, currentXid={1}";
    t[189] = "Prepare трябва да бъде издаден на връзката, на която е започнат клонът. Транзакция в транзакция не се поддържа. prepare xid={0}, currentXid={1}";
    t[198] = "One-phase commit with unknown xid. commit xid={0}, currentXid={1}";
    t[199] = "Едно-фазов commit с непознат xid. commit xid={0}, currentXid={1}";
    t[202] = "The column name {0} was not found in this ResultSet.";
    t[203] = "Името на колоната {0} не бе намерено в този ResultSet.";
    t[208] = "Database connection failed when starting copy";
    t[209] = "Неосъществена връзка към базата данни при започване на копирането";
    t[210] = "Invalid flags {0}";
    t[211] = "Невалидни флагове {0}";
    t[214] = "Can''t use query methods that take a query string on a PreparedStatement.";
    t[215] = "Не може да се употребяват методи за заявка, които ползват низове на PreparedStatement.";
    t[216] = "CommandComplete expected COPY but got: {0}";
    t[217] = "Очаквано командно допълнение COPY но получено: {0}";
    t[226] = "{0} function takes two or three arguments.";
    t[227] = "Функцията {0} може да приеме два или три аргумента.";
    t[228] = "Conversion of interval failed";
    t[229] = "Неуспешно преобразуване на интервал";
    t[242] = "Bind message length {0} too long.  This can be caused by very large or incorrect length specifications on InputStream parameters.";
    t[243] = "Прекалено голяма дължина {0} на съобщението. Това може да е причинено от прекалено голяма или неправилно зададена дължина на InputStream параметри.";
    t[254] = "The JVM claims not to support the encoding: {0}";
    t[255] = "JVM не поддържа тази кодова таблица за момента: {0}";
    t[256] = "Unable to bind parameter values for statement.";
    t[257] = "Не може да подготви параметрите на командата.";
    t[260] = "Ran out of memory retrieving query results.";
    t[261] = "Недостатъчна памет при представяна на резултатите от заявката.";
    t[262] = "Tried to write to an inactive copy operation";
    t[263] = "Опит за писане при неактивна операция за копиране";
    t[264] = "Tried to end inactive copy";
    t[265] = "Опит за прекъсване на неактивно копиране";
    t[268] = "This PooledConnection has already been closed.";
    t[269] = "Тази PooledConnection връзка бе вече прекъсната.";
    t[272] = "Detail: {0}";
    t[273] = "Подробност: {0}";
    t[276] = "ClientInfo property not supported.";
    t[277] = "Информацията за ClientInfo не се поддържа.";
    t[288] = "Cannot reference a savepoint after it has been released.";
    t[289] = "Не може да референцира savepoint, след като е била освободена.";
    t[292] = "Failed to create object for: {0}.";
    t[293] = "Неуспешно създаване на обект за: {0}.";
    t[298] = "Protocol error.  Session setup failed.";
    t[299] = "Грешка в протокола. Неуспешна настройка на сесията.";
    t[302] = "Position: {0}";
    t[303] = "Позиция: {0}";
    t[304] = "Cannot 2nd phase commit prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. commit xid={0}, transactionState={1}";
    t[305] = "Втората фаза на commit на подготвена транзакция не може да бъде издадена, докато на тази връзка тече локална транзакция. Първо направете commit или rollback на локалната транзакция. commit xid={0}, transactionState={1}";
    t[310] = "Unknown ResultSet holdability setting: {0}.";
    t[311] = "Неизвестна ResultSet holdability настройка: {0}.";
    t[318] = "Conversion of money failed.";
    t[319] = "Неуспешно валутно преобразуване.";
    t[320] = "Where: {0}";
    t[321] = "Където: {0}";
    t[324] = "Connection is already associated with an active XA branch. End the current branch before starting a new one. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[325] = "Връзката вече е свързана с активен XA клон. Завършете текущия клон, преди да започнете нов. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[330] = "Suspend/resume not implemented";
    t[331] = "спиране / започване не се поддържа за момента";
    t[334] = "Bad value for type {0} : {1}";
    t[335] = "Невалидна стойност за тип {0} : {1}";
    t[338] = "ResultSets with concurrency CONCUR_READ_ONLY cannot be updated.";
    t[339] = "ResultSets с concurrency CONCUR_READ_ONLY не могат да бъдат актуализирани.";
    t[340] = "Cannot change transaction isolation level in the middle of a transaction.";
    t[341] = "Не може да променяте изолационното ниво на транзакцията по време на нейното извършване.";
    t[346] = "This SQLXML object has already been initialized, so you cannot manipulate it further.";
    t[347] = "Този SQLXML обект вече е инициализиран и не може да бъде променен.";
    t[348] = "Unable to create StAXResult for SQLXML";
    t[349] = "Не може да се създаде StAXResult за SQLXML.";
    t[356] = "Can''t use relative move methods while on the insert row.";
    t[357] = "Не може да се използват относителни методи за движение, когато се намираме при редицата на въвеждане.";
    t[360] = "Invalid fetch direction constant: {0}.";
    t[361] = "Невалидна константа за fetch посоката: {0}.";
    t[368] = "Requested CopyIn but got {0}";
    t[369] = "Зададено CopyIn но получено {0}";
    t[370] = "Unable to find name datatype in the system catalogs.";
    t[371] = "Не може да се намери името на типа данни в системните каталози.";
    t[374] = "Expected command status BEGIN, got {0}.";
    t[375] = "Очаквана команда BEGIN, получена {0}.";
    t[376] = "The JVM claims not to support the {0} encoding.";
    t[377] = "JVM не поддържа за момента {0} кодовата таблица.";
    t[378] = "Error opening transaction. start xid={0}";
    t[379] = "Грешка при отваряне на транзакция. start xid={0}";
    t[380] = "The fastpath function {0} is unknown.";
    t[381] = "Функцията {0} е неизвестна.";
    t[382] = "The connection attempt failed.";
    t[383] = "Опита за връзка бе неуспешен.";
    t[384] = "Fetch size must be a value greater than or equal to 0.";
    t[385] = "Размера за fetch size трябва да бъде по-голям или равен на 0.";
    t[386] = "Server SQLState: {0}";
    t[387] = "SQL статус на сървъра: {0}";
    t[394] = "The server''s standard_conforming_strings parameter was reported as {0}. The JDBC driver expected on or off.";
    t[395] = "Параметърът standard_conforming_strings при сървъра бе докладван като {0}. JDBC драйвъра очаква този параметър да бъде on или off.";
    t[398] = "Error rolling back transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[399] = "Грешка при възстановяване на състоянието на транзакция. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[402] = "Unknown Types value.";
    t[403] = "Стойност от неизвестен тип.";
    t[408] = "Internal Query: {0}";
    t[409] = "Вътрешна заявка: {0}";
    t[410] = "Results cannot be retrieved from a CallableStatement before it is executed.";
    t[411] = "Резултати от CallableStatement функция не могат да бъдат получени, преди тя да бъде обработена.";
    t[416] = "Connection has been closed.";
    t[417] = "Връзката бе прекъсната.";
    t[420] = "Malformed function or procedure escape syntax at offset {0}.";
    t[421] = "Непозволен синтаксис на функция или процедура при офсет {0}.";
    t[432] = "One-phase commit called for xid {0} but connection was prepared with xid {1}";
    t[433] = "Едно-фазов commit е извикан за xid {0}, но връзката е подготвена с xid {1}";
    t[434] = "Invalid character data was found.  This is most likely caused by stored data containing characters that are invalid for the character set the database was created in.  The most common example of this is storing 8bit data in a SQL_ASCII database.";
    t[435] = "Бяха намерени невалидни данни. Това най-вероятно се дължи на съхранявани данни, съдържащи символи, които са невалидни за набора от знаци при създаване на базата данни. Чест пример за това е съхраняване на 8bit данни в SQL_ASCII бази данни.";
    t[436] = "One-phase commit must be issued on the connection that started the branch. commit xid={0}";
    t[437] = "Едно-фазов commit трябва да бъде издаден на връзката, на която е започнат клонът. commit xid={0}";
    t[450] = "Unable to determine a value for MaxIndexKeys due to missing system catalog data.";
    t[451] = "Невъзможно е да се определи стойността за MaxIndexKeys поради липса на системния каталог с данни.";
    t[452] = "A CallableStatement was executed with nothing returned.";
    t[453] = "CallableStatement функция бе обработена, но няма резултати.";
    t[454] = "You must specify at least one column value to insert a row.";
    t[455] = "Трябва да посочите поне една стойност за колона, за да вмъкнете ред.";
    t[458] = "Unexpected copydata from server for {0}";
    t[459] = "Неочаквано CopyData от сървъра за {0}";
    t[464] = "Transaction control methods setAutoCommit, commit, rollback and setSavepoint are not allowed while an XA transaction is active.";
    t[465] = "Методите за управление на транзакции setAutoCommit, commit, rollback и setSavepoint не са разрешени, докато XA транзакция е активна.";
    t[466] = "Cannot retrieve the id of a named savepoint.";
    t[467] = "Не може да определи ID на спомената savepoint.";
    t[468] = "Unsupported Types value: {0}";
    t[469] = "Неподдържана стойност за тип: {0}";
    t[472] = "LOB positioning offsets start at 1.";
    t[473] = "Позиционалният офсет при големи обекти LOB започва от 1.";
    t[480] = "No value specified for parameter {0}.";
    t[481] = "Няма стойност, определена за параметър {0}.";
    t[482] = "PostgreSQL LOBs can only index to: {0}";
    t[483] = "PostgreSQL индексира големи обекти LOB само до: {0}";
    t[492] = "Statement has been closed.";
    t[493] = "Командата е завършена.";
    t[494] = "The array index is out of range: {0}";
    t[495] = "Индексът на масив е извън обхвата: {0}";
    t[500] = "Unexpected packet type during copy: {0}";
    t[501] = "Неочакван тип пакет при копиране: {0}";
    t[510] = "Cannot convert an instance of {0} to type {1}";
    t[511] = "Не може да преобразува инстанцията на {0} във вида {1}";
    t[516] = "A CallableStatement was declared, but no call to registerOutParameter(1, <some type>) was made.";
    t[517] = "CallableStatement функция бе декларирана, но обработена като registerOutParameter(1, <some type>) ";
    t[520] = "A result was returned when none was expected.";
    t[521] = "Бе получен резултат, когато такъв не бе очакван.";
    t[522] = "xid must not be null";
    t[523] = "xid не може да бъде null";
    t[526] = "Tried to break lock on database connection";
    t[527] = "Опит за премахване на заключването/резервацията при връзка към базата данни";
    t[536] = "Provided InputStream failed.";
    t[537] = "Зададения InputStream поток е неуспешен.";
    t[538] = "Conversion to type {0} failed: {1}.";
    t[539] = "Неуспешно преобразуване към тип {0}: {1}.";
    t[542] = "Method {0} is not yet implemented.";
    t[543] = "Методът {0} все още не е функционален.";
    t[548] = "A CallableStatement function was executed and the out parameter {0} was of type {1} however type {2} was registered.";
    t[549] = "CallableStatement функция бе обработена и изходния параметър {0} бе от тип {1}, обаче тип {2} бе използван.";
    t[554] = "Unsupported value for stringtype parameter: {0}";
    t[555] = "Непозволена стойност за StringType параметър: {0}";
    t[558] = "Internal Position: {0}";
    t[559] = "Вътрешна позиция: {0}";
    t[560] = "Unable to load the class {0} responsible for the datatype {1}";
    t[561] = "Невъзможно е зареждането на клас {0}, отговарящ за типа данни {1}";
    t[564] = "Unable to convert DOMResult SQLXML data to a string.";
    t[565] = "Не може да преобразува DOMResult SQLXML данни в низ.";
    t[578] = "Cannot establish a savepoint in auto-commit mode.";
    t[579] = "Не може да се установи savepoint в auto-commit модус.";
    t[580] = "Unable to decode xml data.";
    t[581] = "Не може да декодира XML данните.";
    t[586] = "Unknown XML Source class: {0}";
    t[587] = "Неизвестен XML входящ клас: {0}";
    t[588] = "The array index is out of range: {0}, number of elements: {1}.";
    t[589] = "Индексът на масив е извън обхвата: {0}, брой елементи: {1}.";
    t[592] = "Current connection does not have an associated xid. prepare xid={0}";
    t[593] = "Текущата връзка няма свързан xid. prepare xid={0}";
    t[594] = "DataSource has been closed.";
    t[595] = "Източникът на данни е прекъснат.";
    t[598] = "The parameter index is out of range: {0}, number of parameters: {1}.";
    t[599] = "Параметърният индекс е извън обхват: {0}, брой параметри: {1}.";
    t[600] = "An unexpected result was returned by a query.";
    t[601] = "Заявката върна неочакван резултат.";
    t[608] = "Unable to translate data into the desired encoding.";
    t[609] = "Невъзможно преобразуване на данни в желаното кодиране.";
    t[610] = "Unknown XML Result class: {0}";
    t[611] = "Неизвестен XML изходящ клас: {0}";
    t[614] = "Location: File: {0}, Routine: {1}, Line: {2}";
    t[615] = "Местоположение: Файл: {0}, Функция: {1}, Ред: {2}";
    t[618] = "Expected an EOF from server, got: {0}";
    t[619] = "Очакван край на файла от сървъра, но получено: {0}";
    t[620] = "commit() called before end(). commit xid={0}, state={1}";
    t[621] = "commit() е извикан преди end(). commit xid={0}, state={1}";
    t[626] = "Unexpected error writing large object to database.";
    t[627] = "Неочаквана грешка при записване на голям обект LOB в базата данни.";
    t[630] = "GSS Authentication failed";
    t[631] = "GSS удостоверяването бе неуспешно";
    t[632] = "Received CommandComplete ''{0}'' without an active copy operation";
    t[633] = "Получено командно допълнение ''{0}'' без активна команда за копиране";
    t[638] = "Cannot write to copy a byte of value {0}";
    t[639] = "Няма пишещи права, за да копира байтова стойност {0}";
    t[650] = "A CallableStatement was executed with an invalid number of parameters";
    t[651] = "CallableStatement функция бе обработена, но с непозволен брой параметри.";
    t[652] = "{0} function takes four and only four argument.";
    t[653] = "Функцията {0} може да приеме четири и само четири аргумента.";
    t[654] = "{0} function takes one and only one argument.";
    t[655] = "Функцията {0} може да приеме само един единствен аргумент.";
    t[660] = "Tried to cancel an inactive copy operation";
    t[661] = "Опит за прекъсване на неактивно копиране";
    t[662] = "Error during one-phase commit. commit xid={0}";
    t[663] = "Грешка при едно-фазов commit. commit xid={0}";
    t[664] = "Error committing prepared transaction. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[665] = "Грешка при commit на подготвена транзакция. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[666] = "This statement has been closed.";
    t[667] = "Командата е извършена.";
    t[672] = "Cannot cast an instance of {0} to type {1}";
    t[673] = "Не може да преобразува инстанция на {0} към тип {1}";
    t[674] = "Query timeout must be a value greater than or equals to 0.";
    t[675] = "Времето за изпълнение на заявката трябва да бъде стойност по-голяма или равна на 0.";
    t[676] = "Cannot call updateRow() when on the insert row.";
    t[677] = "Не може да се изпълни updateRow() метода, когато се намираме при редицата на въвеждане.";
    t[686] = "No function outputs were registered.";
    t[687] = "Резултати от функцията не бяха регистрирани.";
    t[690] = "Database connection failed when writing to copy";
    t[691] = "Неосъществена връзка към базата данни при опит за копиране";
    t[694] = "Failed to convert binary xml data to encoding: {0}.";
    t[695] = "Неуспешно преобразуване на двоични XML данни за кодиране съгласно: {0}.";
    t[704] = "Currently positioned after the end of the ResultSet.  You cannot call deleteRow() here.";
    t[705] = "В момента се намираме преди края на ResultSet. Тук не може да се изпълни deleteRow() метода.";
    t[706] = "Got CopyOutResponse from server during an active {0}";
    t[707] = "Получен CopyOutResponse отговор от сървъра при активно {0}";
    t[708] = "Custom type maps are not supported.";
    t[709] = "Специфични типови съответствия не се поддържат.";
    t[710] = "This statement does not declare an OUT parameter.  Use '{' ?= call ... '}' to declare one.";
    t[711] = "Тази заявка не декларира изходен параметър. Ползвайте '{' ?= call ... '}' за да декларирате такъв.";
    t[712] = "Error loading default settings from driverconfig.properties";
    t[713] = "Грешка при зареждане на настройките по подразбиране от файла driverconfig.properties";
    t[716] = "Prepare called before end(). prepare xid={0}, state={1}";
    t[717] = "Prepare е извикан преди end(). prepare xid={0}, state={1}";
    t[720] = "2nd phase commit cannot be issued while an XA branch is active on this connection. commit xid={0}, currentXid={1}, state={2}";
    t[721] = "Втората фаза на commit не може да бъде издадена, докато на тази връзка е активен XA клон. commit xid={0}, currentXid={1}, state={2}";
    t[722] = "Large Objects may not be used in auto-commit mode.";
    t[723] = "Големи обекти LOB не могат да се използват в auto-commit модус.";
    t[728] = "Parameter of type {0} was registered, but call to get{1} (sqltype={2}) was made.";
    t[729] = "Отчетен параметър от тип {0}, но обработено като get{1} (sqltype={2}). ";
    t[734] = "Cannot call deleteRow() when on the insert row.";
    t[735] = "Не може да се изпълни deleteRow() метода, когато се намираме при редицата на въвеждане.";
    t[736] = "Connection attempt timed out.";
    t[737] = "Времето за осъществяване на връзката изтече (таймаут).";
    t[740] = "Got CopyInResponse from server during an active {0}";
    t[741] = "Получен CopyInResponse отговор от сървъра при активно {0}";
    t[744] = "Got {0} error responses to single copy cancel request";
    t[745] = "Получени {0} отговори за грешка при единствено искане да се прекъсне копирането";
    t[770] = "Database connection failed when ending copy";
    t[771] = "Неосъществена връзка към базата данни при завършване на копирането";
    t[774] = "Multiple ResultSets were returned by the query.";
    t[775] = "Заявката върна няколко ResultSets.";
    t[776] = "Cannot change transaction read-only property in the middle of a transaction.";
    t[777] = "Не може да променяте правата на транзакцията по време на нейното извършване.";
    t[778] = "ResultSet not positioned properly, perhaps you need to call next.";
    t[779] = "ResultSet не е референциран правилно. Вероятно трябва да придвижите курсора посредством next.";
    t[780] = "Too many update results were returned.";
    t[781] = "Твърде много резултати бяха получени при актуализацията.";
    t[784] = "{0} function takes three and only three arguments.";
    t[785] = "Функцията {0} може да приеме три и само три аргумента.";
    t[792] = "Returning autogenerated keys by column index is not supported.";
    t[793] = "Автоматично генерирани ключове спрямо индекс на колона не се поддържат.";
    t[794] = "This ResultSet is closed.";
    t[795] = "Операциите по този ResultSet са били прекратени.";
    t[796] = "Connection has been closed automatically because a new connection was opened for the same PooledConnection or the PooledConnection has been closed.";
    t[797] = "Връзката бе автоматично прекъсната, защото нова връзка за същата беше осъществена или PooledConnection връзката е вече прекъсната.";
    t[798] = "Truncation of large objects is only implemented in 8.3 and later servers.";
    t[799] = "Скъсяване на големи обекти LOB е осъществено само във версии след 8.3.";
    t[800] = "Cannot retrieve the name of an unnamed savepoint.";
    t[801] = "Не може да определи името на неупомената savepoint.";
    t[804] = "Transaction isolation level {0} not supported.";
    t[805] = "Изолационно ниво на транзакциите {0} не се поддържа.";
    t[810] = "Can''t infer the SQL type to use for an instance of {0}. Use setObject() with an explicit Types value to specify the type to use.";
    t[811] = "Не може да се определи SQL тип, който да се използва за инстанцията на {0}. Ползвайте метода setObject() с точни стойности, за да определите типа.";
    t[816] = "free() was called on this LOB previously";
    t[817] = "Функцията free() бе вече извикана за този голям обект LOB";
    t[818] = "Transaction was already prepared on this connection. prepare xid={0}, preparedXid={1}";
    t[819] = "Транзакцията вече е подготвена на тази връзка. prepare xid={0}, preparedXid={1}";
    t[820] = "There are no rows in this ResultSet.";
    t[821] = "В този ResultSet няма редове.";
    t[824] = "end() called without a matching start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[825] = "end() е извикан без съответстващо извикване на start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[830] = "Zero bytes may not occur in string parameters.";
    t[831] = "Не може да има нула байта в низ параметрите.";
    t[838] = "The server''s DateStyle parameter was changed to {0}. The JDBC driver requires DateStyle to begin with ISO for correct operation.";
    t[839] = "Параметърът DateStyle при сървъра бе променен на {0}. JDBC драйвъра изисква DateStyle започва с ISO за да функционира правилно.";
    t[842] = "Hint: {0}";
    t[843] = "Забележка: {0}";
    t[850] = "Interval {0} not yet implemented";
    t[851] = "Интервалът {0} не е валиден все още.";
    t[852] = "Requested CopyOut but got {0}";
    t[853] = "Зададено CopyOut но получено {0}";
    t[854] = "Got CopyData without an active copy operation";
    t[855] = "Получено CopyData без наличие на активна операция за копиране";
    t[860] = "Cannot tell if path is open or closed: {0}.";
    t[861] = "Не може да определи дали адреса е отворен или затворен: {0}.";
    table = t;
  }
  public java.lang.Object handleGetObject (java.lang.String msgid) throws java.util.MissingResourceException {
    int hash_val = msgid.hashCode() & 0x7fffffff;
    int idx = (hash_val % 433) << 1;
    {
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
    int incr = ((hash_val % 431) + 1) << 1;
    for (;;) {
      idx += incr;
      if (idx >= 866)
        idx -= 866;
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
  }
  public java.util.Enumeration getKeys () {
    return
      new java.util.Enumeration() {
        private int idx = 0;
        { while (idx < 866 && table[idx] == null) idx += 2; }
        public boolean hasMoreElements () {
          return (idx < 866);
        }
        public java.lang.Object nextElement () {
          java.lang.Object key = table[idx];
          do idx += 2; while (idx < 866 && table[idx] == null);
          return key;
        }
      };
  }
  public java.util.ResourceBundle getParent () {
    return parent;
  }
}
