/* Automatically generated by GNU msgfmt.  Do not modify!  */
package org.postgresql.translation;
public class messages_cs extends java.util.ResourceBundle {
  private static final java.lang.String[] table;
  static {
    java.lang.String[] t = new java.lang.String[430];
    t[0] = "";
    t[1] = "Project-Id-Version: PostgreSQL JDBC Driver 8.0\nReport-Msgid-Bugs-To: \nPO-Revision-Date: 2005-08-21 20:00+0200\nLast-Translator: Petr Dittrich <bodyn@medoro.org>\nLanguage-Team: \nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\n";
    t[6] = "Hint: {0}";
    t[7] = "Rada: {0}";
    t[10] = "Protocol error.  Session setup failed.";
    t[11] = "Chyba protokolu. Nastavení relace selhalo.";
    t[12] = "Cannot reference a savepoint after it has been released.";
    t[13] = "Nemohu získat odkaz na savepoint, když byl uvolněn.";
    t[20] = "Server SQLState: {0}";
    t[21] = "Server SQLState: {0}";
    t[22] = "An unexpected result was returned by a query.";
    t[23] = "Obdržen neočekávaný výsledek dotazu.";
    t[28] = "Error loading default settings from driverconfig.properties";
    t[29] = "Chyba načítání standardního nastavení z driverconfig.properties";
    t[36] = "The authentication type {0} is not supported. Check that you have configured the pg_hba.conf file to include the client''s IP address or subnet, and that it is using an authentication scheme supported by the driver.";
    t[37] = "Ověření typu {0} není podporováno. Zkontrolujte zda konfigurační soubor pg_hba.conf obsahuje klientskou IP adresu či podsíť a zda je použité ověřenovací schéma podporováno ovladačem.";
    t[38] = "ResultSets with concurrency CONCUR_READ_ONLY cannot be updated.";
    t[39] = "ResultSets se souběžností CONCUR_READ_ONLY nemůže být aktualizováno";
    t[40] = "Current connection does not have an associated xid. prepare xid={0}";
    t[41] = "Aktuální připojení nemá přiřazené xid. prepare xid={0}";
    t[44] = "Connection has been closed.";
    t[45] = "Spojeni bylo uzavřeno.";
    t[48] = "Invalid stream length {0}.";
    t[49] = "Vadná délka proudu {0}.";
    t[52] = "Invalid protocol state requested. Attempted transaction interleaving is not supported. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[53] = "Byl požadován neplatný stav protokolu. Pokus o prokládání transakcí není podporován. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[58] = "Bad value for type {0} : {1}";
    t[59] = "Špatná hodnota pro typ {0} : {1}";
    t[66] = "{0} function doesn''t take any argument.";
    t[67] = "Funkce {0} nebere žádný argument.";
    t[68] = "end() called without a matching start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[69] = "end() bylo zavoláno bez odpovídajícího start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[70] = "xid must not be null";
    t[71] = "xid nesmí být null";
    t[72] = "No value specified for parameter {0}.";
    t[73] = "Nespecifikována hodnota parametru {0}.";
    t[74] = "Cannot call cancelRowUpdates() when on the insert row.";
    t[75] = "Nemůžete volat cancelRowUpdates() při vkládání řádku.";
    t[78] = "Error during one-phase commit. commit xid={0}";
    t[79] = "Chyba při jednofázovém potvrzení. commit xid={0}";
    t[82] = "Position: {0}";
    t[83] = "Pozice: {0}";
    t[84] = "Connection is already associated with an active XA branch. End the current branch before starting a new one. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[85] = "Připojení je již přiřazeno k aktivní XA větvi. Před zahájením nové větve ukončete tu stávající. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[86] = "Invalid character data was found.  This is most likely caused by stored data containing characters that are invalid for the character set the database was created in.  The most common example of this is storing 8bit data in a SQL_ASCII database.";
    t[87] = "Nalezena vada ve znakových datech. Toto může být způsobeno uloženými daty obsahujícími znaky, které jsou závadné pro znakovou sadu nastavenou při zakládání databáze. Nejznámejší příklad je ukládání 8bitových dat vSQL_ASCII databázi.";
    t[90] = "Invalid flags {0}";
    t[91] = "Neplatné příznaky {0}";
    t[92] = "Can''t use relative move methods while on the insert row.";
    t[93] = "Nemůžete používat relativní přesuny při vkládání řádku.";
    t[94] = "Unsupported Types value: {0}";
    t[95] = "Nepodporovaná hodnota typu: {0}";
    t[98] = "Fetch size must be a value greater than or equal to 0.";
    t[99] = "Nabraná velikost musí být nezáporná.";
    t[100] = "The connection attempt failed.";
    t[101] = "Pokus o připojení selhal.";
    t[102] = "An I/O error occurred while sending to the backend.";
    t[103] = "Vystupně/výstupní chyba při odesílání k backend.";
    t[104] = "The JVM claims not to support the encoding: {0}";
    t[105] = "JVM tvrdí, že nepodporuje kodování: {0}";
    t[106] = "Invalid fetch direction constant: {0}.";
    t[107] = "Špatný směr čtení: {0}.";
    t[108] = "Cannot retrieve the name of an unnamed savepoint.";
    t[109] = "Nemohu získat název nepojmenovaného savepointu.";
    t[110] = "This PooledConnection has already been closed.";
    t[111] = "Tento PooledConnection byl uzavřen.";
    t[112] = "Method {0} is not yet implemented.";
    t[113] = "Metoda {0} není implementována.";
    t[114] = "Unexpected command status: {0}.";
    t[115] = "Neočekávaný stav příkazu: {0}.";
    t[118] = "This ResultSet is closed.";
    t[119] = "Tento ResultSet je uzavřený.";
    t[120] = "Cannot call updateRow() when on the insert row.";
    t[121] = "Nemohu volat updateRow() na vlkádaném řádku.";
    t[124] = "This statement has been closed.";
    t[125] = "Příkaz byl uzavřen.";
    t[130] = "{0} function takes one and only one argument.";
    t[131] = "Funkce {0} bere jeden argument.";
    t[134] = "Where: {0}";
    t[135] = "Kde: {0}";
    t[136] = "Currently positioned after the end of the ResultSet.  You cannot call deleteRow() here.";
    t[137] = "Právě jste za pozicí konce ResultSetu. Zde nemůžete volat deleteRow().s";
    t[138] = "LOB positioning offsets start at 1.";
    t[139] = "Začátek pozicování LOB začína na 1.";
    t[144] = "Unable to translate data into the desired encoding.";
    t[145] = "Nemohu přeložit data do požadovaného kódování.";
    t[146] = "DataSource has been closed.";
    t[147] = "DataSource byl uzavřen.";
    t[150] = "2nd phase commit cannot be issued while an XA branch is active on this connection. commit xid={0}, currentXid={1}, state={2}";
    t[151] = "Druhou fázi potvrzení nelze vydat, pokud je na tomto připojení aktivní XA větev. commit xid={0}, currentXid={1}, state={2}";
    t[154] = "The array index is out of range: {0}";
    t[155] = "Index pole mimo rozsah: {0}";
    t[158] = "A CallableStatement was executed with nothing returned.";
    t[159] = "CallableStatement byl spuštěn, leč nic nebylo vráceno.";
    t[164] = "Error committing prepared transaction. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[165] = "Chyba při potvrzování připravené transakce. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[168] = "A result was returned when none was expected.";
    t[169] = "Obdržen výsledek, ikdyž žádný nebyl očekáván.";
    t[170] = "Malformed function or procedure escape syntax at offset {0}.";
    t[171] = "Poškozená funkce nebo opuštění procedury na pozici {0}.";
    t[172] = "The SSLSocketFactory class provided {0} could not be instantiated.";
    t[173] = "Třída SSLSocketFactory poskytla {0} což nemůže být instancionizováno.";
    t[178] = "No results were returned by the query.";
    t[179] = "Neobdržen žádný výsledek dotazu.";
    t[180] = "There are no rows in this ResultSet.";
    t[181] = "Žádný řádek v ResultSet.";
    t[182] = "A connection could not be made using the requested protocol {0}.";
    t[183] = "Spojení nelze vytvořit s použitím žádaného protokolu {0}.";
    t[192] = "Heuristic commit/rollback not supported. forget xid={0}";
    t[193] = "Heuristické commit/rollback není podporováno. forget xid={0}";
    t[198] = "Transaction control methods setAutoCommit, commit, rollback and setSavepoint are not allowed while an XA transaction is active.";
    t[199] = "Metody řízení transakce setAutoCommit, commit, rollback a setSavepoint nejsou povoleny, pokud je aktivní XA transakce.";
    t[202] = "Cannot rollback prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. rollback xid={0}, transactionState={1}";
    t[203] = "Nelze odvolat připravenou transakci, dokud na tomto připojení probíhá lokální transakce. Nejprve potvrďte nebo odvolejte lokální transakci. rollback xid={0}, transactionState={1}";
    t[206] = "Statement has been closed.";
    t[207] = "Statement byl uzavřen.";
    t[210] = "One-phase commit called for xid {0} but connection was prepared with xid {1}";
    t[211] = "Jednofázové potvrzení bylo zavoláno pro xid {0}, ale připojení bylo připraveno s xid {1}";
    t[216] = "The parameter index is out of range: {0}, number of parameters: {1}.";
    t[217] = "Index parametru mimo rozsah: {0}, počet parametrů {1}.";
    t[220] = "Multiple ResultSets were returned by the query.";
    t[221] = "Vícenásobný ResultSet byl vrácen dotazem.";
    t[228] = "Query timeout must be a value greater than or equals to 0.";
    t[229] = "Časový limit dotazu musí být nezáporné číslo.";
    t[230] = "Cannot retrieve the id of a named savepoint.";
    t[231] = "Nemohu získat id nepojmenovaného savepointu.";
    t[234] = "Unable to load the class {0} responsible for the datatype {1}";
    t[235] = "Nemohu načíst třídu {0} odpovědnou za typ {1}";
    t[236] = "Location: File: {0}, Routine: {1}, Line: {2}";
    t[237] = "Poloha: Soubor: {0}, Rutina: {1}, Řádek: {2}";
    t[238] = "Prepare must be issued on the connection that started the branch. Transaction interleaving is not supported. prepare xid={0}, currentXid={1}";
    t[239] = "Prepare musí být vydáno na připojení, které větev zahájilo. Prokládání transakcí není podporováno. prepare xid={0}, currentXid={1}";
    t[242] = "The server does not support SSL.";
    t[243] = "Server nepodporuje SSL.";
    t[246] = "{0} function takes two and only two arguments.";
    t[247] = "Funkce {0} bere právě dva argumenty.";
    t[262] = "Unknown Response Type {0}.";
    t[263] = "Neznámý typ odpovědi {0}.";
    t[266] = "Error preparing transaction. prepare xid={0}";
    t[267] = "Chyba při přípravě transakce. prepare xid={0}";
    t[268] = "The column index is out of range: {0}, number of columns: {1}.";
    t[269] = "Index sloupece je mimo rozsah: {0}, počet sloupců: {1}.";
    t[276] = "An error occurred while setting up the SSL connection.";
    t[277] = "Nastala chyba při nastavení SSL spojení.";
    t[282] = "Conversion of money failed.";
    t[283] = "Převod peněz selhal.";
    t[284] = "Prepare called before end(). prepare xid={0}, state={1}";
    t[285] = "Prepare bylo zavoláno před end(). prepare xid={0}, state={1}";
    t[286] = "ResultSet is not updateable.  The query that generated this result set must select only one table, and must select all primary keys from that table. See the JDBC 2.1 API Specification, section 5.6 for more details.";
    t[287] = "ResultSet není aktualizavatelný. Dotaz musí vybírat pouze z jedné tabulky a musí obsahovat všechny primární klíče tabulky. Koukni do JDBC 2.1 API Specifikace, sekce 5.6 pro více podrobností.";
    t[288] = "Cannot establish a savepoint in auto-commit mode.";
    t[289] = "Nemohu vytvořit savepoint v auto-commit modu.";
    t[294] = "{0} function takes two or three arguments.";
    t[295] = "Funkce {0} bere dva nebo tři argumenty.";
    t[296] = "Unknown Types value.";
    t[297] = "Neznámá hodnota typu.";
    t[308] = "Error during recover. flag={0}";
    t[309] = "Chyba při obnově. flag={0}";
    t[310] = "The array index is out of range: {0}, number of elements: {1}.";
    t[311] = "Index pole mimo rozsah: {0}, počet prvků: {1}.";
    t[312] = "You must specify at least one column value to insert a row.";
    t[313] = "Musíte vyplnit alespoň jeden sloupec pro vložení řádku.";
    t[322] = "Suspend/resume not implemented";
    t[323] = "Suspend/resume není implementováno";
    t[330] = "Not on the insert row.";
    t[331] = "Ne na vkládaném řádku.";
    t[334] = "Failed to create object for: {0}.";
    t[335] = "Selhalo vytvoření objektu: {0}.";
    t[336] = "Error rolling back transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[337] = "Chyba při odvolávání transakce. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[338] = "Error opening transaction. start xid={0}";
    t[339] = "Chyba při otevírání transakce. start xid={0}";
    t[342] = "The maximum field size must be a value greater than or equal to 0.";
    t[343] = "Maximální velikost pole musí být nezáporné číslo.";
    t[350] = "Can''t refresh the insert row.";
    t[351] = "Nemohu obnovit vkládaný řádek.";
    t[354] = "{0} function takes four and only four argument.";
    t[355] = "Funkce {0} bere přesně čtyři argumenty.";
    t[356] = "Too many update results were returned.";
    t[357] = "Bylo vráceno příliš mnoho výsledků aktualizací.";
    t[360] = "Large Objects may not be used in auto-commit mode.";
    t[361] = "Velké objecky nemohou být použity v auto-commit modu.";
    t[364] = "Expected command status BEGIN, got {0}.";
    t[365] = "Očekáván příkaz BEGIN, obdržen {0}.";
    t[366] = "Provided Reader failed.";
    t[367] = "Selhal poskytnutý Reader.";
    t[368] = "The column name {0} was not found in this ResultSet.";
    t[369] = "Sloupec pojmenovaný {0} nebyl nalezen v ResultSet.";
    t[372] = "Returning autogenerated keys is not supported.";
    t[373] = "Vrácení automaticky generovaných klíčů není podporováno.";
    t[376] = "commit() called before end(). commit xid={0}, state={1}";
    t[377] = "commit() bylo zavoláno před end(). commit xid={0}, state={1}";
    t[378] = "Cannot 2nd phase commit prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. commit xid={0}, transactionState={1}";
    t[379] = "Nelze provést druhou fázi potvrzení připravené transakce, dokud na tomto připojení probíhá lokální transakce. Nejprve potvrďte nebo odvolejte lokální transakci. commit xid={0}, transactionState={1}";
    t[384] = "Something unusual has occurred to cause the driver to fail. Please report this exception.";
    t[385] = "Něco neobvyklého přinutilo ovladač selhat. Prosím nahlaste tuto vyjímku.";
    t[386] = "Cannot cast an instance of {0} to type {1}";
    t[387] = "Nemohu přetypovat instanci {0} na typ {1}";
    t[392] = "Unable to find name datatype in the system catalogs.";
    t[393] = "Nemohu najít název typu v systémovém katalogu.";
    t[398] = "Transaction was already prepared on this connection. prepare xid={0}, preparedXid={1}";
    t[399] = "Transakce již byla na tomto připojení připravena. prepare xid={0}, preparedXid={1}";
    t[402] = "Unexpected error writing large object to database.";
    t[403] = "Neočekávaná chyba při zapisování velkého objektu do databáze.";
    t[406] = "Unknown type {0}.";
    t[407] = "Neznámý typ {0}.";
    t[410] = "Cannot call deleteRow() when on the insert row.";
    t[411] = "Nemůžete volat deleteRow() při vkládání řádku.";
    t[414] = "Provided InputStream failed.";
    t[415] = "Selhal poskytnutý InputStream.";
    t[420] = "One-phase commit with unknown xid. commit xid={0}, currentXid={1}";
    t[421] = "Jednofázové potvrzení s neznámým xid. commit xid={0}, currentXid={1}";
    t[422] = "One-phase commit must be issued on the connection that started the branch. commit xid={0}";
    t[423] = "Jednofázové potvrzení musí být vydáno na připojení, které větev zahájilo. commit xid={0}";
    t[424] = "Detail: {0}";
    t[425] = "Detail: {0}";
    t[428] = "The JVM claims not to support the {0} encoding.";
    t[429] = "JVM tvrdí, že nepodporuje kodování {0}.";
    table = t;
  }
  public java.lang.Object handleGetObject (java.lang.String msgid) throws java.util.MissingResourceException {
    int hash_val = msgid.hashCode() & 0x7fffffff;
    int idx = (hash_val % 215) << 1;
    {
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
    int incr = ((hash_val % 213) + 1) << 1;
    for (;;) {
      idx += incr;
      if (idx >= 430)
        idx -= 430;
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
  }
  public java.util.Enumeration getKeys () {
    return
      new java.util.Enumeration() {
        private int idx = 0;
        { while (idx < 430 && table[idx] == null) idx += 2; }
        public boolean hasMoreElements () {
          return (idx < 430);
        }
        public java.lang.Object nextElement () {
          java.lang.Object key = table[idx];
          do idx += 2; while (idx < 430 && table[idx] == null);
          return key;
        }
      };
  }
  public java.util.ResourceBundle getParent () {
    return parent;
  }
}
