/* Automatically generated by GNU msgfmt.  Do not modify!  */
package org.postgresql.translation;
public class messages_ko extends java.util.ResourceBundle {
  private static final java.lang.String[] table;
  static {
    java.lang.String[] t = new java.lang.String[1502];
    t[0] = "";
    t[1] = "Project-Id-Version: head-ko\nReport-Msgid-Bugs-To: \nPO-Revision-Date: 2024-05-29 11:10+0500\nLast-Translator: Sheeraz Majeed<sheeraz.majeed01@gmail.com>\nLanguage-Team: PostgreSQL Translators<pgsql-translators@postgresql.org>\nLanguage: ko\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\n";
    t[2] = "Read from copy failed.";
    t[3] = "복사에서 읽기 실패.";
    t[8] = "Requested CopyIn but got {0}";
    t[9] = "요청된 CopyIn 대신 {0} 을(를) 받았습니다.";
    t[10] = "Connection to {0} refused. Check that the hostname and port are correct and that the postmaster is accepting TCP/IP connections.";
    t[11] = "{0} 에 대한 연결이 거부되었습니다. 호스트 이름과 포트가 올바른지, 그리고 postmaster가 TCP/IP 연결을 수락하고 있는지 확인하십시오.";
    t[16] = "Can't convert {0} to {1} literal";
    t[17] = "{0} 을(를) {1} 리터럴로 변환할 수 없습니다.";
    t[18] = "Unsupported property name: {0}";
    t[19] = "지원되지 않는 속성 이름: {0}";
    t[28] = "This connection has been closed.";
    t[29] = "이 연결은 닫혔습니다.";
    t[38] = "Batch entry {0} {1} was aborted: {2}  Call getNextException to see other errors in the batch.";
    t[39] = "배치 항목 {0} {1} 이(가) 중단되었습니다: {2} 배치의 다른 오류를 보려면 getNextException을 호출하십시오.";
    t[48] = "Unexpected command status: {0}.";
    t[49] = "예상치 못한 명령 상태: {0}.";
    t[58] = "An error occurred while trying to get the socket timeout.";
    t[59] = "소켓 시간 초과를 가져오는 동안 오류가 발생했습니다.";
    t[60] = "Invalid character data was found.  This is most likely caused by stored data containing characters that are invalid for the character set the database was created in.  The most common example of this is storing 8bit data in a SQL_ASCII database.";
    t[61] = "잘못된 문자 데이터가 발견되었습니다. 이는 데이터베이스가 생성된 문자 세트에 대해 잘못된 문자를 포함하는 저장된 데이터로 인해 발생할 가능성이 큽니다. 가장 일반적인 예는 SQL_ASCII 데이터베이스에 8비트 데이터를 저장하는 것입니다.";
    t[62] = "Fetch size must be a value greater than or equal to 0.";
    t[63] = "가져오기 크기는 0보다 크거나 같아야 합니다.";
    t[64] = "The server does not support GSS Encryption.";
    t[65] = "서버가 GSS 암호화를 지원하지 않습니다.";
    t[72] = "A result was returned when none was expected.";
    t[73] = "예상치 못한 결과가 반환되었습니다.";
    t[82] = "Tried to end inactive copy";
    t[83] = "비활성 복사를 끝내려고 시도했습니다.";
    t[84] = "The server''s standard_conforming_strings parameter was reported as {0}. The JDBC driver expected on or off.";
    t[85] = "서버의 standard_conforming_strings 매개 변수가 {0} 으로 보고되었습니다. JDBC 드라이버는 켜짐 또는 꺼짐을 예상했습니다.";
    t[92] = "Unable to load the class {0} responsible for the datatype {1}";
    t[93] = "데이터 유형 {1} 을 담당하는 클래스 {0} 을(를) 로드할 수 없습니다.";
    t[102] = "The parameter index is out of range: {0}, number of parameters: {1}.";
    t[103] = "매개 변수 인덱스가 범위를 벗어났습니다: {0}, 매개 변수 수: {1}.";
    t[104] = "Unknown value for ResultSet type";
    t[105] = "ResultSet 유형에 대한 알 수 없는 값입니다.";
    t[106] = "Could not close SSL certificate file {0}.";
    t[107] = "SSL 인증서 파일 {0} 을(를) 닫을 수 없습니다.";
    t[112] = "Could not read password for SSL key file, console is not available.";
    t[113] = "SSL 키 파일의 비밀번호를 읽을 수 없습니다. 콘솔을 사용할 수 없습니다.";
    t[124] = "Unsupported properties: {0}";
    t[125] = "지원되지 않는 속성: {0}";
    t[132] = "Invalid fetch direction constant: {0}.";
    t[133] = "잘못된 가져오기 방향 상수: {0}.";
    t[134] = "Protocol error.  Session setup failed.";
    t[135] = "프로토콜 오류. 세션 설정 실패.";
    t[146] = "Unexpected packet type during copy: {0}";
    t[147] = "복사 중 예상치 못한 패킷 유형: {0}";
    t[148] = "Error opening transaction. start xid={0}";
    t[149] = "트랜잭션 열기 오류. start xid={0}";
    t[152] = "Validating connection.";
    t[153] = "연결을 검증 중입니다.";
    t[154] = "The SSLSocketFactory class provided {0} could not be instantiated.";
    t[155] = "제공된 SSLSocketFactory 클래스 {0} 을(를) 인스턴스화할 수 없습니다.";
    t[156] = "Prepare called before end(). prepare xid={0}, state={1}";
    t[157] = "end() 호출 전에 Prepare가 호출되었습니다. prepare xid={0}, state={1}";
    t[158] = "Unable to bind parameter values for statement.";
    t[159] = "문에 대한 매개 변수 값을 바인딩할 수 없습니다.";
    t[162] = "The array index is out of range: {0}, number of elements: {1}.";
    t[163] = "배열 인덱스가 범위를 벗어났습니다: {0}, 요소 수: {1}.";
    t[168] = "The system property containing the server's SSL certificate must not be empty.";
    t[169] = "서버의 SSL 인증서를 포함하는 시스템 속성은 비어 있을 수 없습니다.";
    t[170] = "The fastpath function {0} is unknown.";
    t[171] = "Fastpath 함수 {0} 은(는) 알려지지 않았습니다.";
    t[172] = "Hint: {0}";
    t[173] = "힌트: {0}";
    t[174] = "Parameter of type {0} was registered, but call to get{1} (sqltype={2}) was made.";
    t[175] = "유형 {0} 의 매개 변수가 등록되었지만 get{1} (sqltype={2}) 호출이 이루어졌습니다.";
    t[180] = "Fastpath call {0} - No result was returned or wrong size while expecting a long.";
    t[181] = "Fastpath 호출 {0} - 결과가 반환되지 않았거나 long을 예상하는 동안 잘못된 크기입니다.";
    t[188] = "Hostname {0} is invalid";
    t[189] = "호스트 이름 {0} 이(가) 유효하지 않습니다.";
    t[190] = "Can not reset stream for large object {0} to position {1}";
    t[191] = "대형 객체 {0} 에 대한 스트림을 위치 {1} (으)로 재설정할 수 없습니다.";
    t[204] = "Backend timezone is not known. Backend should have returned TimeZone when establishing a connection";
    t[205] = "백엔드 표준 시간대를 알 수 없습니다. 연결을 설정할 때 백엔드에서 TimeZone을 반환해야 합니다.";
    t[208] = "LOB positioning offsets start at 1.";
    t[209] = "LOB 위치 오프셋은 1부터 시작합니다.";
    t[212] = "Maximum number of rows must be a value greater than or equal to 0.";
    t[213] = "최대 행 수는 0보다 크거나 같아야 합니다.";
    t[214] = "Cannot tell if path is open or closed: {0}.";
    t[215] = "경로가 열려 있는지 닫혀 있는지 알 수 없습니다: {0}.";
    t[216] = "Ran out of memory retrieving query results.";
    t[217] = "쿼리 결과를 검색하는 동안 메모리가 부족했습니다.";
    t[232] = "Conversion of money failed.";
    t[233] = "금액 변환 실패.";
    t[234] = "Invalid stream length {0}.";
    t[235] = "잘못된 스트림 길이 {0}.";
    t[242] = "Fastpath call {0} - No result was returned and we expected a numeric.";
    t[243] = "Fastpath 호출 {0} - 결과가 반환되지 않았고 숫자를 예상했습니다.";
    t[246] = "Can not close large object {0}";
    t[247] = "대형 객체 {0} 을(를) 닫을 수 없습니다.";
    t[248] = "Something unusual has occurred to cause the driver to fail. Please report this exception.";
    t[249] = "드라이버가 실패하는 비정상적인 현상이 발생했습니다. 이 예외를 보고해 주세요.";
    t[250] = "{0} function takes four and only four argument.";
    t[251] = "{0} 함수는 네 개의 인수만 받습니다.";
    t[256] = "Cannot truncate LOB to a negative length.";
    t[257] = "LOB를 음수 길이로 잘릴 수 없습니다.";
    t[264] = "Copying from database failed: {0}";
    t[265] = "데이터베이스에서 복사 실패: {0}";
    t[270] = "Connection has been closed automatically because a new connection was opened for the same PooledConnection or the PooledConnection has been closed.";
    t[271] = "같은 PooledConnection에 대해 새 연결이 열리거나 PooledConnection이 닫혔기 때문에 연결이 자동으로 닫혔습니다.";
    t[272] = "Result set exceeded maxResultBuffer limit. Received:  {0}; Current limit: {1}";
    t[273] = "결과 집합이 maxResultBuffer 한도를 초과했습니다. 받은 값: {0}; 현재 한도: {1}";
    t[298] = "Database connection failed when writing to copy";
    t[299] = "복사에 쓰는 동안 데이터베이스 연결 실패";
    t[308] = "Unable to convert DOMResult SQLXML data to a string.";
    t[309] = "DOMResult SQLXML 데이터를 문자열로 변환할 수 없습니다.";
    t[310] = "Heuristic commit/rollback not supported. forget xid={0}";
    t[311] = "휴리스틱 커밋/롤백이 지원되지 않습니다. forget xid={0}";
    t[312] = "The sslfactoryarg property may not be empty.";
    t[313] = "sslfactoryarg 속성은 비어 있을 수 없습니다.";
    t[320] = "Server name validation failed: certificate for hostname {0} has no DNS subjectAltNames, and it CommonName is missing as well";
    t[321] = "서버 이름 유효성 검사 실패: 호스트 이름 {0} 에 대한 인증서에 DNS subjectAltNames가 없으며 CommonName도 없습니다.";
    t[322] = "Error during one-phase commit. commit xid={0}";
    t[323] = "1단계 커밋 중 오류 발생. commit xid={0}";
    t[324] = "The column index is out of range: {0}, number of columns: {1}.";
    t[325] = "열 인덱스가 범위를 벗어났습니다: {0}, 열 수: {1}.";
    t[330] = "Cannot update the ResultSet because it is either before the start or after the end of the results.";
    t[331] = "결과의 시작 전이나 끝 후에 있기 때문에 ResultSet을 업데이트할 수 없습니다.";
    t[332] = "Unable to get network timeout.";
    t[333] = "네트워크 시간 초과를 가져올 수 없습니다.";
    t[334] = "Database connection failed when starting copy";
    t[335] = "복사 시작 시 데이터베이스 연결 실패";
    t[338] = "Got CopyBothResponse from server during an active {0}";
    t[339] = "활성 {0} 중 서버로부터 CopyBothResponse를 받았습니다.";
    t[340] = "Cannot call deleteRow() when on the insert row.";
    t[341] = "삽입 행에 있는 동안 deleteRow()를 호출할 수 없습니다.";
    t[346] = "Expected a row when reading password_encryption but none was found";
    t[347] = "password_encryption을 읽을 때 행이 예상되었으나 아무 것도 발견되지 않았습니다.";
    t[348] = "Zero bytes may not occur in string parameters.";
    t[349] = "문자열 매개 변수에 0 바이트가 발생할 수 없습니다.";
    t[354] = "Cannot change transaction read-only property in the middle of a transaction.";
    t[355] = "트랜잭션 중간에 트랜잭션 읽기 전용 속성을 변경할 수 없습니다.";
    t[356] = "Cannot retrieve the name of an unnamed savepoint.";
    t[357] = "이름이 없는 세이브포인트의 이름을 검색할 수 없습니다.";
    t[360] = "The server does not support GSS Encoding.";
    t[361] = "서버가 GSS 인코딩을 지원하지 않습니다.";
    t[362] = "Could not decrypt SSL key file {0}.";
    t[363] = "SSL 키 파일 {0} 을(를) 해독할 수 없습니다.";
    t[370] = "Database connection failed when reading from copy";
    t[371] = "복사에서 읽는 동안 데이터베이스 연결 실패";
    t[372] = "Invalid Inet data.";
    t[373] = "잘못된 Inet 데이터입니다.";
    t[374] = "Where: {0}";
    t[375] = "위치: {0}";
    t[376] = "Error preparing transaction. prepare xid={0}";
    t[377] = "트랜잭션 준비 오류. prepare xid={0}";
    t[388] = "Unable to find keywords in the system catalogs.";
    t[389] = "시스템 카탈로그에서 키워드를 찾을 수 없습니다.";
    t[394] = "Suspend/resume not implemented";
    t[395] = "일시 중지/다시 시작이 구현되지 않았습니다.";
    t[404] = "Could not initialize SSL context.";
    t[405] = "SSL 컨텍스트를 초기화할 수 없습니다.";
    t[406] = "Statement has been closed.";
    t[407] = "Statement가 닫혔습니다.";
    t[410] = "This SQLXML object has already been initialized, so you cannot manipulate it further.";
    t[411] = "이 SQLXML 객체는 이미 초기화되었으므로 더 이상 조작할 수 없습니다.";
    t[414] = "Location: File: {0}, Routine: {1}, Line: {2}";
    t[415] = "위치: 파일: {0}, 루틴: {1}, 줄: {2}";
    t[420] = "This statement has been closed.";
    t[421] = "이 문이 닫혔습니다.";
    t[422] = "Failed to create object for: {0}.";
    t[423] = "{0} 에 대한 개체 생성 실패.";
    t[424] = "Internal Position: {0}";
    t[425] = "내부 위치: {0}";
    t[428] = "Server name validation pass for {0}, subjectAltName {1}";
    t[429] = "서버 이름 유효성 검사가 {0}, subjectAltName {1} 에 대해 통과했습니다.";
    t[436] = "Error committing prepared transaction. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[437] = "준비된 트랜잭션을 커밋하는 중 오류가 발생했습니다. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[438] = "Invalid UUID data.";
    t[439] = "잘못된 UUID 데이터입니다.";
    t[446] = "No value specified for parameter {0}.";
    t[447] = "매개 변수 {0} 에 대해 지정된 값이 없습니다.";
    t[448] = "The server requested SCRAM-based authentication, but the password is an empty string.";
    t[449] = "서버가 SCRAM 기반 인증을 요청했지만, 비밀번호가 빈 문자열입니다.";
    t[456] = "Malformed function or procedure escape syntax at offset {0}.";
    t[457] = "오프셋 {0} 에서 잘못된 함수 또는 절차 이스케이프 구문입니다.";
    t[464] = "No function outputs were registered.";
    t[465] = "등록된 함수 출력이 없습니다.";
    t[484] = "Unable to set network timeout.";
    t[485] = "네트워크 시간 초과를 설정할 수 없습니다.";
    t[488] = "An error occurred while setting up the SSL connection.";
    t[489] = "SSL 연결을 설정하는 동안 오류가 발생했습니다.";
    t[500] = "No results were returned by the query.";
    t[501] = "쿼리에서 반환된 결과가 없습니다.";
    t[506] = "One-phase commit must be issued on the connection that started the branch. commit xid={0}";
    t[507] = "1단계 커밋은 분기를 시작한 연결에서 발행해야 합니다. commit xid={0}";
    t[510] = "Got CopyData without an active copy operation";
    t[511] = "활성 복사 작업 없이 CopyData를 받았습니다.";
    t[512] = "User cannot be null";
    t[513] = "사용자는 null일 수 없습니다.";
    t[518] = "This PooledConnection has already been closed.";
    t[519] = "이 PooledConnection은 이미 닫혔습니다.";
    t[522] = "conversion to {0} from {1} not supported";
    t[523] = "{1} 에서 {0} (으)로의 변환이 지원되지 않습니다.";
    t[526] = "Cannot cast to boolean: \"{0}\"";
    t[527] = "boolean으로 캐스팅할 수 없습니다: \"{0}\"";
    t[528] = "Unsupported value for stringtype parameter: {0}";
    t[529] = "stringtype 매개 변수에 대한 지원되지 않는 값: {0}";
    t[530] = "Too many update results were returned.";
    t[531] = "너무 많은 업데이트 결과가 반환되었습니다.";
    t[534] = "CommandComplete expected COPY but got: {0}";
    t[535] = "CommandComplete는 COPY를 예상했으나 대신 다음을 받았습니다: {0}";
    t[536] = "The array index is out of range: {0}";
    t[537] = "배열 인덱스가 범위를 벗어났습니다: {0}";
    t[540] = "The server requested password-based authentication, but no password was provided by plugin {0}";
    t[541] = "서버가 비밀번호 기반 인증을 요청했으나, 플러그인 {0} 에서 비밀번호를 제공하지 않았습니다.";
    t[542] = "Method {0} is not yet implemented.";
    t[543] = "메서드 {0} 이(가) 아직 구현되지 않았습니다.";
    t[550] = "Got CopyInResponse from server during an active {0}";
    t[551] = "활성 {0} 중 서버로부터 CopyInResponse를 받았습니다.";
    t[556] = "Connection is already associated with an active XA branch. End the current branch before starting a new one. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[557] = "연결이 이미 활성 XA 분기와 연관되어 있습니다. 새 분기를 시작하기 전에 현재 분기를 종료하십시오. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[560] = "Server name validation failed: hostname {0} does not match common name {1}";
    t[561] = "서버 이름 유효성 검사 실패: 호스트 이름 {0} 이(가) 공통 이름 {1} 과(와) 일치하지 않습니다.";
    t[562] = "Unknown value for ResultSet concurrency";
    t[563] = "ResultSet 동시성에 대한 알 수 없는 값입니다.";
    t[566] = "The authentication type {0} is not supported. Check that you have configured the pg_hba.conf file to include the client''s IP address or subnet, and that it is using an authentication scheme supported by the driver.";
    t[567] = "인증 유형 {0} 이(가) 지원되지 않습니다. pg_hba.conf 파일에 클라이언트의 IP 주소 또는 서브넷이 포함되어 있고, 드라이버가 지원하는 인증 방식을 사용하고 있는지 확인하십시오.";
    t[568] = "Unexpected packet type during replication: {0}";
    t[569] = "복제 중 예상치 못한 패킷 유형: {0}";
    t[570] = "Interval {0} not yet implemented";
    t[571] = "구간 {0} 은(는) 아직 구현되지 않았습니다.";
    t[572] = "Unknown Types value.";
    t[573] = "알 수 없는 유형 값입니다.";
    t[574] = "Interrupted while waiting to obtain lock on database connection";
    t[575] = "데이터베이스 연결에서 잠금을 얻기 위해 대기하는 동안 중단되었습니다.";
    t[582] = "Conversion of interval failed";
    t[583] = "간격 변환 실패";
    t[584] = "Can''t infer the SQL type to use for an instance of {0}. Use setObject() with an explicit Types value to specify the type to use.";
    t[585] = "{0} 의 인스턴스에 사용할 SQL 유형을 추론할 수 없습니다. 명시적 유형 값을 사용하여 setObject()를 사용하여 사용할 유형을 지정하십시오.";
    t[586] = "Enter SSL password: ";
    t[587] = "SSL 비밀번호 입력: ";
    t[588] = "This SQLXML object has already been freed.";
    t[589] = "이 SQLXML 객체는 이미 해제되었습니다.";
    t[590] = "Could not find a java cryptographic algorithm: X.509 CertificateFactory not available.";
    t[591] = "Java 암호화 알고리즘을 찾을 수 없습니다: X.509 CertificateFactory를 사용할 수 없습니다.";
    t[594] = "Error during recover. flag={0}";
    t[595] = "복구 중 오류. flag={0}";
    t[600] = "Could not find a server with specified targetServerType: {0}";
    t[601] = "지정된 targetServerType을 가진 서버를 찾을 수 없습니다: {0}";
    t[606] = "Zero bytes may not occur in identifiers.";
    t[607] = "식별자에 0 바이트가 발생할 수 없습니다.";
    t[608] = "free() was called on this LOB previously";
    t[609] = "이 LOB에서 이전에 free()가 호출되었습니다.";
    t[612] = "Unable to parse URL {0}";
    t[613] = "URL {0} 을(를) 파싱할 수 없습니다";
    t[614] = "Could not read password for SSL key file by callbackhandler {0}.";
    t[615] = "콜백 핸들러 {0} 을(를) 사용하여 SSL 키 파일의 비밀번호를 읽을 수 없습니다.";
    t[618] = "{0} function doesn''t take any argument.";
    t[619] = "{0} 함수는 인수를 받지 않습니다.";
    t[634] = "PostgreSQL LOBs can only index to: {0}";
    t[635] = "PostgreSQL LOB는 다음으로만 인덱싱할 수 있습니다: {0}";
    t[636] = "The server''s DateStyle parameter was changed to {0}. The JDBC driver requires DateStyle to begin with ISO for correct operation.";
    t[637] = "서버의 DateStyle 매개 변수가 {0} 으로 변경되었습니다. JDBC 드라이버는 올바른 작동을 위해 DateStyle이 ISO로 시작해야 합니다.";
    t[638] = "Expected command status BEGIN, got {0}.";
    t[639] = "예상한 명령 상태 BEGIN 대신 {0} 을(를) 받았습니다.";
    t[640] = "Transaction control methods setAutoCommit, commit, rollback and setSavepoint are not allowed while an XA transaction is active.";
    t[641] = "XA 트랜잭션이 활성 상태인 동안 트랜잭션 제어 메서드 setAutoCommit, commit, rollback 및 setSavepoint가 허용되지 않습니다.";
    t[646] = "This statement does not declare an OUT parameter.  Use '{' ?= call ... '}' to declare one.";
    t[647] = "이 문은 OUT 매개 변수를 선언하지 않습니다. OUT 매개 변수를 선언하려면 '{' ?= call ... '}'을 사용하십시오.";
    t[648] = "You must specify at least one column value to insert a row.";
    t[649] = "행을 삽입하려면 적어도 하나의 열 값을 지정해야 합니다.";
    t[652] = "hstore key must not be null";
    t[653] = "hstore 키는 null일 수 없습니다.";
    t[658] = "Large Objects may not be used in auto-commit mode.";
    t[659] = "대형 객체는 자동 커밋 모드에서 사용할 수 없습니다.";
    t[660] = "Requested CopyOut but got {0}";
    t[661] = "요청된 CopyOut 대신 {0} 을(를) 받았습니다.";
    t[662] = "Current connection does not have an associated xid. prepare xid={0}";
    t[663] = "현재 연결에는 연결된 xid가 없습니다. prepare xid={0}";
    t[664] = "No certificates found for hostname {0}";
    t[665] = "호스트 이름 {0} 에 대한 인증서를 찾을 수 없습니다.";
    t[670] = "Value is not an OID: {0}";
    t[671] = "값이 OID가 아닙니다: {0}";
    t[674] = "The column name {0} was not found in this ResultSet.";
    t[675] = "이 ResultSet에서 열 이름 {0} 을(를) 찾을 수 없습니다.";
    t[680] = "Failed to convert binary xml data to encoding: {0}.";
    t[681] = "이진 xml 데이터를 인코딩 {0} (으)로 변환하지 못했습니다.";
    t[682] = "Detail: {0}";
    t[683] = "세부 정보: {0}";
    t[684] = "oid type {0} not known and not a number";
    t[685] = "oid 유형 {0} 이(가) 알려지지 않았고 숫자가 아닙니다.";
    t[686] = "Currently positioned before the start of the ResultSet.  You cannot call deleteRow() here.";
    t[687] = "현재 ResultSet의 시작 이전에 위치해 있습니다. 여기에서 deleteRow()를 호출할 수 없습니다.";
    t[692] = "Server name validation failed: certificate for host {0} dNSName entries subjectAltName, but none of them match. Assuming server name validation failed";
    t[693] = "서버 이름 유효성 검사 실패: 호스트 {0} dNSName 항목 subjectAltName에 대한 인증서가 있지만 일치하지 않습니다. 서버 이름 유효성 검사 실패로 가정";
    t[696] = "This SQLXML object has not been initialized, so you cannot retrieve data from it.";
    t[697] = "이 SQLXML 객체가 초기화되지 않았으므로 데이터를 검색할 수 없습니다.";
    t[700] = "WARNING! Required to allocate {0} bytes, which exceeded possible heap memory size. Assigned {1} bytes as limit.";
    t[701] = "경고! {0} 바이트를 할당해야 하는데 이는 가능한 힙 메모리 크기를 초과했습니다. {1} 바이트를 한도로 할당했습니다.";
    t[702] = "Interrupted while attempting to connect.";
    t[703] = "연결 시도 중 중단되었습니다.";
    t[706] = "{0} returned no results";
    t[707] = "{0} 반환된 결과가 없습니다.";
    t[712] = "Tried to break lock on database connection";
    t[713] = "데이터베이스 연결에서 잠금을 해제하려고 시도했습니다.";
    t[716] = "DataSource has been closed.";
    t[717] = "DataSource가 닫혔습니다.";
    t[722] = "Returning autogenerated keys by column index is not supported.";
    t[723] = "열 인덱스별 자동 생성 키 반환이 지원되지 않습니다.";
    t[728] = "The sslfactoryarg property must start with the prefix file:, classpath:, env:, sys:, or -----BEGIN CERTIFICATE-----.";
    t[729] = "sslfactoryarg 속성은 file:, classpath:, env:, sys: 또는 -----BEGIN CERTIFICATE----- 접두사로 시작해야 합니다.";
    t[736] = "Unable to parse certificates for hostname {0}";
    t[737] = "호스트 이름 {0} 에 대한 인증서를 구문 분석할 수 없습니다.";
    t[738] = "Invalid elements {0}";
    t[739] = "잘못된 요소 {0}";
    t[740] = "Unable to find name datatype in the system catalogs.";
    t[741] = "시스템 카탈로그에서 이름 데이터 유형을 찾을 수 없습니다.";
    t[760] = "Unable to parse the count in command completion tag: {0}.";
    t[761] = "명령 완료 태그의 카운트를 파싱할 수 없습니다: {0}.";
    t[762] = "Transaction was already prepared on this connection. prepare xid={0}, preparedXid={1}";
    t[763] = "이 연결에서 트랜잭션이 이미 준비되었습니다. prepare xid={0}, preparedXid={1}";
    t[766] = "The connection attempt failed.";
    t[767] = "연결 시도가 실패했습니다.";
    t[768] = "Added parameters index out of range: {0}, number of columns: {1}.";
    t[769] = "추가된 매개 변수 인덱스가 범위를 벗어났습니다: {0}, 열 수: {1}.";
    t[774] = "Tried to cancel an inactive copy operation";
    t[775] = "비활성 복사 작업을 취소하려고 시도했습니다.";
    t[778] = "Query timeout must be a value greater than or equals to 0.";
    t[779] = "쿼리 시간 초과는 0보다 크거나 같아야 합니다.";
    t[782] = "Cannot convert the column of type {0} to requested type {1}.";
    t[783] = "유형 {0} 의 열을 요청된 유형 {1} (으)로 변환할 수 없습니다.";
    t[786] = "Internal Query: {0}";
    t[787] = "내부 쿼리: {0}";
    t[788] = "Unknown XML Source class: {0}";
    t[789] = "알 수 없는 XML 소스 클래스: {0}";
    t[794] = "The JVM claims not to support the encoding: {0}";
    t[795] = "JVM이 인코딩을 지원하지 않는다고 주장합니다: {0}";
    t[798] = "Unexpected copydata from server for {0}";
    t[799] = "{0} 에 대한 서버의 예상치 못한 copydata";
    t[802] = "Unknown type {0}.";
    t[803] = "알 수 없는 유형 {0}.";
    t[808] = "Cannot call updateRow() when on the insert row.";
    t[809] = "삽입 행에 있는 동안 updateRow()를 호출할 수 없습니다.";
    t[812] = "Server name validation failed: unable to extract common name from X509Certificate for hostname {0}";
    t[813] = "서버 이름 유효성 검사 실패: 호스트 이름 {0} 에 대한 X509Certificate에서 공통 이름을 추출할 수 없습니다.";
    t[814] = "Requested CopyDual but got {0}";
    t[815] = "요청된 CopyDual 대신 {0} 을(를) 받았습니다.";
    t[816] = "Missing expected error response to copy cancel request";
    t[817] = "복사 취소 요청에 대한 예상 오류 응답이 누락되었습니다.";
    t[818] = "Cannot cast an instance of {0} to type {1}";
    t[819] = "{0} 의 인스턴스를 유형 {1}(으)로 캐스팅할 수 없습니다.";
    t[822] = "Invalid gssEncMode value: {0}";
    t[823] = "잘못된 gssEncMode 값: {0}";
    t[824] = "No hstore extension installed.";
    t[825] = "설치된 hstore 확장이 없습니다.";
    t[830] = "Invalid timeout ({0}<0).";
    t[831] = "잘못된 시간 초과 ({0}<0).";
    t[832] = "Unable to create StAXResult for SQLXML";
    t[833] = "SQLXML에 대한 StAXResult를 생성할 수 없습니다.";
    t[836] = "Transaction isolation level {0} not supported.";
    t[837] = "트랜잭션 격리 수준 {0} 이(가) 지원되지 않습니다.";
    t[838] = "The HostnameVerifier class provided {0} could not be instantiated.";
    t[839] = "제공된 HostnameVerifier 클래스 {0} 을(를) 인스턴스화할 수 없습니다.";
    t[842] = "Unable to find resource {0} via class {1} ClassLoader {2}";
    t[843] = "클래스 {1} ClassLoader {2} 을(를) 통해 리소스 {0} 을(를) 찾을 수 없습니다.";
    t[844] = "An unexpected result was returned by a query.";
    t[845] = "쿼리가 예상치 못한 결과를 반환했습니다.";
    t[846] = "One-phase commit called for xid {0} but connection was prepared with xid {1}";
    t[847] = "1단계 커밋이 xid {0} 에 대해 호출되었으나 연결이 xid {1}(으)로 준비되었습니다.";
    t[852] = "A CallableStatement was executed with an invalid number of parameters";
    t[853] = "CallableStatement가 잘못된 수의 매개 변수로 실행되었습니다.";
    t[854] = "Premature end of input stream, expected {0} bytes, but only read {1}.";
    t[855] = "입력 스트림의 조기 종료, 예상 {0} 바이트 중 {1} 바이트만 읽었습니다.";
    t[862] = "Database connection failed when canceling copy operation";
    t[863] = "복사 작업을 취소하는 동안 데이터베이스 연결 실패";
    t[870] = "This copy stream is closed.";
    t[871] = "이 복사 스트림은 닫혀 있습니다.";
    t[872] = "Failed to setup DataSource.";
    t[873] = "DataSource 설정 실패.";
    t[874] = "{0} function takes one and only one argument.";
    t[875] = "{0} 함수는 한 개의 인수만 받습니다.";
    t[876] = "Can''t use relative move methods while on the insert row.";
    t[877] = "삽입 행에 있는 동안 상대적 이동 메서드를 사용할 수 없습니다.";
    t[880] = "Could not find a java cryptographic algorithm: {0}.";
    t[881] = "Java 암호화 알고리즘을 찾을 수 없습니다: {0}.";
    t[882] = "No eligible primary or unique key found for table {0}.";
    t[883] = "테이블 {0} 에 대해 적합한 기본 키 또는 고유 키가 없습니다.";
    t[890] = "Operation requires a scrollable ResultSet, but this ResultSet is FORWARD_ONLY.";
    t[891] = "작업에는 스크롤 가능한 ResultSet이 필요하지만 이 ResultSet은 FORWARD_ONLY입니다.";
    t[892] = "Tried to read from inactive copy";
    t[893] = "비활성 복사에서 읽기를 시도했습니다.";
    t[898] = "A connection could not be made using the requested protocol {0}.";
    t[899] = "요청된 프로토콜 {0} 을(를) 사용하여 연결할 수 없습니다.";
    t[902] = "The maximum field size must be a value greater than or equal to 0.";
    t[903] = "최대 필드 크기는 0보다 크거나 같아야 합니다.";
    t[908] = "Could not open SSL root certificate file {0}.";
    t[909] = "SSL 루트 인증서 파일 {0} 을(를) 열 수 없습니다.";
    t[912] = "Error loading default settings from driverconfig.properties";
    t[913] = "driverconfig.properties에서 기본 설정을 로드하는 중 오류 발생";
    t[914] = "{0} function takes two and only two arguments.";
    t[915] = "{0} 함수는 두 개의 인수만 받습니다.";
    t[918] = "Unknown ResultSet holdability setting: {0}.";
    t[919] = "알 수 없는 ResultSet 유지 가능성 설정: {0}.";
    t[920] = "The JVM claims not to support the {0} encoding.";
    t[921] = "JVM이 {0} 인코딩을 지원하지 않는다고 주장합니다.";
    t[932] = "The server does not support SSL.";
    t[933] = "서버가 SSL을 지원하지 않습니다.";
    t[934] = "Provided InputStream failed.";
    t[935] = "제공된 InputStream이 실패했습니다.";
    t[946] = "No X509TrustManager found";
    t[947] = "X509TrustManager를 찾을 수 없습니다.";
    t[948] = "Connection attempt timed out.";
    t[949] = "연결 시도가 시간 초과되었습니다.";
    t[950] = "A CallableStatement was declared, but no call to registerOutParameter(1, <some type>) was made.";
    t[951] = "CallableStatement가 선언되었지만 registerOutParameter(1, <some type>) 호출이 이루어지지 않았습니다.";
    t[954] = "Can not write data to large object {0}, requested write length: {1}";
    t[955] = "대형 객체 {0} 에 데이터를 쓸 수 없습니다. 요청된 쓰기 길이: {1}";
    t[956] = "Can not read data from large object {0}, position: {1}, buffer size: {2}";
    t[957] = "대형 객체 {0} 에서 데이터를 읽을 수 없습니다. 위치: {1}, 버퍼 크기: {2}";
    t[958] = "Could not read SSL key file {0}.";
    t[959] = "SSL 키 파일 {0} 을(를) 읽을 수 없습니다.";
    t[964] = "ClientInfo property not supported.";
    t[965] = "ClientInfo 속성이 지원되지 않습니다.";
    t[966] = "Can''t use executeWithFlags(int) on a Statement.";
    t[967] = "문에서 executeWithFlags(int)를 사용할 수 없습니다.";
    t[970] = "Unknown Response Type {0}.";
    t[971] = "알 수 없는 응답 유형 {0}.";
    t[976] = "Unable to find resource {0} via Thread contextClassLoader {1}";
    t[977] = "스레드 contextClassLoader {1} 을(를) 통해 리소스 {0} 을(를) 찾을 수 없습니다.";
    t[986] = "Could not instantiate xmlFactoryFactory: {0}";
    t[987] = "xmlFactoryFactory를 인스턴스화할 수 없습니다: {0}";
    t[988] = "Truncation of large objects is only implemented in 8.3 and later servers.";
    t[989] = "대형 객체의 잘림은 8.3 이후의 서버에서만 구현됩니다.";
    t[996] = "Unsupported binary encoding of {0}.";
    t[997] = "{0} 의 지원되지 않는 이진 인코딩.";
    t[998] = "Unexpected error writing large object to database.";
    t[999] = "데이터베이스에 대형 객체를 쓰는 동안 예상치 못한 오류가 발생했습니다.";
    t[1004] = "Can''t refresh the insert row.";
    t[1005] = "삽입 행을 새로 고칠 수 없습니다.";
    t[1008] = "ResultSet not positioned properly, perhaps you need to call next.";
    t[1009] = "ResultSet이 올바르게 위치하지 않았습니다. 아마도 next를 호출해야 할 것입니다.";
    t[1016] = "Server SQLState: {0}";
    t[1017] = "서버 SQL 상태: {0}";
    t[1022] = "Cannot call cancelRowUpdates() when on the insert row.";
    t[1023] = "삽입 행에 있는 동안 cancelRowUpdates()를 호출할 수 없습니다.";
    t[1032] = "The hostname {0} could not be verified by hostnameverifier {1}.";
    t[1033] = "hostnameverifier {1} 이(가) 호스트 이름 {0}을(를) 확인할 수 없습니다.";
    t[1034] = "{0} function takes two or three arguments.";
    t[1035] = "{0} 함수는 두 개 또는 세 개의 인수를 받습니다.";
    t[1044] = "Unable to determine a value for DefaultTransactionIsolation due to missing  entry in pg_catalog.pg_settings WHERE name='default_transaction_isolation'.";
    t[1045] = "pg_catalog.pg_settings에 name='default_transaction_isolation' 항목이 누락되어 DefaultTransactionIsolation 값을 결정할 수 없습니다.";
    t[1058] = "SHOW password_encryption returned null value";
    t[1059] = "SHOW password_encryption이 null 값을 반환했습니다.";
    t[1060] = "Invalid sslmode value: {0}";
    t[1061] = "잘못된 sslmode 값: {0}";
    t[1072] = "Object is too large to send over the protocol.";
    t[1073] = "객체가 프로토콜을 통해 보내기에는 너무 큽니다.";
    t[1076] = "Prepare must be issued on the connection that started the branch. Transaction interleaving is not supported. prepare xid={0}, currentXid={1}";
    t[1077] = "Prepare는 분기를 시작한 연결에서 발행해야 합니다. 트랜잭션 교차는 지원되지 않습니다. prepare xid={0}, currentXid={1}";
    t[1082] = "Invalid targetServerType value: {0}";
    t[1083] = "잘못된 targetServerType 값: {0}";
    t[1086] = "Cannot rollback when autoCommit is enabled.";
    t[1087] = "autoCommit이 활성화된 상태에서 롤백할 수 없습니다.";
    t[1088] = "Fastpath call {0} - No result was returned and we expected a long.";
    t[1089] = "Fastpath 호출 {0} - 결과가 반환되지 않았고 long을 예상했습니다.";
    t[1090] = "The password callback class provided {0} could not be instantiated.";
    t[1091] = "제공된 비밀번호 콜백 클래스 {0} 을(를) 인스턴스화할 수 없습니다.";
    t[1092] = "wasNull cannot be call before fetching a result.";
    t[1093] = "wasNull은 결과를 가져오기 전에 호출할 수 없습니다.";
    t[1094] = "One or more ClientInfo failed.";
    t[1095] = "하나 이상의 ClientInfo가 실패했습니다.";
    t[1098] = "Network timeout must be a value greater than or equal to 0.";
    t[1099] = "네트워크 시간 초과는 0보다 크거나 같아야 합니다.";
    t[1106] = "Invalid protocol state requested. Attempted transaction interleaving is not supported. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[1107] = "잘못된 프로토콜 상태 요청됨. 트랜잭션 교차 시도는 지원되지 않습니다. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[1110] = "Conversion to type {0} failed: {1}.";
    t[1111] = "유형 {0} 으로 변환 실패: {1}.";
    t[1114] = "There are no rows in this ResultSet.";
    t[1115] = "이 ResultSet에는 행이 없습니다.";
    t[1116] = " (pgjdbc: autodetected server-encoding to be {0}, if the message is not readable, please check database logs and/or host, port, dbname, user, password, pg_hba.conf)";
    t[1117] = "(pgjdbc: 서버 인코딩이 {0} (으)로 자동 감지되었습니다. 메시지를 읽을 수 없는 경우 데이터베이스 로그 및/또는 호스트, 포트, dbname, 사용자, 비밀번호, pg_hba.conf를 확인하십시오.)";
    t[1124] = "Unable to convert bytea parameter at position {0} to literal";
    t[1125] = "위치 {0} 의 bytea 매개 변수를 리터럴로 변환할 수 없습니다.";
    t[1130] = "SSL error: {0}";
    t[1131] = "SSL 오류: {0}";
    t[1136] = "Unable to close connection properly";
    t[1137] = "연결을 올바르게 닫을 수 없습니다.";
    t[1140] = "The server''s client_encoding parameter was changed to {0}. The JDBC driver requires client_encoding to be UTF8 for correct operation.";
    t[1141] = "서버의 client_encoding 매개 변수가 {0} 으로 변경되었습니다. JDBC 드라이버는 올바른 작동을 위해 client_encoding이 UTF8이어야 합니다.";
    t[1144] = "Received CommandComplete ''{0}'' without an active copy operation";
    t[1145] = "활성 복사 작업 없이 CommandComplete ''{0}'' 을(를) 받았습니다.";
    t[1146] = "Cannot convert an instance of {0} to type {1}";
    t[1147] = "{0} 의 인스턴스를 유형 {1} (으)로 변환할 수 없습니다.";
    t[1148] = "end() called without a matching start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[1149] = "일치하는 start() 호출 없이 end()가 호출되었습니다. end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[1150] = "Can''t use query methods that take a query string on a PreparedStatement.";
    t[1151] = "PreparedStatement에서 쿼리 문자열을 사용하는 쿼리 메서드를 사용할 수 없습니다.";
    t[1152] = "ResultSets with concurrency CONCUR_READ_ONLY cannot be updated.";
    t[1153] = "동시성 CONCUR_READ_ONLY를 가진 ResultSet은 업데이트할 수 없습니다.";
    t[1154] = "COPY commands are only supported using the CopyManager API.";
    t[1155] = "COPY 명령은 CopyManager API를 사용하여서만 지원됩니다.";
    t[1158] = "One-phase commit with unknown xid. commit xid={0}, currentXid={1}";
    t[1159] = "알 수 없는 xid와 1단계 커밋. commit xid={0}, currentXid={1}";
    t[1170] = "Connection has been closed.";
    t[1171] = "연결이 닫혔습니다.";
    t[1172] = "The server requested SCRAM-based authentication, but no password was provided.";
    t[1173] = "서버가 SCRAM 기반 인증을 요청했지만, 비밀번호가 제공되지 않았습니다.";
    t[1176] = "CopyIn copy direction can't receive data";
    t[1177] = "CopyIn 복사 방향은 데이터를 수신할 수 없습니다.";
    t[1180] = "A CallableStatement was executed with nothing returned.";
    t[1181] = "CallableStatement가 실행되었으나 반환된 값이 없습니다.";
    t[1190] = "Results cannot be retrieved from a CallableStatement before it is executed.";
    t[1191] = "CallableStatement가 실행되기 전에 결과를 검색할 수 없습니다.";
    t[1192] = "Loading the SSL root certificate {0} into a TrustManager failed.";
    t[1193] = "SSL 루트 인증서 {0} 을(를) TrustManager로 로드하지 못했습니다.";
    t[1200] = "Error rolling back transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[1201] = "트랜잭션을 롤백하는 중 오류가 발생했습니다. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[1206] = "Failed to set ClientInfo property: {0}";
    t[1207] = "ClientInfo 속성 설정 실패: {0}";
    t[1208] = "Neither Subject.doAs (Java before 18) nor Subject.callAs (Java 18+) method found";
    t[1209] = "Subject.doAs (Java 18 이전) 또는 Subject.callAs (Java 18+) 메서드가 발견되지 않았습니다.";
    t[1216] = "Bad value for type {0} : {1}";
    t[1217] = "유형 {0} 에 대한 잘못된 값: {1}";
    t[1218] = "Provided Reader failed.";
    t[1219] = "제공된 Reader가 실패했습니다.";
    t[1222] = "Unable to find pkcs12 keystore.";
    t[1223] = "pkcs12 키 저장소를 찾을 수 없습니다.";
    t[1228] = "Returning autogenerated keys is not supported.";
    t[1229] = "자동 생성된 키 반환이 지원되지 않습니다.";
    t[1236] = "Cannot 2nd phase commit prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. commit xid={0}, transactionState={1}";
    t[1237] = "이 연결에서 로컬 트랜잭션이 진행 중인 동안에는 준비된 트랜잭션의 2단계 커밋을 수행할 수 없습니다. 먼저 로컬 트랜잭션을 커밋하거나 롤백하십시오. commit xid={0}, transactionState={1}";
    t[1238] = "Error releasing savepoint";
    t[1239] = "세이브포인트 해제 오류";
    t[1240] = "Unsupported Types value: {0}";
    t[1241] = "지원되지 않는 유형 값: {0}";
    t[1242] = "The environment variable containing the server's SSL certificate must not be empty.";
    t[1243] = "서버의 SSL 인증서를 포함하는 환경 변수는 비어 있을 수 없습니다.";
    t[1244] = "Unknown value for ResultSet holdability";
    t[1245] = "ResultSet 유지 가능성에 대한 알 수 없는 값입니다.";
    t[1246] = "Tried to obtain lock while already holding it";
    t[1247] = "이미 잠금을 보유한 상태에서 잠금을 얻으려고 시도했습니다.";
    t[1250] = "Fastpath call {0} - No result was returned and we expected an integer.";
    t[1251] = "Fastpath 호출 {0} - 결과가 반환되지 않았고 정수를 예상했습니다.";
    t[1254] = "Cannot retrieve the id of a named savepoint.";
    t[1255] = "이름이 지정된 세이브포인트의 ID를 검색할 수 없습니다.";
    t[1256] = "Cannot commit when autoCommit is enabled.";
    t[1257] = "autoCommit이 활성화된 상태에서 커밋할 수 없습니다.";
    t[1260] = "Could not read SSL root certificate file {0}.";
    t[1261] = "SSL 루트 인증서 파일 {0} 을(를) 읽을 수 없습니다.";
    t[1270] = "Unsupported type conversion to {0}.";
    t[1271] = "{0} 으로의 지원되지 않는 유형 변환.";
    t[1272] = "Unable to translate data into the desired encoding.";
    t[1273] = "데이터를 원하는 인코딩으로 변환할 수 없습니다.";
    t[1274] = "Database cannot be null";
    t[1275] = "데이터베이스는 null일 수 없습니다.";
    t[1276] = "PGStream is closed";
    t[1277] = "PGStream이 닫혔습니다.";
    t[1282] = "An error occurred reading the certificate";
    t[1283] = "인증서를 읽는 동안 오류가 발생했습니다.";
    t[1286] = "Fastpath call {0} - No result was returned or wrong size while expecting an integer.";
    t[1287] = "Fastpath 호출 {0} - 결과가 반환되지 않았거나 정수를 예상하는 동안 잘못된 크기입니다.";
    t[1290] = "Unable to instantiate SecBufferDesc, so SSPI is unavailable";
    t[1291] = "SecBufferDesc을 인스턴스화할 수 없어 SSPI를 사용할 수 없습니다.";
    t[1296] = "Unable to decode xml data.";
    t[1297] = "xml 데이터를 디코딩할 수 없습니다.";
    t[1298] = "This replication stream has been closed.";
    t[1299] = "이 복제 스트림은 닫혔습니다.";
    t[1300] = "Bad value for type timestamp/date/time: {0}";
    t[1301] = "유형 타임스탬프/날짜/시간에 대한 잘못된 값: {0}";
    t[1302] = "Invalid flags {0}";
    t[1303] = "잘못된 플래그 {0}";
    t[1306] = "Loading the SSL certificate {0} into a KeyManager failed.";
    t[1307] = "SSL 인증서 {0} 을(를) KeyManager로 로드하지 못했습니다.";
    t[1308] = "commit() called before end(). commit xid={0}, state={1}";
    t[1309] = "end() 호출 전에 commit()이 호출되었습니다. commit xid={0}, state={1}";
    t[1310] = "Server does not support temporary replication slots";
    t[1311] = "서버가 임시 복제 슬롯을 지원하지 않습니다.";
    t[1312] = "GSS Authentication failed";
    t[1313] = "GSS 인증 실패";
    t[1316] = "Expected an EOF from server, got: {0}";
    t[1317] = "서버로부터 EOF를 기대했지만, 대신: {0} 을(를) 받았습니다.";
    t[1322] = "Could not open SSL certificate file {0}.";
    t[1323] = "SSL 인증서 파일 {0} 을(를) 열 수 없습니다.";
    t[1324] = "{0} function takes three and only three arguments.";
    t[1325] = "{0} 함수는 세 개의 인수만 받습니다.";
    t[1328] = "Cannot write to copy a byte of value {0}";
    t[1329] = "값 {0} 의 바이트를 복사에 쓸 수 없습니다.";
    t[1330] = "An I/O error occurred while sending to the backend.";
    t[1331] = "백엔드로 전송하는 동안 I/O 오류가 발생했습니다.";
    t[1334] = "Cannot rollback prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. rollback xid={0}, transactionState={1}";
    t[1335] = "이 연결에서 로컬 트랜잭션이 진행 중인 동안에는 준비된 트랜잭션을 롤백할 수 없습니다. 먼저 로컬 트랜잭션을 커밋하거나 롤백하십시오. rollback xid={0}, transactionState={1}";
    t[1338] = "Multiple ResultSets were returned by the query.";
    t[1339] = "쿼리에서 여러 ResultSet이 반환되었습니다.";
    t[1342] = "Cannot change transaction isolation level in the middle of a transaction.";
    t[1343] = "트랜잭션 중간에 트랜잭션 격리 수준을 변경할 수 없습니다.";
    t[1352] = "Unable to load Authentication Plugin {0}";
    t[1353] = "인증 플러그인 {0} 을(를) 로드할 수 없습니다.";
    t[1354] = "The SocketFactory class provided {0} could not be instantiated.";
    t[1355] = "제공된 SocketFactory 클래스 {0} 을(를) 인스턴스화할 수 없습니다.";
    t[1356] = "2nd phase commit cannot be issued while an XA branch is active on this connection. commit xid={0}, currentXid={1}, state={2}";
    t[1357] = "이 연결에서 XA 분기가 활성 상태인 동안에는 2단계 커밋을 발행할 수 없습니다. commit xid={0}, currentXid={1}, state={2}";
    t[1358] = "Unable to create SAXResult for SQLXML.";
    t[1359] = "SQLXML에 대한 SAXResult를 생성할 수 없습니다.";
    t[1360] = "Not on the insert row.";
    t[1361] = "삽입 행에 있지 않습니다.";
    t[1362] = "Can not flush large object {0}";
    t[1363] = "대형 객체 {0} 을(를) 플러시할 수 없습니다.";
    t[1368] = "This ResultSet is closed.";
    t[1369] = "이 ResultSet은 닫혔습니다.";
    t[1370] = "An error occurred while setting up the GSS Encoded connection.";
    t[1371] = "GSS 인코딩된 연결을 설정하는 동안 오류가 발생했습니다.";
    t[1374] = "PreparedStatement can have at most {0} parameters. Please consider using arrays, or splitting the query in several ones, or using COPY. Given query has {1} parameters";
    t[1375] = "PreparedStatement는 최대 {0} 개의 매개 변수를 가질 수 있습니다. 배열을 사용하거나 쿼리를 여러 개로 나누거나 COPY를 사용하는 것을 고려하십시오. 주어진 쿼리는 {1} 개의 매개 변수를 가집니다.";
    t[1376] = "Database connection failed when ending copy";
    t[1377] = "복사를 종료하는 동안 데이터베이스 연결 실패";
    t[1380] = "ResultSet is not updateable.  The query that generated this result set must select only one table, and must select all primary keys from that table. See the JDBC 2.1 API Specification, section 5.6 for more details.";
    t[1381] = "ResultSet은 업데이트할 수 없습니다. 이 결과 집합을 생성한 쿼리는 하나의 테이블만 선택해야 하며 해당 테이블의 모든 기본 키를 선택해야 합니다. 자세한 내용은 JDBC 2.1 API 명세서 섹션 5.6을 참조하십시오.";
    t[1386] = "{0} parameter value must be an integer but was: {1}";
    t[1387] = "{0} 매개 변수 값은 정수여야 하지만 실제로는: {1} 입니다.";
    t[1392] = "Cannot establish a savepoint in auto-commit mode.";
    t[1393] = "자동 커밋 모드에서는 세이브포인트를 설정할 수 없습니다.";
    t[1396] = "Unable to find server array type for provided name {0}.";
    t[1397] = "제공된 이름 {0} 에 대한 서버 배열 유형을 찾을 수 없습니다.";
    t[1400] = "StreamWrapper leak detected StreamWrapper.close() was not called. ";
    t[1401] = "StreamWrapper 누수가 감지되었습니다. StreamWrapper.close()가 호출되지 않았습니다.";
    t[1402] = "Tried to write to an inactive copy operation";
    t[1403] = "비활성 복사 작업에 쓰기를 시도했습니다.";
    t[1404] = "Custom type maps are not supported.";
    t[1405] = "사용자 정의 유형 맵은 지원되지 않습니다.";
    t[1406] = "Bind message length {0} too long.  This can be caused by very large or incorrect length specifications on InputStream parameters.";
    t[1407] = "바인드 메시지 길이 {0} 이 너무 깁니다. 이는 매우 크거나 잘못된 길이 지정이 InputStream 매개 변수에 포함되어 있을 때 발생할 수 있습니다.";
    t[1412] = "Position: {0}";
    t[1413] = "위치: {0}";
    t[1414] = "Currently positioned after the end of the ResultSet.  You cannot call deleteRow() here.";
    t[1415] = "현재 ResultSet의 끝 이후에 위치해 있습니다. 여기에서 deleteRow()를 호출할 수 없습니다.";
    t[1422] = "xid must not be null";
    t[1423] = "xid는 null일 수 없습니다.";
    t[1428] = "No IOException expected from StringBuffer or StringBuilder";
    t[1429] = "StringBuffer 또는 StringBuilder에서 IOException이 발생하지 않았습니다.";
    t[1430] = "An error occurred while trying to reset the socket timeout.";
    t[1431] = "소켓 시간 초과를 재설정하는 동안 오류가 발생했습니다.";
    t[1436] = "Unable to parse X509Certificate for hostname {0}";
    t[1437] = "호스트 이름 {0} 에 대한 X509Certificate을(를) 구문 분석할 수 없습니다.";
    t[1438] = "Got CopyOutResponse from server during an active {0}";
    t[1439] = "활성 {0} 중 서버로부터 CopyOutResponse를 받았습니다.";
    t[1440] = "A CallableStatement function was executed and the out parameter {0} was of type {1} however type {2} was registered.";
    t[1441] = "CallableStatement 함수가 실행되었고 out 매개 변수 {0} 의 유형이 {1} 이었지만 유형 {2} 가 등록되었습니다.";
    t[1442] = "Got {0} error responses to single copy cancel request";
    t[1443] = "단일 복사 취소 요청에 대해 {0} 오류 응답을 받았습니다.";
    t[1460] = "Your security policy has prevented the connection from being attempted.  You probably need to grant the connect java.net.SocketPermission to the database server host and port that you wish to connect to.";
    t[1461] = "보안 정책으로 인해 연결을 시도할 수 없습니다. 데이터베이스 서버 호스트와 연결하고자 하는 포트에 java.net.SocketPermission 연결 권한을 부여해야 할 것입니다.";
    t[1462] = "Properties for the driver contains a non-string value for the key {0}";
    t[1463] = "드라이버의 속성에 문자열이 아닌 값이 포함되어 있습니다. 키: {0}";
    t[1472] = "Leak detected: Connection.close() was not called";
    t[1473] = "누출 감지됨: Connection.close()가 호출되지 않았습니다.";
    t[1476] = "Cannot reference a savepoint after it has been released.";
    t[1477] = "해제된 후에는 세이브포인트를 참조할 수 없습니다.";
    t[1486] = "Unknown XML Result class: {0}";
    t[1487] = "알 수 없는 XML 결과 클래스: {0}";
    t[1490] = "Unable to determine a value for MaxIndexKeys due to missing system catalog data.";
    t[1491] = "시스템 카탈로그 데이터가 누락되어 MaxIndexKeys 값을 결정할 수 없습니다.";
    table = t;
  }
  public java.lang.Object handleGetObject (java.lang.String msgid) throws java.util.MissingResourceException {
    int hash_val = msgid.hashCode() & 0x7fffffff;
    int idx = (hash_val % 751) << 1;
    {
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
    int incr = ((hash_val % 749) + 1) << 1;
    for (;;) {
      idx += incr;
      if (idx >= 1502)
        idx -= 1502;
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
  }
  public java.util.Enumeration getKeys () {
    return
      new java.util.Enumeration() {
        private int idx = 0;
        { while (idx < 1502 && table[idx] == null) idx += 2; }
        public boolean hasMoreElements () {
          return (idx < 1502);
        }
        public java.lang.Object nextElement () {
          java.lang.Object key = table[idx];
          do idx += 2; while (idx < 1502 && table[idx] == null);
          return key;
        }
      };
  }
  public java.util.ResourceBundle getParent () {
    return parent;
  }
}
