/* Automatically generated by GNU msgfmt.  Do not modify!  */
package org.postgresql.translation;
public class messages_it extends java.util.ResourceBundle {
  private static final java.lang.String[] table;
  static {
    java.lang.String[] t = new java.lang.String[1006];
    t[0] = "";
    t[1] = "Project-Id-Version: PostgreSQL JDBC Driver 8.2\nReport-Msgid-Bugs-To: \nPO-Revision-Date: 2006-06-23 17:25+0200\nLast-Translator: Giuseppe Sacco <eppesuig@debian.org>\nLanguage-Team: Italian <tp@lists.linux.it>\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\n";
    t[4] = "Database connection failed when writing to copy";
    t[5] = "La connessione al database è fallita durante la scrittura in «copy»";
    t[6] = "Bad value for type {0} : {1}";
    t[7] = "Il valore «{1}» non è adeguato al tipo «{0}».";
    t[8] = "Cannot retrieve the name of an unnamed savepoint.";
    t[9] = "Non è possibile trovare il nome di un punto di ripristino anonimo.";
    t[12] = "Cannot convert an instance of {0} to type {1}";
    t[13] = "Non è possibile convertire una istanza di «{0}» nel tipo «{1}»";
    t[14] = "Validating connection.";
    t[15] = "Verifica connessione.";
    t[22] = "Results cannot be retrieved from a CallableStatement before it is executed.";
    t[23] = "I «result» non possono essere letti da un «CallableStatement» prima che esso sia stato eseguito.";
    t[26] = "No results were returned by the query.";
    t[27] = "Nessun risultato è stato restituito dalla query.";
    t[34] = "Missing expected error response to copy cancel request";
    t[35] = "La richiesta di cancellazione «copy» non ha ritornato nessun messaggio di errore";
    t[36] = "Error during recover. flag={0}";
    t[37] = "Errore durante il ripristino. flag={0}";
    t[38] = "This statement has been closed.";
    t[39] = "Questo statement è stato chiuso.";
    t[40] = "Cannot retrieve the id of a named savepoint.";
    t[41] = "Non è possibile trovare l''id del punto di ripristino indicato.";
    t[42] = "Database connection failed when canceling copy operation";
    t[43] = "Connessione al database fallita durante la cancellazione dell'operazione di «copy»";
    t[48] = "No value specified for parameter {0}.";
    t[49] = "Nessun valore specificato come parametro {0}.";
    t[50] = "Error rolling back transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[51] = "Errore durante il rollback della transazione. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[54] = "Returning autogenerated keys is not supported.";
    t[55] = "La restituzione di chiavi autogenerate non è supportata.";
    t[60] = "wasNull cannot be call before fetching a result.";
    t[61] = "«wasNull» non può essere eseguito prima della lettura di un «result».";
    t[62] = "Prepare must be issued on the connection that started the branch. Transaction interleaving is not supported. prepare xid={0}, currentXid={1}";
    t[63] = "«Prepare» deve essere eseguito sulla connessione che ha avviato il ramo. L''interleaving delle transazioni non è supportato. prepare xid={0}, currentXid={1}";
    t[64] = "One-phase commit with unknown xid. commit xid={0}, currentXid={1}";
    t[65] = "Commit «one-phase» con xid sconosciuto. commit xid={0}, currentXid={1}";
    t[66] = "Connection attempt timed out.";
    t[67] = "Il tentativo di connessione è scaduto.";
    t[68] = "Cannot cast an instance of {0} to type {1}";
    t[69] = "Non è possibile fare il cast di una istanza di «{0}» al tipo «{1}».";
    t[72] = "A connection could not be made using the requested protocol {0}.";
    t[73] = "Non è stato possibile attivare la connessione utilizzando il protocollo richiesto {0}.";
    t[74] = "Loading the SSL certificate {0} into a KeyManager failed.";
    t[75] = "Impossibile caricare il certificato SSL {0} nel «KeyManager».";
    t[78] = "Could not open SSL root certificate file {0}.";
    t[79] = "Impossibile aprire il file di certificato root SSL {0}.";
    t[84] = "Invalid character data was found.  This is most likely caused by stored data containing characters that are invalid for the character set the database was created in.  The most common example of this is storing 8bit data in a SQL_ASCII database.";
    t[85] = "Sono stati trovati caratteri non validi tra i dati. Molto probabilmente sono stati memorizzati dei caratteri che non sono validi per la codifica dei caratteri impostata alla creazione del database. Il caso più diffuso è quello nel quale si memorizzano caratteri a 8bit in un database con codifica SQL_ASCII.";
    t[86] = "The array index is out of range: {0}";
    t[87] = "Indice di colonna fuori dall''intervallo ammissibile: {0}";
    t[90] = "Operation requires a scrollable ResultSet, but this ResultSet is FORWARD_ONLY.";
    t[91] = "L''operazione richiete un «ResultSet» scorribile mentre questo è «FORWARD_ONLY».";
    t[92] = "Got CopyData without an active copy operation";
    t[93] = "Ricevuto «CopyData» senza un'operazione «copy» attiva";
    t[96] = "PostgreSQL LOBs can only index to: {0}";
    t[97] = "Il massimo valore per l''indice dei LOB di PostgreSQL è {0}. ";
    t[100] = "Error committing prepared transaction. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[101] = "Errore durante il commit di una transazione preparata. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[102] = "No function outputs were registered.";
    t[103] = "Non è stato registrato alcun output di funzione.";
    t[108] = "{0} function doesn''t take any argument.";
    t[109] = "Il metodo «{0}» non accetta argomenti.";
    t[110] = "Prepare called before end(). prepare xid={0}, state={1}";
    t[111] = "«Prepare» invocato prima di end(). prepare xid={0}, state={1}";
    t[112] = "Currently positioned after the end of the ResultSet.  You cannot call deleteRow() here.";
    t[113] = "La posizione attuale è successiva alla fine del ResultSet. Non è possibile invocare «deleteRow()» qui.";
    t[118] = "Unexpected error writing large object to database.";
    t[119] = "Errore inatteso inviando un «large object» al database.";
    t[124] = "Multiple ResultSets were returned by the query.";
    t[125] = "La query ha restituito «ResultSet» multipli.";
    t[126] = "Got CopyInResponse from server during an active {0}";
    t[127] = "Ricevuto «CopyInResponse» dal server durante un {0} attivo";
    t[128] = "The fastpath function {0} is unknown.";
    t[129] = "La funzione fastpath «{0}» è sconosciuta.";
    t[132] = "This statement does not declare an OUT parameter.  Use '{' ?= call ... '}' to declare one.";
    t[133] = "Questo statement non dichiara il parametro in uscita. Usare «{ ?= call ... }» per farlo.";
    t[140] = "Parameter of type {0} was registered, but call to get{1} (sqltype={2}) was made.";
    t[141] = "È stato definito il parametro di tipo «{0}», ma poi è stato invocato il metodo «get{1}()» (sqltype={2}).";
    t[144] = "Query timeout must be a value greater than or equals to 0.";
    t[145] = "Il timeout relativo alle query deve essere maggiore o eguale a 0.";
    t[150] = "Bind message length {0} too long.  This can be caused by very large or incorrect length specifications on InputStream parameters.";
    t[151] = "Il messaggio di «bind» è troppo lungo ({0}). Questo può essere causato da una dimensione eccessiva o non corretta dei parametri dell''«InputStream».";
    t[152] = "An unexpected result was returned by a query.";
    t[153] = "Un risultato inaspettato è stato ricevuto dalla query.";
    t[154] = "Can''t use executeWithFlags(int) on a Statement.";
    t[155] = "Non è possibile usare «executeWithFlags(int)» su di una istruzione.";
    t[156] = "The column name {0} was not found in this ResultSet.";
    t[157] = "Colonna denominata «{0}» non è presente in questo «ResultSet».";
    t[160] = "Database connection failed when ending copy";
    t[161] = "La connessione al database è fallita durante la terminazione di «copy»";
    t[164] = "Conversion of interval failed";
    t[165] = "Fallita la conversione di un «interval».";
    t[166] = "Could not find a java cryptographic algorithm: X.509 CertificateFactory not available.";
    t[167] = "Impossibile trovare un algoritmo crittografico java: «X.509 CertificateFactory» non disponibile.";
    t[168] = "Truncation of large objects is only implemented in 8.3 and later servers.";
    t[169] = "La truncate dei large object è implementata soltanto per i server di versione 8.3 e successive.";
    t[174] = "Cannot rollback when autoCommit is enabled.";
    t[175] = "Il «rollback» non è possibile quando «autoCommit» è abilitato.";
    t[176] = "Transaction control methods setAutoCommit, commit, rollback and setSavepoint are not allowed while an XA transaction is active.";
    t[177] = "I metodi di controllo della transazione setAutoCommit, commit, rollback e setSavepoint non sono consentiti mentre una transazione XA è attiva.";
    t[178] = "Unable to load the class {0} responsible for the datatype {1}";
    t[179] = "Non è possibile caricare la class «{0}» per gestire il tipo «{1}».";
    t[184] = "Invalid stream length {0}.";
    t[185] = "La dimensione specificata, {0}, per lo «stream» non è valida.";
    t[188] = "The system property containing the server's SSL certificate must not be empty.";
    t[189] = "La variabile di sistema che contiene il certificato SSL del server non può essere vuota.";
    t[194] = "Current connection does not have an associated xid. prepare xid={0}";
    t[195] = "La connessione corrente non ha un xid associato. prepare xid={0}";
    t[198] = "Conversion of money failed.";
    t[199] = "Fallita la conversione di un «money».";
    t[204] = "Could not find a server with specified targetServerType: {0}";
    t[205] = "Non riesco a trovare un server con il «targetServerType» specificato: {0}";
    t[206] = "Unable to find name datatype in the system catalogs.";
    t[207] = "Non è possibile trovare il datatype «name» nel catalogo di sistema.";
    t[210] = "end() called without a matching start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[211] = "end() chiamato senza una corrispondente start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[218] = "Invalid flags {0}";
    t[219] = "Flag non validi {0}";
    t[222] = "Can''t use query methods that take a query string on a PreparedStatement.";
    t[223] = "Non si possono utilizzare i metodi \"query\" che hanno come argomento una stringa nel caso di «PreparedStatement».";
    t[224] = "Your security policy has prevented the connection from being attempted.  You probably need to grant the connect java.net.SocketPermission to the database server host and port that you wish to connect to.";
    t[225] = "Le impostazioni di sicurezza hanno impedito il tentativo di connessione. Probabilmente è necessario configurare «grant» affinché «java.net.SocketPermission» abbia il permesso di connettersi all'host del database server a cui ci si vuole connettere.";
    t[230] = "Error loading default settings from driverconfig.properties";
    t[231] = "Si è verificato un errore caricando le impostazioni predefinite da «driverconfig.properties».";
    t[232] = "ResultSet not positioned properly, perhaps you need to call next.";
    t[233] = "Il «ResultSet» non è correttamente posizionato; forse è necessario invocare «next()».";
    t[234] = "Large Objects may not be used in auto-commit mode.";
    t[235] = "Non è possibile impostare i «Large Object» in modalità «auto-commit».";
    t[236] = "Expected command status BEGIN, got {0}.";
    t[237] = "Lo stato del comando avrebbe dovuto essere BEGIN, mentre invece è {0}.";
    t[238] = "This SQLXML object has already been initialized, so you cannot manipulate it further.";
    t[239] = "Non è possibile manipolare l'oggetto «SQLXML» dopo che è stato inizializzato.";
    t[240] = "Unsupported value for stringtype parameter: {0}";
    t[241] = "Il valore per il parametro di tipo string «{0}» non è supportato.";
    t[244] = "Something unusual has occurred to cause the driver to fail. Please report this exception.";
    t[245] = "Qualcosa di insolito si è verificato causando il fallimento del driver. Per favore riferire all''autore del driver questa eccezione.";
    t[252] = "Connection is already associated with an active XA branch. End the current branch before starting a new one. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[253] = "La connessione è già associata a un ramo XA attivo. Terminare il ramo corrente prima di avviarne uno nuovo. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[256] = "{0} function takes three and only three arguments.";
    t[257] = "Il metodo «{0}» accetta tre e solo tre argomenti.";
    t[258] = "The sslfactoryarg property may not be empty.";
    t[259] = "La proprietà sslfactoryarg non deve essere vuota.";
    t[260] = "Suspend/resume not implemented";
    t[261] = "«Suspend»/«resume» non implementato";
    t[264] = "Conversion to type {0} failed: {1}.";
    t[265] = "Conversione al tipo {0} fallita: {1}.";
    t[272] = "{0} function takes two or three arguments.";
    t[273] = "Il metodo «{0}» accetta due o tre argomenti.";
    t[276] = "Database connection failed when reading from copy";
    t[277] = "La connessione al database è fallita durante la lettura da «copy»";
    t[282] = "Could not open SSL certificate file {0}.";
    t[283] = "Impossibile accedere al file di certificato SSL {0}.";
    t[286] = "The parameter index is out of range: {0}, number of parameters: {1}.";
    t[287] = "Il parametro indice è fuori intervallo: {0}, numero di elementi: {1}.";
    t[292] = "Statement has been closed.";
    t[293] = "Questo «Statement» è stato chiuso.";
    t[294] = "Connection has been closed automatically because a new connection was opened for the same PooledConnection or the PooledConnection has been closed.";
    t[295] = "La «Connection» è stata chiusa automaticamente perché una nuova l''ha sostituita nello stesso «PooledConnection», oppure il «PooledConnection» è stato chiuso.";
    t[296] = "Unexpected command status: {0}.";
    t[297] = "Stato del comando non previsto: {0}.";
    t[298] = "Cannot cast to boolean: \"{0}\"";
    t[299] = "Non è possibile convertire in booleano: \"{0}\"";
    t[306] = "Tried to break lock on database connection";
    t[307] = "Si è tentato di rimuovere il lock sulla connessione al database";
    t[308] = "Location: File: {0}, Routine: {1}, Line: {2}";
    t[309] = "Individuazione: file: \"{0}\", routine: {1}, linea: {2}";
    t[324] = "The server does not support SSL.";
    t[325] = "Il server non supporta SSL.";
    t[330] = "Unknown Types value.";
    t[331] = "Valore di tipo sconosciuto.";
    t[336] = "Cannot 2nd phase commit prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. commit xid={0}, transactionState={1}";
    t[337] = "Impossibile eseguire il commit di seconda fase di una transazione preparata mentre una transazione locale è in corso su questa connessione. Eseguire prima il commit o il rollback della transazione locale. commit xid={0}, transactionState={1}";
    t[340] = "Position: {0}";
    t[341] = "Posizione: {0}";
    t[354] = "Detail: {0}";
    t[355] = "Dettaglio: {0}";
    t[366] = "Failed to create object for: {0}.";
    t[367] = "Fallita la creazione dell''oggetto per: {0}.";
    t[368] = "Unknown ResultSet holdability setting: {0}.";
    t[369] = "Il parametro «holdability» per il «ResultSet» è sconosciuto: {0}.";
    t[376] = "Transaction isolation level {0} not supported.";
    t[377] = "Il livello di isolamento delle transazioni «{0}» non è supportato.";
    t[378] = "Unable to set network timeout.";
    t[379] = "Impossibile impostare il timeout di rete.";
    t[388] = "SSL error: {0}";
    t[389] = "Errore SSL: {0}";
    t[396] = "Provided Reader failed.";
    t[397] = "Il «Reader» fornito è fallito.";
    t[398] = "Cannot commit when autoCommit is enabled.";
    t[399] = "Il «commit» esplicito non è possibile quando «autoCommit» è abilitato.";
    t[400] = "An I/O error occurred while sending to the backend.";
    t[401] = "Si è verificato un errore di I/O nella spedizione di dati al server.";
    t[402] = "{0} parameter value must be an integer but was: {1}";
    t[403] = "Il valore del parametro {0} deve essere un numero intero, invece il suo valore è {1}";
    t[404] = "Cannot change transaction read-only property in the middle of a transaction.";
    t[405] = "Non è possibile modificare la proprietà «read-only» delle transazioni nel mezzo di una transazione.";
    t[408] = "Got CopyBothResponse from server during an active {0}";
    t[409] = "Ricevuto «CopyBothResponse» dal server durante un {0} attivo";
    t[414] = "Unexpected packet type during replication: {0}";
    t[415] = "Ricevuto «packet type» inaspettato durante replica: {0}";
    t[422] = "Cannot reference a savepoint after it has been released.";
    t[423] = "Non è possibile utilizzare un punto di ripristino successivamente al suo rilascio.";
    t[424] = "A result was returned when none was expected.";
    t[425] = "È stato restituito un valore nonostante non ne fosse atteso nessuno.";
    t[430] = "Fetch size must be a value greater than or equal to 0.";
    t[431] = "La dimensione dell''area di «fetch» deve essere maggiore o eguale a 0.";
    t[434] = "Not on the insert row.";
    t[435] = "Non si è in una nuova riga.";
    t[436] = "No IOException expected from StringBuffer or StringBuilder";
    t[437] = "Errore «IOException» inaspettato generato dalla classe «StringBuffer» o «StringBuilder»";
    t[442] = "Provided InputStream failed.";
    t[443] = "L''«InputStream» fornito è fallito.";
    t[450] = "Unable to find server array type for provided name {0}.";
    t[451] = "Il tipo array {0} non è presente sul server.";
    t[452] = "ResultSets with concurrency CONCUR_READ_ONLY cannot be updated.";
    t[453] = "I «ResultSet» in modalità CONCUR_READ_ONLY non possono essere aggiornati.";
    t[454] = "Cannot call deleteRow() when on the insert row.";
    t[455] = "Non è possibile invocare «deleteRow()» durante l''inserimento di una riga.";
    t[458] = "GSS Authentication failed";
    t[459] = "Autenticazione «GSS» fallita";
    t[468] = "This PooledConnection has already been closed.";
    t[469] = "Questo «PooledConnection» è stato chiuso.";
    t[470] = "Got {0} error responses to single copy cancel request";
    t[471] = "Ricevute {0} risposte di errore a una singola richiesta di cancellazione «copy»";
    t[476] = "ResultSet is not updateable.  The query that generated this result set must select only one table, and must select all primary keys from that table. See the JDBC 2.1 API Specification, section 5.6 for more details.";
    t[477] = "Il «ResultSet» non è aggiornabile. La query che lo genera deve selezionare una sola tabella e deve selezionarne tutti i campi che ne compongono la chiave primaria. Si vedano le specifiche dell''API JDBC 2.1, sezione 5.6, per ulteriori dettagli.";
    t[478] = "Requested CopyDual but got {0}";
    t[479] = "Era richiesto «CopyDual» ma si è ottenuto {0}";
    t[480] = "Too many update results were returned.";
    t[481] = "Sono stati restituiti troppi aggiornamenti.";
    t[494] = "Unable to get network timeout.";
    t[495] = "Impossibile leggere il timeout di rete.";
    t[500] = "Unknown type {0}.";
    t[501] = "Tipo sconosciuto {0}.";
    t[502] = "A CallableStatement was declared, but no call to registerOutParameter(1, <some type>) was made.";
    t[503] = "È stato definito un «CallableStatement» ma non è stato invocato il metodo «registerOutParameter(1, <tipo>)».";
    t[522] = "Tried to cancel an inactive copy operation";
    t[523] = "Si è tentato di cancellare una operazione di «copy» inattiva";
    t[524] = "Protocol error.  Session setup failed.";
    t[525] = "Errore di protocollo. Impostazione della sessione fallita.";
    t[528] = "Internal Query: {0}";
    t[529] = "Query interna: {0}";
    t[530] = "Unknown Response Type {0}.";
    t[531] = "Risposta di tipo sconosciuto {0}.";
    t[538] = "Ran out of memory retrieving query results.";
    t[539] = "Fine memoria scaricando i risultati della query.";
    t[546] = "Unknown XML Source class: {0}";
    t[547] = "Classe sorgente XML sconosciuta: {0}";
    t[556] = "A CallableStatement function was executed and the out parameter {0} was of type {1} however type {2} was registered.";
    t[557] = "È stato eseguito un «CallableStatement» ma il parametro in uscita «{0}» era di tipo «{1}» al posto di «{2}», che era stato dichiarato.";
    t[558] = "The hostname {0} could not be verified by hostnameverifier {1}.";
    t[559] = "L''hostnameverifier {1} non è in grado di verificare l''hostname {0}.";
    t[568] = "{0} function takes two and only two arguments.";
    t[569] = "Il metodo «{0}» accetta due e solo due argomenti.";
    t[570] = "The sslfactoryarg property must start with the prefix file:, classpath:, env:, sys:, or -----BEGIN CERTIFICATE-----.";
    t[571] = "La proprietà sslfactoryarg deve iniziare con uno dei seguenti prefissi, file:, classpath:, env:, sys:, oppure -----BEGIN CERTIFICATE-----.";
    t[584] = "Method {0} is not yet implemented.";
    t[585] = "Il metodo «{0}» non è stato ancora implementato.";
    t[594] = " (pgjdbc: autodetected server-encoding to be {0}, if the message is not readable, please check database logs and/or host, port, dbname, user, password, pg_hba.conf)";
    t[595] = "(pgjdbc: l''encoding del server rilevato automaticamente è {0}. Se il messaggio non è leggibile verificare i log del database, i parametri host, port, dbname, user, password oppure il file pg_hba.conf )";
    t[600] = "Tried to obtain lock while already holding it";
    t[601] = "Si è tentato di ottenere un lock ma era già stato ottenuto";
    t[608] = "Currently positioned before the start of the ResultSet.  You cannot call deleteRow() here.";
    t[609] = "La posizione attuale è precedente all''inizio del ResultSet. Non è possibile invocare «deleteRow()» qui.";
    t[610] = "Where: {0}";
    t[611] = "Dove: {0}";
    t[614] = "{0} function takes four and only four argument.";
    t[615] = "Il metodo «{0}» accetta quattro e solo quattro argomenti.";
    t[622] = "Interval {0} not yet implemented";
    t[623] = "L''intervallo «{0}» non è stato ancora implementato.";
    t[630] = "Unable to decode xml data.";
    t[631] = "Impossibile decodificare i dati xml.";
    t[634] = "Interrupted while attempting to connect.";
    t[635] = "Si è verificata una interruzione durante il tentativo di connessione.";
    t[640] = "Could not read SSL key file {0}.";
    t[641] = "Impossibile leggere il file di chiave SSL {0}.";
    t[644] = "The environment variable containing the server's SSL certificate must not be empty.";
    t[645] = "La variabile d''ambiente che contiene il certificato SSL del server non può essere vuota.";
    t[646] = "Can''t refresh the insert row.";
    t[647] = "Non è possibile aggiornare la riga in inserimento.";
    t[652] = "Tried to end inactive copy";
    t[653] = "Si è tentato di terminare una «copy» inattiva";
    t[654] = "The server''s DateStyle parameter was changed to {0}. The JDBC driver requires DateStyle to begin with ISO for correct operation.";
    t[655] = "Il parametro del server «DateStyle» è stato cambiato in {0}. Il driver JDBC richiede che «DateStyle» cominci con «ISO» per un corretto funzionamento.";
    t[656] = "Error preparing transaction. prepare xid={0}";
    t[657] = "Errore nella preparazione della transazione. prepare xid={0}";
    t[662] = "Unable to convert DOMResult SQLXML data to a string.";
    t[663] = "Impossibile convertire i dati «DOMResult SQLXML» in stringa.";
    t[664] = "Read from copy failed.";
    t[665] = "Lettura da «copy» fallita.";
    t[672] = "The column index is out of range: {0}, number of columns: {1}.";
    t[673] = "Indice di colonna, {0}, è maggiore del numero di colonne {1}.";
    t[682] = "Fastpath call {0} - No result was returned and we expected an integer.";
    t[683] = "Chiamata Fastpath «{0}»: Nessun risultato restituito mentre ci si aspettava un intero.";
    t[696] = "Could not find a java cryptographic algorithm: {0}.";
    t[697] = "Impossibile determinare l''algoritmo crittografico java: {0}";
    t[700] = "free() was called on this LOB previously";
    t[701] = "«free()» è già stata eseguita su questo LOB in precedenza";
    t[704] = "The JVM claims not to support the encoding: {0}";
    t[705] = "La JVM sostiene di non supportare la codifica: {0}.";
    t[708] = "Unable to bind parameter values for statement.";
    t[709] = "Impossibile fare il «bind» dei valori passati come parametri per lo statement.";
    t[712] = "The connection attempt failed.";
    t[713] = "Il tentativo di connessione è fallito.";
    t[718] = "commit() called before end(). commit xid={0}, state={1}";
    t[719] = "commit() invocato prima di end(). commit xid={0}, state={1}";
    t[730] = "Expected an EOF from server, got: {0}";
    t[731] = "Ricevuto dal server «{0}» mentre era atteso un EOF";
    t[734] = "{0} function takes one and only one argument.";
    t[735] = "Il metodo «{0}» accetta un ed un solo argomento.";
    t[736] = "Tried to read from inactive copy";
    t[737] = "Tentativo di lettura da «copy» inattiva";
    t[738] = "Tried to write to an inactive copy operation";
    t[739] = "C'è stato un tentativo di scrittura su di una operazione «copy» inattiva";
    t[740] = "Invalid protocol state requested. Attempted transaction interleaving is not supported. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[741] = "Stato del protocollo richiesto non valido. Il tentativo di interlacciamento transazioni non è supportato. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[746] = "Zero bytes may not occur in string parameters.";
    t[747] = "Byte con valore zero non possono essere contenuti nei parametri stringa.";
    t[752] = "Loading the SSL root certificate {0} into a TrustManager failed.";
    t[753] = "Il caricamento del certificato SSL root {0} in «TrustManager» è fallito.";
    t[758] = "The SSLSocketFactory class provided {0} could not be instantiated.";
    t[759] = "La classe «SSLSocketFactory» specificata, «{0}», non può essere istanziata.";
    t[762] = "Heuristic commit/rollback not supported. forget xid={0}";
    t[763] = "«Commit»/«rollback» euristico non supportato. forget xid={0}";
    t[766] = "You must specify at least one column value to insert a row.";
    t[767] = "Per inserire un record si deve specificare almeno il valore di una colonna.";
    t[768] = "xid must not be null";
    t[769] = "xid non può essere NULL";
    t[774] = "Error during one-phase commit. commit xid={0}";
    t[775] = "Errore durante il commit «one-phase». commit xid={0}";
    t[776] = "The JVM claims not to support the {0} encoding.";
    t[777] = "La JVM sostiene di non supportare la codifica {0}.";
    t[782] = "Object is too large to send over the protocol.";
    t[783] = "Le dimensioni dell'oggetto sono troppo grandi per la trasmissione attraverso il protocollo.";
    t[786] = "Internal Position: {0}";
    t[787] = "Posizione interna: {0}";
    t[788] = "2nd phase commit cannot be issued while an XA branch is active on this connection. commit xid={0}, currentXid={1}, state={2}";
    t[789] = "Il commit di seconda fase non può essere eseguito mentre un ramo XA è attivo su questa connessione. commit xid={0}, currentXid={1}, state={2}";
    t[790] = "One or more ClientInfo failed.";
    t[791] = "Una o più operazioni «ClientInfo» sono fallite.";
    t[792] = "Error opening transaction. start xid={0}";
    t[793] = "Errore nell''apertura della transazione. start xid={0}";
    t[800] = "Failed to setup DataSource.";
    t[801] = "Configurazione «DataSource» fallita.";
    t[802] = "Cannot call cancelRowUpdates() when on the insert row.";
    t[803] = "Non è possibile invocare «cancelRowUpdates()» durante l''inserimento di una riga.";
    t[806] = "Unexpected packet type during copy: {0}";
    t[807] = "Ricevuto «packet type» inaspettato durante operazione «copy»: {0}";
    t[816] = "Cannot tell if path is open or closed: {0}.";
    t[817] = "Impossibile stabilire se il percorso è aperto o chiuso: {0}.";
    t[826] = "Enter SSL password: ";
    t[827] = "Inserire la password SSL: ";
    t[828] = "Could not decrypt SSL key file {0}.";
    t[829] = "Impossibile decriptare il file di chiave SSL {0}.";
    t[830] = "Could not initialize SSL context.";
    t[831] = "Impossibile inizializzare il contesto SSL.";
    t[834] = "A CallableStatement was executed with nothing returned.";
    t[835] = "Un «CallableStatement» è stato eseguito senza produrre alcun risultato. ";
    t[838] = "The authentication type {0} is not supported. Check that you have configured the pg_hba.conf file to include the client''s IP address or subnet, and that it is using an authentication scheme supported by the driver.";
    t[839] = "L''autenticazione di tipo {0} non è supportata. Verificare che nel file di configurazione pg_hba.conf sia presente l''indirizzo IP o la sottorete del client, e che lo schema di autenticazione utilizzato sia supportato dal driver.";
    t[840] = "Cannot write to copy a byte of value {0}";
    t[841] = "Impossibile scrivere in «copy» un byte il cui valore è {0}";
    t[846] = "Can''t infer the SQL type to use for an instance of {0}. Use setObject() with an explicit Types value to specify the type to use.";
    t[847] = "Non è possibile identificare il tipo SQL da usare per l''istanza di tipo «{0}». Usare «setObject()» specificando esplicitamente il tipo da usare per questo valore.";
    t[856] = "Custom type maps are not supported.";
    t[857] = "Le «type map» customizzate non sono supportate.";
    t[858] = "Can''t use relative move methods while on the insert row.";
    t[859] = "Non è possibile utilizzare gli spostamenti relativi durante l''inserimento di una riga.";
    t[860] = "LOB positioning offsets start at 1.";
    t[861] = "L''offset per la posizione dei LOB comincia da 1.";
    t[868] = "Connection has been closed.";
    t[869] = "Questo «Connection» è stato chiuso.";
    t[874] = "This ResultSet is closed.";
    t[875] = "Questo «ResultSet» è chiuso.";
    t[876] = "An error occurred while setting up the SSL connection.";
    t[877] = "Si è verificato un errore impostando la connessione SSL.";
    t[884] = "Unsupported Types value: {0}";
    t[885] = "Valore di tipo «{0}» non supportato.";
    t[888] = "Unable to create StAXResult for SQLXML";
    t[889] = "Impossibile creare «StAXResult» per «SQLXML»";
    t[890] = "Cannot change transaction isolation level in the middle of a transaction.";
    t[891] = "Non è possibile cambiare il livello di isolamento delle transazioni nel mezzo di una transazione.";
    t[892] = "Cannot update the ResultSet because it is either before the start or after the end of the results.";
    t[893] = "Non è possibile aggiornare il «ResultSet» perché la posizione attuale è precedente all''inizio o successiva alla file dei risultati.";
    t[894] = "Could not read password for SSL key file, console is not available.";
    t[895] = "Impossibile leggere la password del file di chiave SSL, console non disponibile.";
    t[898] = "Premature end of input stream, expected {0} bytes, but only read {1}.";
    t[899] = "Il flusso di input è stato interrotto, sono arrivati {1} byte al posto dei {0} attesi.";
    t[902] = "oid type {0} not known and not a number";
    t[903] = "Lo oid {0} è di tipo sconosciuto oppure non è numerico";
    t[904] = "Cannot call updateRow() when on the insert row.";
    t[905] = "Non è possibile invocare «updateRow()» durante l''inserimento di una riga.";
    t[910] = "Invalid fetch direction constant: {0}.";
    t[911] = "Costante per la direzione dell''estrazione non valida: {0}.";
    t[918] = "Requested CopyIn but got {0}";
    t[919] = "Era richiesto «CopyIn» ma si è ottenuto {0}";
    t[926] = "Got CopyOutResponse from server during an active {0}";
    t[927] = "Ricevuto «CopyOutResponse» dal server durante un {0} attivo";
    t[932] = "No hstore extension installed.";
    t[933] = "L'estensione hstore non è installata sul server.";
    t[934] = "No X509TrustManager found";
    t[935] = "Impossibile trovare «X509TrustManager»";
    t[938] = "Received CommandComplete ''{0}'' without an active copy operation";
    t[939] = "É stato ricevuto un «CommandComplete» ''{0}'' senza un'operazione «copy» attiva";
    t[942] = "Failed to convert binary xml data to encoding: {0}.";
    t[943] = "La conversione di dati binari xml ad encoding {0} è fallita.";
    t[944] = "The maximum field size must be a value greater than or equal to 0.";
    t[945] = "La dimensione massima del campo deve essere maggiore o eguale a 0.";
    t[946] = "There are no rows in this ResultSet.";
    t[947] = "Non ci sono righe in questo «ResultSet».";
    t[948] = "Unable to determine a value for MaxIndexKeys due to missing system catalog data.";
    t[949] = "Non è possibile trovare il valore di «MaxIndexKeys» nel catalogo si sistema.";
    t[952] = "Cannot rollback prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. rollback xid={0}, transactionState={1}";
    t[953] = "Impossibile effettuare il rollback di una transazione preparata mentre una transazione locale è in corso su questa connessione. Eseguire prima il commit o il rollback della transazione locale. rollback xid={0}, transactionState={1}";
    t[960] = "Database connection failed when starting copy";
    t[961] = "Connessione al database fallita durante l'avvio della copy";
    t[962] = "One-phase commit must be issued on the connection that started the branch. commit xid={0}";
    t[963] = "Il commit «one-phase» deve essere eseguito sulla connessione che ha avviato il ramo. commit xid={0}";
    t[964] = "The array index is out of range: {0}, number of elements: {1}.";
    t[965] = "L''indice dell''array è fuori intervallo: {0}, numero di elementi: {1}.";
    t[966] = "Server SQLState: {0}";
    t[967] = "SQLState del server: {0}";
    t[968] = "CopyIn copy direction can't receive data";
    t[969] = "La direzione di copia «CopyIn» non può ricevere dati";
    t[972] = "Hint: {0}";
    t[973] = "Suggerimento: {0}";
    t[974] = "This SQLXML object has not been initialized, so you cannot retrieve data from it.";
    t[975] = "Impossibile leggere i dati da un oggetto «SQLXML» non inizializzato.";
    t[978] = "Cannot truncate LOB to a negative length.";
    t[979] = "Non è possibile troncare i LOB ad una dimensione negativa.";
    t[982] = "Transaction was already prepared on this connection. prepare xid={0}, preparedXid={1}";
    t[983] = "La transazione è già stata preparata su questa connessione. prepare xid={0}, preparedXid={1}";
    t[984] = "Unable to translate data into the desired encoding.";
    t[985] = "Impossibile tradurre i dati nella codifica richiesta.";
    t[986] = "Requested CopyOut but got {0}";
    t[987] = "Era richiesto «CopyOut» ma si è ottenuto {0}";
    t[992] = "One-phase commit called for xid {0} but connection was prepared with xid {1}";
    t[993] = "Commit «one-phase» invocato per xid {0} ma la connessione è stata preparata con xid {1}";
    t[994] = "Could not read password for SSL key file by callbackhandler {0}.";
    t[995] = "Impossibile leggere la password del file di chiave SSL con il «callbackhandler» {0}.";
    t[998] = "Malformed function or procedure escape syntax at offset {0}.";
    t[999] = "Sequenza di escape definita erroneamente nella funzione o procedura all''offset {0}.";
    t[1002] = "Cannot establish a savepoint in auto-commit mode.";
    t[1003] = "Non è possibile impostare i punti di ripristino in modalità «auto-commit».";
    t[1004] = "DataSource has been closed.";
    t[1005] = "Questo «DataSource» è stato chiuso.";
    table = t;
  }
  public java.lang.Object handleGetObject (java.lang.String msgid) throws java.util.MissingResourceException {
    int hash_val = msgid.hashCode() & 0x7fffffff;
    int idx = (hash_val % 503) << 1;
    {
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
    int incr = ((hash_val % 501) + 1) << 1;
    for (;;) {
      idx += incr;
      if (idx >= 1006)
        idx -= 1006;
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
  }
  public java.util.Enumeration getKeys () {
    return
      new java.util.Enumeration() {
        private int idx = 0;
        { while (idx < 1006 && table[idx] == null) idx += 2; }
        public boolean hasMoreElements () {
          return (idx < 1006);
        }
        public java.lang.Object nextElement () {
          java.lang.Object key = table[idx];
          do idx += 2; while (idx < 1006 && table[idx] == null);
          return key;
        }
      };
  }
  public java.util.ResourceBundle getParent () {
    return parent;
  }
}
