/* Automatically generated by GNU msgfmt.  Do not modify!  */
package org.postgresql.translation;
public class messages_de extends java.util.ResourceBundle {
  private static final java.lang.String[] table;
  static {
    java.lang.String[] t = new java.lang.String[686];
    t[0] = "";
    t[1] = "Project-Id-Version: head-de\nReport-Msgid-Bugs-To: \nPO-Revision-Date: 2008-09-12 14:22+0200\nLast-Translator: Andre Bialojahn <ab.spamnews@freenet.de>\nLanguage-Team: Deutsch\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Generator: KBabel 1.0.2\nX-Poedit-Language: German\nX-Poedit-Country: GERMANY\n";
    t[2] = "Connection has been closed automatically because a new connection was opened for the same PooledConnection or the PooledConnection has been closed.";
    t[3] = "Die Verbindung wurde automatisch geschlossen, da entweder eine neue Verbindung für die gleiche PooledConnection geöffnet wurde, oder die PooledConnection geschlossen worden ist..";
    t[10] = "Failed to create object for: {0}.";
    t[11] = "Erstellung des Objektes schlug fehl für: {0}.";
    t[16] = "Unsupported Types value: {0}";
    t[17] = "Unbekannter Typ: {0}.";
    t[20] = "{0} function doesn''t take any argument.";
    t[21] = "Die {0}-Funktion akzeptiert kein Argument.";
    t[24] = "Currently positioned after the end of the ResultSet.  You cannot call deleteRow() here.";
    t[25] = "Die augenblickliche Position ist hinter dem Ende des ResultSets.  Dort kann ''deleteRow()'' nicht aufgerufen werden.";
    t[30] = "Connection attempt timed out.";
    t[31] = "Keine Verbindung innerhalb des Zeitintervalls möglich.";
    t[32] = "Can''t infer the SQL type to use for an instance of {0}. Use setObject() with an explicit Types value to specify the type to use.";
    t[33] = "Der in SQL für eine Instanz von {0} zu verwendende Datentyp kann nicht abgeleitet werden. Benutzen Sie ''setObject()'' mit einem expliziten Typ, um ihn festzulegen.";
    t[36] = "Connection is already associated with an active XA branch. End the current branch before starting a new one. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[37] = "Die Verbindung ist bereits mit einem aktiven XA-Zweig verknüpft. Beenden Sie den aktuellen Zweig, bevor Sie einen neuen starten. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[38] = "Where: {0}";
    t[39] = "Wobei: {0}";
    t[42] = "ResultSet not positioned properly, perhaps you need to call next.";
    t[43] = "Das ResultSet ist nicht richtig positioniert. Eventuell muss ''next'' aufgerufen werden.";
    t[44] = "Error during one-phase commit. commit xid={0}";
    t[45] = "Bei der einphasigen Bestätigung trat ein Fehler auf. commit xid={0}";
    t[48] = "The server''s DateStyle parameter was changed to {0}. The JDBC driver requires DateStyle to begin with ISO for correct operation.";
    t[49] = "Der Parameter ''Date Style'' wurde auf dem Server auf {0} verändert. Der JDBC-Treiber setzt für korrekte Funktion voraus, dass ''Date Style'' mit ''ISO'' beginnt.";
    t[58] = "Cannot change transaction read-only property in the middle of a transaction.";
    t[59] = "Die Nur-Lesen-Eigenschaft einer Transaktion kann nicht während der Transaktion verändert werden.";
    t[62] = "commit() called before end(). commit xid={0}, state={1}";
    t[63] = "commit() wurde vor end() aufgerufen. commit xid={0}, state={1}";
    t[72] = "No results were returned by the query.";
    t[73] = "Die Abfrage lieferte kein Ergebnis.";
    t[76] = "Cannot tell if path is open or closed: {0}.";
    t[77] = "Es konnte nicht ermittelt werden, ob der Pfad offen oder geschlossen ist: {0}.";
    t[80] = "2nd phase commit cannot be issued while an XA branch is active on this connection. commit xid={0}, currentXid={1}, state={2}";
    t[81] = "Die zweite Bestätigungsphase kann nicht abgesetzt werden, solange auf dieser Verbindung ein XA-Zweig aktiv ist. commit xid={0}, currentXid={1}, state={2}";
    t[88] = "The fastpath function {0} is unknown.";
    t[89] = "Die Fastpath-Funktion {0} ist unbekannt.";
    t[92] = "Cannot retrieve the id of a named savepoint.";
    t[93] = "Die ID eines benamten Rettungspunktes kann nicht ermittelt werden.";
    t[100] = "The column index is out of range: {0}, number of columns: {1}.";
    t[101] = "Der Spaltenindex {0} ist außerhalb des gültigen Bereichs. Anzahl Spalten: {1}.";
    t[104] = "Protocol error.  Session setup failed.";
    t[105] = "Protokollfehler.  Die Sitzung konnte nicht gestartet werden.";
    t[108] = "Suspend/resume not implemented";
    t[109] = "Anhalten/Fortsetzen ist nicht implementiert.";
    t[112] = "free() was called on this LOB previously";
    t[113] = "free() wurde bereits für dieses LOB aufgerufen.";
    t[114] = "end() called without a matching start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[115] = "end() wurde ohne zugehörigen start()-Aufruf aufgerufen. end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[116] = "Unable to translate data into the desired encoding.";
    t[117] = "Die Daten konnten nicht in die gewünschte Kodierung gewandelt werden.";
    t[126] = "Prepare called before end(). prepare xid={0}, state={1}";
    t[127] = "Prepare wurde vor end() aufgerufen. prepare xid={0}, state={1}";
    t[130] = "ResultSet is not updateable.  The query that generated this result set must select only one table, and must select all primary keys from that table. See the JDBC 2.1 API Specification, section 5.6 for more details.";
    t[131] = "Das ResultSet kann nicht aktualisiert werden.  Die Abfrage, die es erzeugte, darf nur eine Tabelle und muss darin alle Primärschlüssel auswählen. Siehe JDBC 2.1 API-Spezifikation, Abschnitt 5.6 für mehr Details.";
    t[138] = "Cannot retrieve the name of an unnamed savepoint.";
    t[139] = "Der Name eines namenlosen Rettungpunktes kann nicht ermittelt werden.";
    t[142] = "The array index is out of range: {0}, number of elements: {1}.";
    t[143] = "Der Arrayindex {0} ist außerhalb des gültigen Bereichs. Vorhandene Elemente: {1}.";
    t[144] = "Cannot cast an instance of {0} to type {1}";
    t[145] = "Die Typwandlung für eine Instanz von {0} nach {1} ist nicht möglich.";
    t[152] = "Error during recover. flag={0}";
    t[153] = "Beim Wiederherstellen trat ein Fehler auf. flag={0}";
    t[158] = "Bad value for type {0} : {1}";
    t[159] = "Unzulässiger Wert für den Typ {0} : {1}.";
    t[160] = "An unexpected result was returned by a query.";
    t[161] = "Eine Abfrage lieferte ein unerwartetes Resultat.";
    t[162] = "Expected command status BEGIN, got {0}.";
    t[163] = "Statt des erwarteten Befehlsstatus BEGIN, wurde {0} empfangen.";
    t[166] = "Unable to load the class {0} responsible for the datatype {1}";
    t[167] = "Die für den Datentyp {1} verantwortliche Klasse {0} konnte nicht geladen werden.";
    t[168] = "Cannot change transaction isolation level in the middle of a transaction.";
    t[169] = "Die Transaktions-Trennungsstufe kann nicht während einer Transaktion verändert werden.";
    t[174] = "The server''s standard_conforming_strings parameter was reported as {0}. The JDBC driver expected on or off.";
    t[175] = "Der standard_conforming_strings Parameter des Servers steht auf {0}. Der JDBC-Treiber erwartete on oder off.";
    t[178] = "Invalid stream length {0}.";
    t[179] = "Ungültige Länge des Datenstroms: {0}.";
    t[184] = "Results cannot be retrieved from a CallableStatement before it is executed.";
    t[185] = "Ergebnisse können nicht von einem CallableStatement abgerufen werden, bevor es ausgeführt wurde.";
    t[186] = "This statement has been closed.";
    t[187] = "Die Anweisung wurde geschlossen.";
    t[188] = "Error loading default settings from driverconfig.properties";
    t[189] = "Fehler beim Laden der Voreinstellungen aus driverconfig.properties";
    t[190] = "Invalid flags {0}";
    t[191] = "Ungültige Flags {0}";
    t[196] = "xid must not be null";
    t[197] = "Die xid darf nicht null sein.";
    t[204] = "Conversion to type {0} failed: {1}.";
    t[205] = "Die Umwandlung in den Typ {0} schlug fehl: {1}.";
    t[206] = "DataSource has been closed.";
    t[207] = "Die Datenquelle wurde geschlossen.";
    t[208] = "Connection has been closed.";
    t[209] = "Die Verbindung wurde geschlossen.";
    t[210] = "A CallableStatement was executed with nothing returned.";
    t[211] = "Ein CallableStatement wurde ausgeführt ohne etwas zurückzugeben.";
    t[212] = "Your security policy has prevented the connection from being attempted.  You probably need to grant the connect java.net.SocketPermission to the database server host and port that you wish to connect to.";
    t[213] = "Ihre Sicherheitsrichtlinie hat den Versuch des Verbindungsaufbaus verhindert. Sie müssen wahrscheinlich der Verbindung zum Datenbankrechner java.net.SocketPermission gewähren, um den Rechner auf dem gewählten Port zu erreichen.";
    t[218] = "Unexpected command status: {0}.";
    t[219] = "Unerwarteter Befehlsstatus: {0}.";
    t[220] = "Cannot reference a savepoint after it has been released.";
    t[221] = "Ein Rettungspunkt kann nicht angesprochen werden, nach dem er entfernt wurde.";
    t[222] = "Error opening transaction. start xid={0}";
    t[223] = "Beim Öffnen der Transaktion trat ein Fehler auf. start xid={0}";
    t[228] = "The authentication type {0} is not supported. Check that you have configured the pg_hba.conf file to include the client''s IP address or subnet, and that it is using an authentication scheme supported by the driver.";
    t[229] = "Der Authentifizierungstyp {0} wird nicht unterstützt. Stellen Sie sicher, dass die Datei ''pg_hba.conf'' die IP-Adresse oder das Subnetz des Clients enthält und dass der Client ein Authentifizierungsschema nutzt, das vom Treiber unterstützt wird.";
    t[242] = "Internal Position: {0}";
    t[243] = "Interne Position: {0}";
    t[244] = "This statement does not declare an OUT parameter.  Use '{' ?= call ... '}' to declare one.";
    t[245] = "Diese Anweisung deklariert keinen OUT-Parameter. Benutzen Sie '{' ?= call ... '}' um das zu tun.";
    t[256] = "Location: File: {0}, Routine: {1}, Line: {2}";
    t[257] = "Ort: Datei: {0}, Routine: {1}, Zeile: {2}.";
    t[258] = "Unknown type {0}.";
    t[259] = "Unbekannter Typ {0}.";
    t[260] = "Ran out of memory retrieving query results.";
    t[261] = "Nicht genügend Speicher beim Abholen der Abfrageergebnisse.";
    t[264] = "Zero bytes may not occur in string parameters.";
    t[265] = "Stringparameter dürfen keine Nullbytes enthalten.";
    t[266] = "{0} function takes four and only four argument.";
    t[267] = "Die {0}-Funktion erwartet genau vier Argumente.";
    t[268] = "Truncation of large objects is only implemented in 8.3 and later servers.";
    t[269] = "Das Abschneiden großer Objekte ist nur in Versionen nach 8.3 implementiert.";
    t[270] = "Invalid character data was found.  This is most likely caused by stored data containing characters that are invalid for the character set the database was created in.  The most common example of this is storing 8bit data in a SQL_ASCII database.";
    t[271] = "Ungültige Zeichendaten.  Das ist höchstwahrscheinlich von in der Datenbank gespeicherten Zeichen hervorgerufen, die in einer anderen Kodierung vorliegen, als die, in der die Datenbank erstellt wurde.  Das häufigste Beispiel dafür ist es, 8Bit-Daten in SQL_ASCII-Datenbanken abzulegen.";
    t[278] = "This PooledConnection has already been closed.";
    t[279] = "Diese PooledConnection ist bereits geschlossen worden.";
    t[280] = "Cannot call cancelRowUpdates() when on the insert row.";
    t[281] = "''cancelRowUpdates()'' kann in der Einfügezeile nicht aufgerufen werden.";
    t[284] = "Cannot rollback prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. rollback xid={0}, transactionState={1}";
    t[285] = "Eine vorbereitete Transaktion kann nicht zurückgerollt werden, solange auf dieser Verbindung eine lokale Transaktion läuft. Bestätigen oder rollen Sie zuerst die lokale Transaktion zurück. rollback xid={0}, transactionState={1}";
    t[288] = "PostgreSQL LOBs can only index to: {0}";
    t[289] = "LOBs in PostgreSQL können nur auf {0} verweisen.";
    t[290] = "Provided InputStream failed.";
    t[291] = "Der bereitgestellte InputStream scheiterte.";
    t[298] = "Unexpected error writing large object to database.";
    t[299] = "Beim Schreiben eines LargeObjects (LOB) in die Datenbank trat ein unerwarteter Fehler auf.";
    t[300] = "Fetch size must be a value greater than or equal to 0.";
    t[301] = "Die Fetch-Größe muss ein Wert größer oder gleich Null sein.";
    t[310] = "Error committing prepared transaction. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[311] = "Fehler beim Bestätigen einer vorbereiteten Transaktion. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[312] = "Transaction was already prepared on this connection. prepare xid={0}, preparedXid={1}";
    t[313] = "Auf dieser Verbindung wurde bereits eine Transaktion vorbereitet. prepare xid={0}, preparedXid={1}";
    t[314] = "The parameter index is out of range: {0}, number of parameters: {1}.";
    t[315] = "Der Parameterindex {0} ist außerhalb des gültigen Bereichs. Es gibt {1} Parameter.";
    t[316] = "Not on the insert row.";
    t[317] = "Nicht in der Einfügezeile.";
    t[320] = "{0} function takes two and only two arguments.";
    t[321] = "Die {0}-Funktion erwartet genau zwei Argumente.";
    t[330] = "Unsupported value for stringtype parameter: {0}";
    t[331] = "Nichtunterstützter Wert für den Stringparameter: {0}";
    t[332] = "Unknown Response Type {0}.";
    t[333] = "Die Antwort weist einen unbekannten Typ auf: {0}.";
    t[336] = "An error occurred while setting up the SSL connection.";
    t[337] = "Beim Aufbau der SSL-Verbindung trat ein Fehler auf.";
    t[354] = "Zero bytes may not occur in identifiers.";
    t[355] = "Nullbytes dürfen in Bezeichnern nicht vorkommen.";
    t[360] = "A connection could not be made using the requested protocol {0}.";
    t[361] = "Es konnte keine Verbindung unter Verwendung des Protokolls {0} hergestellt werden.";
    t[362] = "You must specify at least one column value to insert a row.";
    t[363] = "Sie müssen mindestens einen Spaltenwert angeben, um eine Zeile einzufügen.";
    t[364] = "Method {0} is not yet implemented.";
    t[365] = "Die Methode {0} ist noch nicht implementiert.";
    t[368] = "Unknown ResultSet holdability setting: {0}.";
    t[369] = "Unbekannte Einstellung für die Haltbarkeit des ResultSets: {0}.";
    t[374] = "Cannot 2nd phase commit prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. commit xid={0}, transactionState={1}";
    t[375] = "Die zweite Bestätigungsphase einer vorbereiteten Transaktion kann nicht ausgeführt werden, solange auf dieser Verbindung eine lokale Transaktion läuft. Bestätigen oder rollen Sie zuerst die lokale Transaktion zurück. commit xid={0}, transactionState={1}";
    t[376] = "wasNull cannot be call before fetching a result.";
    t[377] = "wasNull kann nicht aufgerufen werden, bevor ein Ergebnis abgefragt wurde.";
    t[378] = "Returning autogenerated keys is not supported.";
    t[379] = "Die Rückgabe automatisch generierter Schlüssel wird nicht unterstützt,";
    t[380] = "Cannot update the ResultSet because it is either before the start or after the end of the results.";
    t[381] = "Das ResultSet kann nicht aktualisiert werden, da es entweder vor oder nach dem Ende der Ergebnisse ist.";
    t[384] = "Unable to bind parameter values for statement.";
    t[385] = "Der Anweisung konnten keine Parameterwerte zugewiesen werden.";
    t[390] = "Error preparing transaction. prepare xid={0}";
    t[391] = "Beim Vorbereiten der Transaktion trat ein Fehler auf. prepare xid={0}";
    t[396] = "LOB positioning offsets start at 1.";
    t[397] = "Positionsoffsets für LOBs beginnen bei 1.";
    t[404] = "Transaction isolation level {0} not supported.";
    t[405] = "Die Transaktions-Trennungsstufe {0} ist nicht unterstützt.";
    t[406] = "{0} function takes two or three arguments.";
    t[407] = "Die {0}-Funktion erwartet zwei oder drei Argumente.";
    t[412] = "Conversion of interval failed";
    t[413] = "Die Umwandlung eines Intervalls schlug fehl.";
    t[414] = "A CallableStatement function was executed and the out parameter {0} was of type {1} however type {2} was registered.";
    t[415] = "Eine CallableStatement-Funktion wurde ausgeführt und der Rückgabewert {0} war vom Typ {1}. Jedoch wurde der Typ {2} dafür registriert.";
    t[416] = "Transaction control methods setAutoCommit, commit, rollback and setSavepoint are not allowed while an XA transaction is active.";
    t[417] = "Die Transaktionssteuerungsmethoden setAutoCommit, commit, rollback und setSavepoint sind nicht erlaubt, solange eine XA-Transaktion aktiv ist.";
    t[422] = "Statement has been closed.";
    t[423] = "Die Anweisung wurde geschlossen.";
    t[424] = "Fastpath call {0} - No result was returned and we expected an integer.";
    t[425] = "Der Fastpath-Aufruf {0} gab kein Ergebnis zurück, jedoch wurde ein Integer erwartet.";
    t[428] = "Something unusual has occurred to cause the driver to fail. Please report this exception.";
    t[429] = "Etwas Ungewöhnliches ist passiert, das den Treiber fehlschlagen ließ. Bitte teilen Sie diesen Fehler mit.";
    t[430] = "This ResultSet is closed.";
    t[431] = "Dieses ResultSet ist geschlossen.";
    t[432] = "Unknown Types value.";
    t[433] = "Unbekannter Typ.";
    t[434] = "Operation requires a scrollable ResultSet, but this ResultSet is FORWARD_ONLY.";
    t[435] = "Die Operation erfordert ein scrollbares ResultSet, dieses jedoch ist FORWARD_ONLY.";
    t[454] = "Conversion of money failed.";
    t[455] = "Die Umwandlung eines Währungsbetrags schlug fehl.";
    t[462] = "The SSLSocketFactory class provided {0} could not be instantiated.";
    t[463] = "Die von {0} bereitgestellte SSLSocketFactory-Klasse konnte nicht instanziiert werden.";
    t[466] = "Large Objects may not be used in auto-commit mode.";
    t[467] = "LargeObjects (LOB) dürfen im Modus ''auto-commit'' nicht verwendet werden.";
    t[468] = "{0} function takes one and only one argument.";
    t[469] = "Die {0}-Funktion erwartet nur genau ein Argument.";
    t[474] = "Cannot call updateRow() when on the insert row.";
    t[475] = "''updateRow()'' kann in der Einfügezeile nicht aufgerufen werden.";
    t[478] = "Can''t use relative move methods while on the insert row.";
    t[479] = "Relative Bewegungen können in der Einfügezeile nicht durchgeführt werden.";
    t[482] = "ResultSets with concurrency CONCUR_READ_ONLY cannot be updated.";
    t[483] = "ResultSets, deren Zugriffsart CONCUR_READ_ONLY ist, können nicht aktualisiert werden.";
    t[484] = "Unable to find name datatype in the system catalogs.";
    t[485] = "In den Systemkatalogen konnte der Namensdatentyp nicht gefunden werden.";
    t[486] = "Bind message length {0} too long.  This can be caused by very large or incorrect length specifications on InputStream parameters.";
    t[487] = "Die Nachrichtenlänge {0} ist zu groß. Das kann von sehr großen oder inkorrekten Längenangaben eines InputStream-Parameters herrühren.";
    t[490] = "A CallableStatement was executed with an invalid number of parameters";
    t[491] = "Ein CallableStatement wurde mit einer falschen Anzahl Parameter ausgeführt.";
    t[500] = "Cannot call deleteRow() when on the insert row.";
    t[501] = "''deleteRow()'' kann in der Einfügezeile nicht aufgerufen werden.";
    t[502] = "A CallableStatement was declared, but no call to registerOutParameter(1, <some type>) was made.";
    t[503] = "Ein CallableStatement wurde deklariert, aber kein Aufruf von ''registerOutParameter(1, <some type>)'' erfolgte.";
    t[508] = "Currently positioned before the start of the ResultSet.  You cannot call deleteRow() here.";
    t[509] = "Die augenblickliche Position ist vor dem Beginn des ResultSets.  Dort kann ''deleteRow()'' nicht aufgerufen werden.";
    t[510] = "{0} function takes three and only three arguments.";
    t[511] = "Die {0}-Funktion erwartet genau drei Argumente.";
    t[518] = "Query timeout must be a value greater than or equals to 0.";
    t[519] = "Das Abfragetimeout muss ein Wert größer oder gleich Null sein.";
    t[520] = "There are no rows in this ResultSet.";
    t[521] = "Es gibt keine Zeilen in diesem ResultSet.";
    t[524] = "Heuristic commit/rollback not supported. forget xid={0}";
    t[525] = "Heuristisches Commit/Rollback wird nicht unterstützt. forget xid={0}";
    t[528] = "Provided Reader failed.";
    t[529] = "Der bereitgestellte Reader scheiterte.";
    t[530] = "Internal Query: {0}";
    t[531] = "Interne Abfrage: {0}";
    t[532] = "The JVM claims not to support the {0} encoding.";
    t[533] = "Die JVM behauptet, die Zeichenkodierung {0} nicht zu unterstützen.";
    t[544] = "The column name {0} was not found in this ResultSet.";
    t[545] = "Der Spaltenname {0} wurde in diesem ResultSet nicht gefunden.";
    t[546] = "Error rolling back transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[547] = "Fehler beim Zurückrollen der Transaktion. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[560] = "No value specified for parameter {0}.";
    t[561] = "Für den Parameter {0} wurde kein Wert angegeben.";
    t[562] = "Can''t refresh the insert row.";
    t[563] = "Die Einfügezeile kann nicht aufgefrischt werden.";
    t[566] = "The array index is out of range: {0}";
    t[567] = "Der Arrayindex ist außerhalb des gültigen Bereichs: {0}.";
    t[568] = "ClientInfo property not supported.";
    t[569] = "Die ClientInfo-Eigenschaft ist nicht unterstützt.";
    t[570] = "Malformed function or procedure escape syntax at offset {0}.";
    t[571] = "Unzulässige Syntax für ein Funktions- oder Prozedur-Escape an Offset {0}.";
    t[590] = "One-phase commit called for xid {0} but connection was prepared with xid {1}";
    t[591] = "Einphasige Bestätigung wurde für xid {0} aufgerufen, die Verbindung wurde jedoch mit xid {1} vorbereitet.";
    t[602] = "One-phase commit with unknown xid. commit xid={0}, currentXid={1}";
    t[603] = "Einphasige Bestätigung mit unbekannter xid. commit xid={0}, currentXid={1}";
    t[606] = "Position: {0}";
    t[607] = "Position: {0}";
    t[612] = "Detail: {0}";
    t[613] = "Detail: {0}";
    t[616] = "The JVM claims not to support the encoding: {0}";
    t[617] = "Die JVM behauptet, die Zeichenkodierung {0} nicht zu unterstützen.";
    t[618] = "Unable to determine a value for MaxIndexKeys due to missing system catalog data.";
    t[619] = "Es konnte kein Wert für MaxIndexKeys gefunden werden, da die Systemkatalogdaten fehlen.";
    t[620] = "Invalid fetch direction constant: {0}.";
    t[621] = "Unzulässige Richtungskonstante bei fetch: {0}.";
    t[622] = "Multiple ResultSets were returned by the query.";
    t[623] = "Die Abfrage ergab mehrere ResultSets.";
    t[626] = "The server does not support SSL.";
    t[627] = "Der Server unterstützt SSL nicht.";
    t[630] = "Server SQLState: {0}";
    t[631] = "Server SQLState: {0}";
    t[632] = "Premature end of input stream, expected {0} bytes, but only read {1}.";
    t[633] = "Vorzeitiges Ende des Eingabedatenstroms. Es wurden {0} Bytes erwartet, jedoch nur {1} gelesen.";
    t[636] = "Expected an EOF from server, got: {0}";
    t[637] = "Vom Server wurde ein EOF erwartet, jedoch {0} gelesen.";
    t[638] = "Hint: {0}";
    t[639] = "Hinweis: {0}";
    t[640] = "Interrupted while attempting to connect.";
    t[641] = "Beim Verbindungsversuch trat eine Unterbrechung auf.";
    t[642] = "The connection attempt failed.";
    t[643] = "Der Verbindungsversuch schlug fehl.";
    t[644] = "Too many update results were returned.";
    t[645] = "Zu viele Updateergebnisse wurden zurückgegeben.";
    t[650] = "Cannot convert an instance of {0} to type {1}";
    t[651] = "Die Typwandlung für eine Instanz von {0} nach {1} ist nicht möglich.";
    t[652] = "Prepare must be issued on the connection that started the branch. Transaction interleaving is not supported. prepare xid={0}, currentXid={1}";
    t[653] = "Prepare muss über die Verbindung abgesetzt werden, die den Zweig gestartet hat. Verschachtelte Transaktionen werden nicht unterstützt. prepare xid={0}, currentXid={1}";
    t[660] = "One-phase commit must be issued on the connection that started the branch. commit xid={0}";
    t[661] = "Die einphasige Bestätigung muss über die Verbindung abgesetzt werden, die den Zweig gestartet hat. commit xid={0}";
    t[664] = "The maximum field size must be a value greater than or equal to 0.";
    t[665] = "Die maximale Feldgröße muss ein Wert größer oder gleich Null sein.";
    t[666] = "Interval {0} not yet implemented";
    t[667] = "Intervall {0} ist noch nicht implementiert.";
    t[668] = "Parameter of type {0} was registered, but call to get{1} (sqltype={2}) was made.";
    t[669] = "Ein Parameter des Typs {0} wurde registriert, jedoch erfolgte ein Aufruf get{1} (sqltype={2}).";
    t[672] = "Current connection does not have an associated xid. prepare xid={0}";
    t[673] = "Mit der aktuellen Verbindung ist keine xid verknüpft. prepare xid={0}";
    t[674] = "Cannot establish a savepoint in auto-commit mode.";
    t[675] = "Ein Rettungspunkt kann im Modus ''auto-commit'' nicht erstellt werden.";
    t[676] = "A result was returned when none was expected.";
    t[677] = "Die Anweisung lieferte ein Ergebnis obwohl keines erwartet wurde.";
    table = t;
  }
  public java.lang.Object handleGetObject (java.lang.String msgid) throws java.util.MissingResourceException {
    int hash_val = msgid.hashCode() & 0x7fffffff;
    int idx = (hash_val % 343) << 1;
    {
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
    int incr = ((hash_val % 341) + 1) << 1;
    for (;;) {
      idx += incr;
      if (idx >= 686)
        idx -= 686;
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
  }
  public java.util.Enumeration getKeys () {
    return
      new java.util.Enumeration() {
        private int idx = 0;
        { while (idx < 686 && table[idx] == null) idx += 2; }
        public boolean hasMoreElements () {
          return (idx < 686);
        }
        public java.lang.Object nextElement () {
          java.lang.Object key = table[idx];
          do idx += 2; while (idx < 686 && table[idx] == null);
          return key;
        }
      };
  }
  public java.util.ResourceBundle getParent () {
    return parent;
  }
}
