/* Automatically generated by GNU msgfmt.  Do not modify!  */
package org.postgresql.translation;
public class messages_pt_BR extends java.util.ResourceBundle {
  private static final java.lang.String[] table;
  static {
    java.lang.String[] t = new java.lang.String[686];
    t[0] = "";
    t[1] = "Project-Id-Version: PostgreSQL 8.4\nReport-Msgid-Bugs-To: \nPO-Revision-Date: 2004-10-31 20:48-0300\nLast-Translator: Euler Taveira de Oliveira <euler@timbira.com>\nLanguage-Team: Brazilian Portuguese <pgbr-dev@listas.postgresql.org.br>\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\n";
    t[2] = "Connection has been closed automatically because a new connection was opened for the same PooledConnection or the PooledConnection has been closed.";
    t[3] = "Conexão foi fechada automaticamente porque uma nova conexão foi aberta pelo mesmo PooledConnection ou o PooledConnection foi fechado.";
    t[10] = "Failed to create object for: {0}.";
    t[11] = "Falhou ao criar objeto para: {0}.";
    t[16] = "Unsupported Types value: {0}";
    t[17] = "Valor de Types não é suportado: {0}";
    t[20] = "{0} function doesn''t take any argument.";
    t[21] = "função {0} não recebe nenhum argumento.";
    t[24] = "Currently positioned after the end of the ResultSet.  You cannot call deleteRow() here.";
    t[25] = "Posicionado depois do fim do ResultSet.  Você não pode chamar deleteRow() aqui.";
    t[28] = "end() called without a matching start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[29] = "end() chamado sem um start() correspondente. end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[30] = "Connection attempt timed out.";
    t[31] = "Tentativa de conexão falhou.";
    t[32] = "Can''t infer the SQL type to use for an instance of {0}. Use setObject() with an explicit Types value to specify the type to use.";
    t[33] = "Não pode inferir um tipo SQL a ser usado para uma instância de {0}. Use setObject() com um valor de Types explícito para especificar o tipo a ser usado.";
    t[36] = "Connection is already associated with an active XA branch. End the current branch before starting a new one. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[37] = "A conexão já está associada a um ramo XA ativo. Finalize o ramo atual antes de iniciar um novo. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[38] = "Where: {0}";
    t[39] = "Onde: {0}";
    t[42] = "ResultSet not positioned properly, perhaps you need to call next.";
    t[43] = "ResultSet não está posicionado corretamente, talvez você precise chamar next.";
    t[44] = "Error during one-phase commit. commit xid={0}";
    t[45] = "Erro durante efetivação de uma fase. commit xid={0}";
    t[48] = "The server''s DateStyle parameter was changed to {0}. The JDBC driver requires DateStyle to begin with ISO for correct operation.";
    t[49] = "O parâmetro do servidor DateStyle foi alterado para {0}. O driver JDBC requer que o DateStyle começe com ISO para operação normal.";
    t[58] = "Custom type maps are not supported.";
    t[59] = "Mapeamento de tipos personalizados não são suportados.";
    t[60] = "Error preparing transaction. prepare xid={0}";
    t[61] = "Erro ao preparar transação. prepare xid={0}";
    t[62] = "commit() called before end(). commit xid={0}, state={1}";
    t[63] = "commit() chamado antes de end(). commit xid={0}, state={1}";
    t[72] = "No results were returned by the query.";
    t[73] = "Nenhum resultado foi retornado pela consulta.";
    t[76] = "Cannot tell if path is open or closed: {0}.";
    t[77] = "Não pode dizer se caminho está aberto ou fechado: {0}.";
    t[80] = "2nd phase commit cannot be issued while an XA branch is active on this connection. commit xid={0}, currentXid={1}, state={2}";
    t[81] = "A efetivação da segunda fase não pode ser executada enquanto um ramo XA estiver ativo nesta conexão. commit xid={0}, currentXid={1}, state={2}";
    t[82] = "Returning autogenerated keys by column index is not supported.";
    t[83] = "Retorno de chaves geradas automaticamente por índice de coluna não é suportado.";
    t[88] = "The fastpath function {0} is unknown.";
    t[89] = "A função do fastpath {0} é desconhecida.";
    t[92] = "Cannot retrieve the id of a named savepoint.";
    t[93] = "Não pode recuperar o id de um savepoint com nome.";
    t[100] = "The column index is out of range: {0}, number of columns: {1}.";
    t[101] = "O índice da coluna está fora do intervalo: {0}, número de colunas: {1}.";
    t[104] = "Protocol error.  Session setup failed.";
    t[105] = "Erro de Protocolo. Configuração da sessão falhou.";
    t[108] = "Suspend/resume not implemented";
    t[109] = "Suspender/retomar não está implementado";
    t[110] = "Unable to find server array type for provided name {0}.";
    t[111] = "Não foi possível encontrar tipo matriz para nome fornecido {0}.";
    t[112] = "free() was called on this LOB previously";
    t[113] = "free() já foi chamado neste LOB";
    t[114] = "Unknown XML Result class: {0}";
    t[115] = "Classe XML Result desconhecida: {0}";
    t[116] = "Unable to translate data into the desired encoding.";
    t[117] = "Não foi possível traduzir dado para codificação desejada.";
    t[126] = "Prepare called before end(). prepare xid={0}, state={1}";
    t[127] = "Prepare chamado antes de end(). prepare xid={0}, state={1}";
    t[130] = "ResultSet is not updateable.  The query that generated this result set must select only one table, and must select all primary keys from that table. See the JDBC 2.1 API Specification, section 5.6 for more details.";
    t[131] = "ResultSet não é atualizável. A consulta que gerou esse conjunto de resultados deve selecionar somente uma tabela, e deve selecionar todas as chaves primárias daquela tabela. Veja a especificação na API do JDBC 2.1, seção 5.6 para obter mais detalhes.";
    t[136] = "Unable to create SAXResult for SQLXML.";
    t[137] = "Não foi possível criar SAXResult para SQLXML.";
    t[138] = "Cannot retrieve the name of an unnamed savepoint.";
    t[139] = "Não pode recuperar o nome de um savepoint sem nome.";
    t[142] = "The array index is out of range: {0}, number of elements: {1}.";
    t[143] = "O índice da matriz está fora do intervalo: {0}, número de elementos: {1}.";
    t[144] = "Cannot cast an instance of {0} to type {1}";
    t[145] = "Não pode converter uma instância de {0} para tipo {1}";
    t[152] = "Error during recover. flag={0}";
    t[153] = "Erro durante recuperação. flag={0}";
    t[158] = "Bad value for type {0} : {1}";
    t[159] = "Valor inválido para tipo {0} : {1}";
    t[160] = "An unexpected result was returned by a query.";
    t[161] = "Um resultado inesperado foi retornado pela consulta.";
    t[162] = "Expected command status BEGIN, got {0}.";
    t[163] = "Status do comando BEGIN esperado, recebeu {0}.";
    t[166] = "Unable to load the class {0} responsible for the datatype {1}";
    t[167] = "Não foi possível carregar a classe {0} responsável pelo tipo de dado {1}";
    t[168] = "Cannot change transaction isolation level in the middle of a transaction.";
    t[169] = "Não pode mudar nível de isolamento da transação no meio de uma transação.";
    t[174] = "The server''s standard_conforming_strings parameter was reported as {0}. The JDBC driver expected on or off.";
    t[175] = "O parâmetro do servidor standard_conforming_strings foi definido como {0}. O driver JDBC espera que seja on ou off.";
    t[178] = "Invalid stream length {0}.";
    t[179] = "Tamanho de dado {0} é inválido.";
    t[180] = "Unable to decode xml data.";
    t[181] = "Não foi possível decodificar dado xml.";
    t[184] = "Results cannot be retrieved from a CallableStatement before it is executed.";
    t[185] = "Resultados não podem ser recuperados de uma função antes dela ser executada.";
    t[186] = "This statement has been closed.";
    t[187] = "Este comando foi fechado.";
    t[188] = "Error loading default settings from driverconfig.properties";
    t[189] = "Erro ao carregar configurações padrão do driverconfig.properties";
    t[190] = "Invalid flags {0}";
    t[191] = "Marcadores={0} inválidos";
    t[196] = "Failed to convert binary xml data to encoding: {0}.";
    t[197] = "Falhou ao converter dados xml binários para codificação: {0}.";
    t[204] = "Conversion to type {0} failed: {1}.";
    t[205] = "Conversão para tipo {0} falhou: {1}.";
    t[206] = "DataSource has been closed.";
    t[207] = "DataSource foi fechado.";
    t[208] = "Connection has been closed.";
    t[209] = "Conexão foi fechada.";
    t[210] = "A CallableStatement was executed with nothing returned.";
    t[211] = "Uma função foi executada e nada foi retornado.";
    t[212] = "Your security policy has prevented the connection from being attempted.  You probably need to grant the connect java.net.SocketPermission to the database server host and port that you wish to connect to.";
    t[213] = "Sua política de segurança impediu que a conexão pudesse ser estabelecida. Você provavelmente precisa conceder permissão em java.net.SocketPermission para a máquina e a porta do servidor de banco de dados que você deseja se conectar.";
    t[218] = "Unexpected command status: {0}.";
    t[219] = "Status do comando inesperado: {0}.";
    t[220] = "Cannot reference a savepoint after it has been released.";
    t[221] = "Não pode referenciar um savepoint após ele ser descartado.";
    t[222] = "Error opening transaction. start xid={0}";
    t[223] = "Erro ao abrir transação. start xid={0}";
    t[228] = "The authentication type {0} is not supported. Check that you have configured the pg_hba.conf file to include the client''s IP address or subnet, and that it is using an authentication scheme supported by the driver.";
    t[229] = "O tipo de autenticação {0} não é suportado. Verifique se você configurou o arquivo pg_hba.conf incluindo a subrede ou endereço IP do cliente, e se está utilizando o esquema de autenticação suportado pelo driver.";
    t[242] = "Internal Position: {0}";
    t[243] = "Posição Interna: {0}";
    t[244] = "This statement does not declare an OUT parameter.  Use '{' ?= call ... '}' to declare one.";
    t[245] = "Este comando não declara um parâmetro de saída. Utilize '{' ?= chamada ... '}' para declarar um)";
    t[256] = "Location: File: {0}, Routine: {1}, Line: {2}";
    t[257] = "Local: Arquivo: {0}, Rotina: {1}, Linha: {2}";
    t[258] = "Unknown type {0}.";
    t[259] = "Tipo desconhecido {0}.";
    t[260] = "Ran out of memory retrieving query results.";
    t[261] = "Memória insuficiente ao recuperar resultados da consulta.";
    t[264] = "Zero bytes may not occur in string parameters.";
    t[265] = "Zero bytes não podem ocorrer em parâmetros de cadeia de caracteres.";
    t[266] = "{0} function takes four and only four argument.";
    t[267] = "função {0} recebe somente quatro argumentos.";
    t[268] = "Truncation of large objects is only implemented in 8.3 and later servers.";
    t[269] = "Truncar objetos grandes só é implementado por servidores 8.3 ou superiores.";
    t[270] = "Invalid character data was found.  This is most likely caused by stored data containing characters that are invalid for the character set the database was created in.  The most common example of this is storing 8bit data in a SQL_ASCII database.";
    t[271] = "Caracter inválido foi encontrado. Isso é mais comumente causado por dado armazenado que contém caracteres que são inválidos para a codificação que foi criado o banco de dados. O exemplo mais comum disso é armazenar dados de 8 bits em um banco de dados SQL_ASCII.";
    t[278] = "This PooledConnection has already been closed.";
    t[279] = "Este PooledConnection já foi fechado.";
    t[280] = "Cannot call cancelRowUpdates() when on the insert row.";
    t[281] = "Não pode chamar cancelRowUpdates() quando estiver inserindo registro.";
    t[284] = "Cannot rollback prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. rollback xid={0}, transactionState={1}";
    t[285] = "Não é possível cancelar uma transação preparada enquanto uma transação local estiver em andamento nesta conexão. Efetive ou cancele a transação local primeiro. rollback xid={0}, transactionState={1}";
    t[288] = "PostgreSQL LOBs can only index to: {0}";
    t[289] = "LOBs do PostgreSQL só podem indexar até: {0}";
    t[290] = "Provided InputStream failed.";
    t[291] = "InputStream fornecido falhou.";
    t[298] = "Unexpected error writing large object to database.";
    t[299] = "Erro inesperado ao escrever objeto grande no banco de dados.";
    t[300] = "Fetch size must be a value greater than or equal to 0.";
    t[301] = "Tamanho da busca deve ser um valor maior ou igual a 0.";
    t[310] = "Invalid protocol state requested. Attempted transaction interleaving is not supported. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[311] = "Intercalação de transação não está implementado. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[312] = "Transaction was already prepared on this connection. prepare xid={0}, preparedXid={1}";
    t[313] = "A transação já havia sido preparada nesta conexão. prepare xid={0}, preparedXid={1}";
    t[314] = "The parameter index is out of range: {0}, number of parameters: {1}.";
    t[315] = "O índice de parâmetro está fora do intervalo: {0}, número de parâmetros: {1}.";
    t[316] = "Not on the insert row.";
    t[317] = "Não está inserindo um registro.";
    t[320] = "{0} function takes two and only two arguments.";
    t[321] = "função {0} recebe somente dois argumentos.";
    t[322] = "Cannot change transaction read-only property in the middle of a transaction.";
    t[323] = "Não pode mudar propriedade somente-leitura da transação no meio de uma transação.";
    t[330] = "GSS Authentication failed";
    t[331] = "Autenticação GSS falhou";
    t[332] = "Unknown Response Type {0}.";
    t[333] = "Tipo de Resposta Desconhecido {0}.";
    t[334] = "This SQLXML object has not been initialized, so you cannot retrieve data from it.";
    t[335] = "Este objeto SQLXML não foi inicializado, então você não pode recuperar dados dele.";
    t[336] = "An error occurred while setting up the SSL connection.";
    t[337] = "Um erro ocorreu ao estabelecer uma conexão SSL.";
    t[344] = "Invalid UUID data.";
    t[345] = "dado UUID é inválido.";
    t[354] = "Zero bytes may not occur in identifiers.";
    t[355] = "Zero bytes não podem ocorrer em identificadores.";
    t[360] = "A connection could not be made using the requested protocol {0}.";
    t[361] = "A conexão não pode ser feita usando protocolo informado {0}.";
    t[362] = "You must specify at least one column value to insert a row.";
    t[363] = "Você deve especificar pelo menos uma coluna para inserir um registro.";
    t[364] = "Method {0} is not yet implemented.";
    t[365] = "Método {0} ainda não foi implementado.";
    t[368] = "Unknown ResultSet holdability setting: {0}.";
    t[369] = "Definição de durabilidade do ResultSet desconhecida: {0}.";
    t[374] = "Cannot 2nd phase commit prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. commit xid={0}, transactionState={1}";
    t[375] = "Não é possível executar a efetivação da segunda fase de uma transação preparada enquanto uma transação local estiver em andamento nesta conexão. Efetive ou cancele a transação local primeiro. commit xid={0}, transactionState={1}";
    t[376] = "wasNull cannot be call before fetching a result.";
    t[377] = "wasNull não pode ser chamado antes de obter um resultado.";
    t[378] = "Returning autogenerated keys is not supported.";
    t[379] = "Retorno de chaves geradas automaticamente não é suportado.";
    t[380] = "Cannot update the ResultSet because it is either before the start or after the end of the results.";
    t[381] = "Não pode atualizar o ResultSet porque ele está antes do início ou depois do fim dos resultados.";
    t[384] = "Unable to bind parameter values for statement.";
    t[385] = "Não foi possível ligar valores de parâmetro ao comando.";
    t[390] = "Unable to create StAXResult for SQLXML";
    t[391] = "Não foi possível criar StAXResult para SQLXML";
    t[394] = "Unknown XML Source class: {0}";
    t[395] = "Classe XML Source desconhecida: {0}";
    t[396] = "LOB positioning offsets start at 1.";
    t[397] = "Deslocamentos da posição de LOB começam em 1.";
    t[402] = "This SQLXML object has already been initialized, so you cannot manipulate it further.";
    t[403] = "Este objeto SQLXML já foi inicializado, então você não pode manipulá-lo depois.";
    t[404] = "Transaction isolation level {0} not supported.";
    t[405] = "Nível de isolamento da transação {0} não é suportado.";
    t[406] = "{0} function takes two or three arguments.";
    t[407] = "função {0} recebe dois ou três argumentos.";
    t[412] = "Conversion of interval failed";
    t[413] = "Conversão de interval falhou";
    t[414] = "A CallableStatement function was executed and the out parameter {0} was of type {1} however type {2} was registered.";
    t[415] = "Uma função foi executada e o parâmetro de retorno {0} era do tipo {1} contudo tipo {2} foi registrado.";
    t[416] = "Transaction control methods setAutoCommit, commit, rollback and setSavepoint are not allowed while an XA transaction is active.";
    t[417] = "Métodos de controle de transação setAutoCommit, commit, rollback e setSavepoint não são permitidos enquanto uma transação XA estiver ativa.";
    t[422] = "Statement has been closed.";
    t[423] = "Comando foi fechado.";
    t[424] = "Fastpath call {0} - No result was returned and we expected an integer.";
    t[425] = "Chamada ao Fastpath {0} - Nenhum resultado foi retornado e nós esperávamos um inteiro.";
    t[428] = "Something unusual has occurred to cause the driver to fail. Please report this exception.";
    t[429] = "Alguma coisa não usual ocorreu para causar a falha do driver. Por favor reporte esta exceção.";
    t[430] = "This ResultSet is closed.";
    t[431] = "Este ResultSet está fechado.";
    t[432] = "Unknown Types value.";
    t[433] = "Valor de Types desconhecido.";
    t[434] = "Operation requires a scrollable ResultSet, but this ResultSet is FORWARD_ONLY.";
    t[435] = "Operação requer um ResultSet rolável, mas este ResultSet é FORWARD_ONLY (somente para frente).";
    t[450] = "No function outputs were registered.";
    t[451] = "Nenhum saída de função foi registrada.";
    t[454] = "Conversion of money failed.";
    t[455] = "Conversão de money falhou.";
    t[460] = "xid must not be null";
    t[461] = "xid não deve ser nulo";
    t[462] = "The SSLSocketFactory class provided {0} could not be instantiated.";
    t[463] = "A classe SSLSocketFactory forneceu {0} que não pôde ser instanciado.";
    t[466] = "Large Objects may not be used in auto-commit mode.";
    t[467] = "Objetos Grandes não podem ser usados no modo de efetivação automática (auto-commit).";
    t[468] = "{0} function takes one and only one argument.";
    t[469] = "função {0} recebe somente um argumento.";
    t[470] = "Unable to convert DOMResult SQLXML data to a string.";
    t[471] = "Não foi possível converter dado SQLXML do DOMResult para uma cadeia de caracteres.";
    t[474] = "Cannot call updateRow() when on the insert row.";
    t[475] = "Não pode chamar updateRow() quando estiver inserindo registro.";
    t[478] = "Can''t use relative move methods while on the insert row.";
    t[479] = "Não pode utilizar métodos de movimentação relativos enquanto estiver inserindo registro.";
    t[482] = "ResultSets with concurrency CONCUR_READ_ONLY cannot be updated.";
    t[483] = "ResultSets com CONCUR_READ_ONLY concorrentes não podem ser atualizados.";
    t[484] = "Unable to find name datatype in the system catalogs.";
    t[485] = "Não foi possível encontrar tipo de dado name nos catálogos do sistema.";
    t[486] = "Bind message length {0} too long.  This can be caused by very large or incorrect length specifications on InputStream parameters.";
    t[487] = "Tamanho de mensagem de ligação {0} é muito longo. Isso pode ser causado por especificações de tamanho incorretas ou muito grandes nos parâmetros do InputStream.";
    t[488] = "Can''t use query methods that take a query string on a PreparedStatement.";
    t[489] = "Não pode utilizar métodos de consulta que pegam uma consulta de um comando preparado.";
    t[490] = "A CallableStatement was executed with an invalid number of parameters";
    t[491] = "Uma função foi executada com um número inválido de parâmetros";
    t[500] = "Cannot call deleteRow() when on the insert row.";
    t[501] = "Não pode chamar deleteRow() quando estiver inserindo registro.";
    t[502] = "A CallableStatement was declared, but no call to registerOutParameter(1, <some type>) was made.";
    t[503] = "Uma função foi declarada mas nenhuma chamada a registerOutParameter (1, <algum_tipo>) foi feita.";
    t[508] = "Currently positioned before the start of the ResultSet.  You cannot call deleteRow() here.";
    t[509] = "Posicionado antes do início do ResultSet.  Você não pode chamar deleteRow() aqui.";
    t[510] = "{0} function takes three and only three arguments.";
    t[511] = "função {0} recebe três e somente três argumentos.";
    t[518] = "Query timeout must be a value greater than or equals to 0.";
    t[519] = "Tempo de espera da consulta deve ser um valor maior ou igual a 0.";
    t[520] = "There are no rows in this ResultSet.";
    t[521] = "Não há nenhum registro neste ResultSet.";
    t[524] = "Heuristic commit/rollback not supported. forget xid={0}";
    t[525] = "Efetivação/Cancelamento heurístico não é suportado. forget xid={0}";
    t[528] = "Provided Reader failed.";
    t[529] = "Reader fornecido falhou.";
    t[530] = "Internal Query: {0}";
    t[531] = "Consulta Interna: {0}";
    t[532] = "The JVM claims not to support the {0} encoding.";
    t[533] = "A JVM reclamou que não suporta a codificação {0}.";
    t[544] = "The column name {0} was not found in this ResultSet.";
    t[545] = "A nome da coluna {0} não foi encontrado neste ResultSet.";
    t[546] = "Error rolling back transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[547] = "Erro ao cancelar transação. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[554] = "Unsupported value for stringtype parameter: {0}";
    t[555] = "Valor do parâmetro stringtype não é suportado: {0}";
    t[560] = "No value specified for parameter {0}.";
    t[561] = "Nenhum valor especificado para parâmetro {0}.";
    t[562] = "Can''t refresh the insert row.";
    t[563] = "Não pode renovar um registro inserido.";
    t[566] = "The array index is out of range: {0}";
    t[567] = "O índice da matriz está fora do intervalo: {0}";
    t[568] = "ClientInfo property not supported.";
    t[569] = "propriedade ClientInfo não é suportada.";
    t[570] = "Malformed function or procedure escape syntax at offset {0}.";
    t[571] = "Sintaxe de escape mal formada da função ou do procedimento no deslocamento {0}.";
    t[578] = "Error committing prepared transaction. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[579] = "Erro ao efetivar transação preparada. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[586] = "This SQLXML object has already been freed.";
    t[587] = "Este objeto SQLXML já foi liberado.";
    t[590] = "One-phase commit called for xid {0} but connection was prepared with xid {1}";
    t[591] = "Efetivação de uma fase chamada para o xid {0}, mas a conexão foi preparada com o xid {1}";
    t[602] = "One-phase commit with unknown xid. commit xid={0}, currentXid={1}";
    t[603] = "Efetivação de uma fase com xid desconhecido. commit xid={0}, currentXid={1}";
    t[606] = "Position: {0}";
    t[607] = "Posição: {0}";
    t[612] = "Detail: {0}";
    t[613] = "Detalhe: {0}";
    t[616] = "The JVM claims not to support the encoding: {0}";
    t[617] = "A JVM reclamou que não suporta a codificação: {0}";
    t[618] = "Unable to determine a value for MaxIndexKeys due to missing system catalog data.";
    t[619] = "Não foi possível determinar um valor para MaxIndexKeys por causa de falta de dados no catálogo do sistema.";
    t[620] = "Invalid fetch direction constant: {0}.";
    t[621] = "Constante de direção da busca é inválida: {0}.";
    t[622] = "Multiple ResultSets were returned by the query.";
    t[623] = "ResultSets múltiplos foram retornados pela consulta.";
    t[626] = "The server does not support SSL.";
    t[627] = "O servidor não suporta SSL.";
    t[630] = "Server SQLState: {0}";
    t[631] = "SQLState: {0}";
    t[632] = "Premature end of input stream, expected {0} bytes, but only read {1}.";
    t[633] = "Fim de entrada prematuro, eram esperados {0} bytes, mas somente {1} foram lidos.";
    t[636] = "Expected an EOF from server, got: {0}";
    t[637] = "Esperado um EOF do servidor, recebido: {0}";
    t[638] = "Hint: {0}";
    t[639] = "Dica: {0}";
    t[640] = "Interrupted while attempting to connect.";
    t[641] = "Interrompido ao tentar se conectar.";
    t[642] = "The connection attempt failed.";
    t[643] = "A tentativa de conexão falhou.";
    t[644] = "Too many update results were returned.";
    t[645] = "Muitos resultados de atualização foram retornados.";
    t[650] = "Cannot convert an instance of {0} to type {1}";
    t[651] = "Não pode converter uma instância de {0} para tipo {1}";
    t[652] = "Prepare must be issued on the connection that started the branch. Transaction interleaving is not supported. prepare xid={0}, currentXid={1}";
    t[653] = "Prepare deve ser executado na conexão que iniciou o ramo. Intercalação de transações não é suportada. prepare xid={0}, currentXid={1}";
    t[660] = "One-phase commit must be issued on the connection that started the branch. commit xid={0}";
    t[661] = "A efetivação de uma fase deve ser executada na conexão que iniciou o ramo. commit xid={0}";
    t[664] = "The maximum field size must be a value greater than or equal to 0.";
    t[665] = "O tamanho máximo de um campo deve ser um valor maior ou igual a 0.";
    t[666] = "Interval {0} not yet implemented";
    t[667] = "Intervalo {0} ainda não foi implementado";
    t[668] = "Parameter of type {0} was registered, but call to get{1} (sqltype={2}) was made.";
    t[669] = "Parâmetro do tipo {0} foi registrado, mas uma chamada a get{1} (tiposql={2}) foi feita.";
    t[672] = "Current connection does not have an associated xid. prepare xid={0}";
    t[673] = "A conexão atual não possui um xid associado. prepare xid={0}";
    t[674] = "Cannot establish a savepoint in auto-commit mode.";
    t[675] = "Não pode estabelecer um savepoint no modo de efetivação automática (auto-commit).";
    t[676] = "A result was returned when none was expected.";
    t[677] = "Um resultado foi retornado quando nenhum era esperado.";
    table = t;
  }
  public java.lang.Object handleGetObject (java.lang.String msgid) throws java.util.MissingResourceException {
    int hash_val = msgid.hashCode() & 0x7fffffff;
    int idx = (hash_val % 343) << 1;
    {
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
    int incr = ((hash_val % 341) + 1) << 1;
    for (;;) {
      idx += incr;
      if (idx >= 686)
        idx -= 686;
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
  }
  public java.util.Enumeration getKeys () {
    return
      new java.util.Enumeration() {
        private int idx = 0;
        { while (idx < 686 && table[idx] == null) idx += 2; }
        public boolean hasMoreElements () {
          return (idx < 686);
        }
        public java.lang.Object nextElement () {
          java.lang.Object key = table[idx];
          do idx += 2; while (idx < 686 && table[idx] == null);
          return key;
        }
      };
  }
  public java.util.ResourceBundle getParent () {
    return parent;
  }
}
