/* Automatically generated by GNU msgfmt.  Do not modify!  */
package org.postgresql.translation;
public class messages_ru extends java.util.ResourceBundle {
  private static final java.lang.String[] table;
  static {
    java.lang.String[] t = new java.lang.String[1502];
    t[0] = "";
    t[1] = "Project-Id-Version: JDBC Driver for PostgreSQL 8.x.x\nReport-Msgid-Bugs-To: \nPO-Revision-Date: 2016-01-07 15:09+0300\nLast-Translator: Vladimir Sitnikov <sitnikov.vladimir@gmail.com>\nLanguage-Team: pgsql-rus <pgsql-rus@yahoogroups.com>\nLanguage: ru_RU\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Generator: Poedit 1.5.7\n";
    t[2] = "Read from copy failed.";
    t[3] = "Не удалось прочитать данные из COPY.";
    t[8] = "Requested CopyIn but got {0}";
    t[9] = "Ожидался ответ CopyIn, а получен {0}";
    t[10] = "Connection to {0} refused. Check that the hostname and port are correct and that the postmaster is accepting TCP/IP connections.";
    t[11] = "Подключение по адресу {0} отклонено. Проверьте, что хост и порт указаны правильно и что postmaster принимает TCP/IP-соединения.";
    t[16] = "Can't convert {0} to {1} literal";
    t[17] = "Невозможно преобразовать {0} в литерал {1}";
    t[18] = "Channel binding is required, but server requested ''{0}'' authentication. Channel binding is only supported with SCRAM authentication over encrypted connections.";
    t[19] = "Требуется channel binding, но сервер запросил аутентификацию ''{0}''. Channel binding поддерживается только с аутентификацией SCRAM по зашифрованному соединению.";
    t[28] = "This connection has been closed.";
    t[29] = "Соединение закрыто.";
    t[38] = "Batch entry {0} {1} was aborted: {2}  Call getNextException to see other errors in the batch.";
    t[39] = "Пакетный запрос {0} {1} прерван: {2}  Вызовите getNextException, чтобы получить остальные ошибки пакета.";
    t[46] = "Channel binding is required, but server skipped authentication. Channel binding is only supported with SCRAM authentication over encrypted connections.";
    t[47] = "Требуется channel binding, но сервер пропустил аутентификацию. Channel binding поддерживается только с аутентификацией SCRAM по зашифрованному соединению.";
    t[48] = "Unexpected command status: {0}.";
    t[49] = "Неожиданный статус команды: {0}.";
    t[54] = "Could not initialize PEMKeyManager.";
    t[55] = "Не удалось инициализировать PEMKeyManager.";
    t[58] = "An error occurred while trying to get the socket timeout.";
    t[59] = "Ошибка при попытке получить таймаут сокета.";
    t[60] = "Invalid character data was found.  This is most likely caused by stored data containing characters that are invalid for the character set the database was created in.  The most common example of this is storing 8bit data in a SQL_ASCII database.";
    t[61] = "Найдены неверные символьные данные.  Причиной этого, скорее всего, являются хранимые данные, содержащие символы, не соответствующие набору символов базы.  Типичный пример — хранение 8-битных данных в базе SQL_ASCII.";
    t[62] = "Fetch size must be a value greater than or equal to 0.";
    t[63] = "Размер выборки (fetch size) должен быть больше или равен 0.";
    t[64] = "The server does not support GSS Encryption.";
    t[65] = "Сервер не поддерживает GSS Encryption.";
    t[72] = "A result was returned when none was expected.";
    t[73] = "Результат возвращён, хотя не ожидался.";
    t[82] = "Tried to end inactive copy";
    t[83] = "Попытка завершить неактивную операцию COPY";
    t[84] = "The server''s standard_conforming_strings parameter was reported as {0}. The JDBC driver expected on or off.";
    t[85] = "Параметр сервера standard_conforming_strings установлен в {0}. JDBC-драйвер ожидал on или off.";
    t[92] = "Channel Binding is required, but server did not offer an authentication method that supports channel binding";
    t[93] = "Требуется channel binding, но сервер не предложил метод аутентификации с поддержкой channel binding";
    t[94] = "Multi-statement SQL is not supported in Statement.addBatch(); call addBatch() once per statement instead.";
    t[95] = "Statement.addBatch() не поддерживает SQL с несколькими запросами; вызывайте addBatch() отдельно на каждый запрос.";
    t[102] = "The parameter index is out of range: {0}, number of parameters: {1}.";
    t[103] = "Индекс параметра вне диапазона: {0}. Допустимые значения: 1..{1}";
    t[104] = "Unknown value for ResultSet type";
    t[105] = "Неизвестное значение типа ResultSet";
    t[106] = "Could not close SSL certificate file {0}.";
    t[107] = "Не удалось закрыть файл SSL-сертификата {0}.";
    t[112] = "Could not read password for SSL key file, console is not available.";
    t[113] = "Не удалось прочитать пароль для файла ключа SSL: консоль недоступна.";
    t[124] = "Unsupported properties: {0}";
    t[125] = "Указанные свойства не поддерживаются: {0}";
    t[132] = "Invalid fetch direction constant: {0}.";
    t[133] = "Неверная константа направления выборки: {0}.";
    t[134] = "Protocol error.  Session setup failed.";
    t[135] = "Ошибка протокола.  Не удалось установить сессию.";
    t[146] = "Unexpected packet type during copy: {0}";
    t[147] = "Неожиданный тип пакета во время COPY: {0}";
    t[148] = "Error opening transaction. start xid={0}";
    t[149] = "Ошибка при открытии транзакции. start xid={0}";
    t[152] = "Validating connection.";
    t[153] = "Проверка соединения.";
    t[154] = "The SSLSocketFactory class provided {0} could not be instantiated.";
    t[155] = "Не удалось создать SSLSocketFactory из указанного класса {0}.";
    t[156] = "Prepare called before end(). prepare xid={0}, state={1}";
    t[157] = "prepare вызван до end(). prepare xid={0}, state={1}";
    t[158] = "Unable to bind parameter values for statement.";
    t[159] = "Не удалось привязать значения параметров к запросу.";
    t[162] = "The array index is out of range: {0}, number of elements: {1}.";
    t[163] = "Индекс массива вне диапазона: {0}. Допустимые значения: 1..{1}";
    t[164] = "Invalid version number major: {0}, minor: {1}";
    t[165] = "Неверный номер версии: major={0}, minor={1}";
    t[168] = "The system property containing the server's SSL certificate must not be empty.";
    t[169] = "Системное свойство с SSL-сертификатом сервера не должно быть пустым.";
    t[170] = "The fastpath function {0} is unknown.";
    t[171] = "Функция fastpath {0} неизвестна.";
    t[172] = "Hint: {0}";
    t[173] = "Подсказка: {0}";
    t[174] = "Parameter of type {0} was registered, but call to get{1} (sqltype={2}) was made.";
    t[175] = "Зарегистрирован параметр типа {0}, но был вызван get{1} (sqltype={2}).";
    t[180] = "Fastpath call {0} - No result was returned or wrong size while expecting a long.";
    t[181] = "Вызов fastpath {0} ничего не вернул либо вернул значение неверного размера; ожидался long.";
    t[188] = "Hostname {0} is invalid";
    t[189] = "Имя хоста {0} некорректно";
    t[190] = "Can not reset stream for large object {0} to position {1}";
    t[191] = "Не удалось перевести поток большого объекта {0} в позицию {1}";
    t[200] = "Unable to decode xml data.";
    t[201] = "Не удалось декодировать XML-данные.";
    t[204] = "Backend timezone is not known. Backend should have returned TimeZone when establishing a connection";
    t[205] = "Таймзона сервера неизвестна. Сервер должен был передать TimeZone при установке соединения";
    t[208] = "LOB positioning offsets start at 1.";
    t[209] = "Смещения позиции в LOB начинаются с 1.";
    t[212] = "Maximum number of rows must be a value greater than or equal to 0.";
    t[213] = "Максимальное число строк должно быть больше или равно 0.";
    t[214] = "Cannot tell if path is open or closed: {0}.";
    t[215] = "Не удалось определить, открыт путь или замкнут: {0}.";
    t[216] = "Ran out of memory retrieving query results.";
    t[217] = "Недостаточно памяти для обработки результатов запроса. Попробуйте увеличить -Xmx или проверьте размеры обрабатываемых данных.";
    t[226] = "Unexpected error when closing Blob binary stream";
    t[227] = "Неожиданная ошибка при закрытии бинарного потока Blob";
    t[228] = "Could not load the private key";
    t[229] = "Не удалось загрузить приватный ключ";
    t[232] = "Conversion of money failed.";
    t[233] = "Ошибка при преобразовании типа money.";
    t[234] = "Invalid stream length {0}.";
    t[235] = "Неверная длина потока {0}.";
    t[242] = "Fastpath call {0} - No result was returned and we expected a numeric.";
    t[243] = "Вызов fastpath {0} ничего не вернул, а ожидался numeric.";
    t[246] = "Can not close large object {0}";
    t[247] = "Не удалось закрыть большой объект {0}.";
    t[248] = "Something unusual has occurred to cause the driver to fail. Please report this exception.";
    t[249] = "Драйвер столкнулся с непредвиденной ошибкой. Сообщите об этом исключении.";
    t[250] = "{0} function takes four and only four argument.";
    t[251] = "Функция {0} принимает ровно четыре аргумента.";
    t[256] = "Cannot truncate LOB to a negative length.";
    t[257] = "Нельзя усечь LOB до отрицательной длины.";
    t[264] = "Copying from database failed: {0}";
    t[265] = "Не удалось скопировать данные из базы: {0}";
    t[270] = "Connection has been closed automatically because a new connection was opened for the same PooledConnection or the PooledConnection has been closed.";
    t[271] = "Соединение закрыто автоматически: для того же PooledConnection было открыто новое соединение либо сам PooledConnection закрыт.";
    t[272] = "Result set exceeded maxResultBuffer limit. Received:  {0}; Current limit: {1}";
    t[273] = "Результат превысил лимит maxResultBuffer. Получено: {0}; текущий лимит: {1}";
    t[292] = "Could not load cert chain";
    t[293] = "Не удалось загрузить цепочку сертификатов";
    t[298] = "Database connection failed when writing to copy";
    t[299] = "Сбой соединения с БД при записи в COPY";
    t[300] = "Unable to retrieve the permissions of the private key file \"{0}\"";
    t[301] = "Не удалось получить права доступа к файлу приватного ключа \"{0}\"";
    t[308] = "Unable to convert DOMResult SQLXML data to a string.";
    t[309] = "Не удалось преобразовать DOMResult SQLXML в строку.";
    t[310] = "Heuristic commit/rollback not supported. forget xid={0}";
    t[311] = "Эвристический commit/rollback не поддерживается. forget xid={0}";
    t[312] = "The sslfactoryarg property may not be empty.";
    t[313] = "Свойство sslfactoryarg не должно быть пустым.";
    t[320] = "Server name validation failed: certificate for hostname {0} has no DNS subjectAltNames, and it CommonName is missing as well";
    t[321] = "Проверка имени сервера не прошла: в сертификате для хоста {0} нет ни DNS subjectAltName, ни CommonName";
    t[322] = "Error during one-phase commit. commit xid={0}";
    t[323] = "Ошибка при однофазной фиксации транзакции. commit xid={0}";
    t[324] = "The column index is out of range: {0}, number of columns: {1}.";
    t[325] = "Индекс колонки вне диапазона: {0}. Допустимые значения: 1..{1}";
    t[330] = "Unable to load the class {0} responsible for the datatype {1}";
    t[331] = "Не удалось загрузить класс {0}, отвечающий за тип данных {1}";
    t[332] = "Unable to get network timeout.";
    t[333] = "Не удалось получить сетевой таймаут.";
    t[334] = "Database connection failed when starting copy";
    t[335] = "Сбой соединения с БД при запуске COPY";
    t[338] = "Got CopyBothResponse from server during an active {0}";
    t[339] = "Получен CopyBothResponse от сервера во время активной операции {0}";
    t[340] = "Cannot call deleteRow() when on the insert row.";
    t[341] = "Нельзя вызывать deleteRow() на строке вставки.";
    t[346] = "Expected a row when reading password_encryption but none was found";
    t[347] = "При чтении password_encryption ожидалась строка, но ничего не получено";
    t[348] = "Zero bytes may not occur in string parameters.";
    t[349] = "Нулевой байт недопустим в строковых параметрах.";
    t[350] = "private key file \"{0}\" has group or world access; file must have permissions u=rw (0600) or less if owned by the current user, or permissions u=rw,g=r (0640) or less if owned by root. Current permissions: {1}";
    t[351] = "файл приватного ключа \"{0}\" доступен группе или всем; права должны быть не шире u=rw (0600) для владельца либо u=rw,g=r (0640), если владелец — root. Текущие права: {1}";
    t[354] = "Cannot change transaction read-only property in the middle of a transaction.";
    t[355] = "Нельзя изменить свойство read-only в середине транзакции.";
    t[356] = "Cannot retrieve the name of an unnamed savepoint.";
    t[357] = "Нельзя получить имя безымянной точки сохранения.";
    t[360] = "The server does not support GSS Encoding.";
    t[361] = "Сервер не поддерживает GSS Encoding.";
    t[362] = "Could not decrypt SSL key file {0}.";
    t[363] = "Не удалось расшифровать файл ключа SSL {0}.";
    t[370] = "Database connection failed when reading from copy";
    t[371] = "Сбой соединения с БД при чтении из COPY";
    t[372] = "Invalid Inet data.";
    t[373] = "Некорректные данные inet.";
    t[374] = "Query timeout must be a value greater than or equal to 0.";
    t[375] = "Таймаут запроса должен быть больше или равен 0.";
    t[376] = "Error preparing transaction. prepare xid={0}";
    t[377] = "Ошибка при выполнении prepare для транзакции {0}";
    t[388] = "Unable to find keywords in the system catalogs.";
    t[389] = "В системных каталогах не найдены ключевые слова.";
    t[394] = "Suspend/resume not implemented";
    t[395] = "Операции XA suspend/resume не реализованы";
    t[400] = "Could not parse maxResultBuffer value {0}; percent values require {1}.";
    t[401] = "Не удалось разобрать значение maxResultBuffer {0}; для процентных значений нужно {1}.";
    t[404] = "Could not initialize SSL context.";
    t[405] = "Не удалось инициализировать SSL-контекст.";
    t[406] = "Statement has been closed.";
    t[407] = "Statement закрыт.";
    t[410] = "This SQLXML object has already been initialized, so you cannot manipulate it further.";
    t[411] = "Объект SQLXML уже инициализирован, дальнейшие изменения недоступны.";
    t[412] = "requireAuth contains duplicate authentication method";
    t[413] = "В свойстве requireAuth есть дублирующиеся методы аутентификации";
    t[414] = "Location: File: {0}, Routine: {1}, Line: {2}";
    t[415] = "Расположение: Файл: {0}, Процедура: {1}, Строка: {2}";
    t[420] = "This statement has been closed.";
    t[421] = "Этот Statement закрыт.";
    t[422] = "Failed to create object for: {0}.";
    t[423] = "Ошибка при создании объекта: {0}.";
    t[424] = "Internal Position: {0}";
    t[425] = "Внутренняя позиция: {0}";
    t[426] = "SCRAM authentication failed: {0}";
    t[427] = "Аутентификация SCRAM не удалась: {0}";
    t[428] = "Server name validation pass for {0}, subjectAltName {1}";
    t[429] = "Имя сервера {0} подтверждено через subjectAltName {1}";
    t[436] = "Server requested {0} SCRAM PBKDF2 iterations, which exceeds the client-side limit of {1}. If you trust this server, raise the {2} connection property.";
    t[437] = "Сервер запросил {0} итераций SCRAM PBKDF2, что превышает клиентский лимит {1}. Если этому серверу можно доверять, увеличьте свойство соединения {2}.";
    t[438] = "Invalid UUID data.";
    t[439] = "Некорректные данные UUID.";
    t[446] = "No value specified for parameter {0}.";
    t[447] = "Не указано значение для параметра {0}.";
    t[448] = "The server requested SCRAM-based authentication, but the password is an empty string.";
    t[449] = "Сервер запросил аутентификацию SCRAM, но пароль пуст.";
    t[456] = "Malformed function or procedure escape syntax at offset {0}.";
    t[457] = "Ошибка в синтаксисе JDBC-escape функции или процедуры на позиции {0}.";
    t[464] = "No function outputs were registered.";
    t[465] = "Выходные параметры функции не зарегистрированы.";
    t[470] = "Authentication method is not allowed by requireAuth";
    t[471] = "Метод аутентификации запрещён настройкой requireAuth";
    t[484] = "Unable to set network timeout.";
    t[485] = "Не удалось задать сетевой таймаут.";
    t[488] = "An error occurred while setting up the SSL connection.";
    t[489] = "Ошибка при установке SSL-соединения.";
    t[496] = "Channel Binding is required, but SSL is not in use";
    t[497] = "Требуется channel binding, но SSL не используется";
    t[500] = "No results were returned by the query.";
    t[501] = "Запрос не вернул результатов.";
    t[506] = "One-phase commit must be issued on the connection that started the branch. commit xid={0}";
    t[507] = "Однофазная фиксация должна выполняться на том соединении, которое начало ветвь. commit xid={0}";
    t[510] = "Got CopyData without an active copy operation";
    t[511] = "Получены данные CopyData без активной операции COPY";
    t[512] = "User cannot be null";
    t[513] = "Параметр user не должен быть null";
    t[518] = "This PooledConnection has already been closed.";
    t[519] = "PooledConnection уже закрыт.";
    t[522] = "conversion to {0} from {1} not supported";
    t[523] = "Преобразование из {1} в {0} не поддерживается.";
    t[526] = "Cannot cast to boolean: \"{0}\"";
    t[527] = "Невозможно привести к boolean: \"{0}\"";
    t[528] = "Unsupported value for stringtype parameter: {0}";
    t[529] = "Неподдерживаемое значение параметра stringtype: {0}";
    t[530] = "Too many update results were returned.";
    t[531] = "Возвращено слишком много результатов обновления.";
    t[534] = "CommandComplete expected COPY but got: {0}";
    t[535] = "В CommandComplete ожидалось COPY, получено: {0}";
    t[536] = "The array index is out of range: {0}";
    t[537] = "Индекс массива вне диапазона: {0}";
    t[540] = "The server requested password-based authentication, but no password was provided by plugin {0}";
    t[541] = "Сервер запросил парольную аутентификацию, но плагин {0} не вернул пароль.";
    t[542] = "Method {0} is not yet implemented.";
    t[543] = "Метод {0} ещё не реализован.";
    t[546] = "Where: {0}";
    t[547] = "Где: {0}";
    t[550] = "Got CopyInResponse from server during an active {0}";
    t[551] = "Получен CopyInResponse от сервера во время активной операции {0}";
    t[556] = "Connection is already associated with an active XA branch. End the current branch before starting a new one. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[557] = "Соединение уже связано с активной XA-ветвью. Завершите текущую ветвь, прежде чем начинать новую. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[560] = "Could not read permissions for private key file \"{0}\"";
    t[561] = "Не удалось прочитать права доступа к файлу приватного ключа \"{0}\"";
    t[562] = "Unknown value for ResultSet concurrency";
    t[563] = "Неизвестное значение concurrency для ResultSet";
    t[566] = "The authentication type {0} is not supported. Check that you have configured the pg_hba.conf file to include the client''s IP address or subnet, and that it is using an authentication scheme supported by the driver.";
    t[567] = "Тип аутентификации {0} не поддерживается. Убедитесь, что файл pg_hba.conf настроен на приём IP-адреса или подсети клиента, а также использует схему аутентификации, поддерживаемую драйвером.";
    t[568] = "Unexpected packet type during replication: {0}";
    t[569] = "Неожиданный тип пакета при репликации: {0}";
    t[570] = "Interval {0} not yet implemented";
    t[571] = "Интервал {0} ещё не реализован.";
    t[572] = "Unknown Types value.";
    t[573] = "Неизвестная константа java.sql.Types.";
    t[574] = "Interrupted while waiting to obtain lock on database connection";
    t[575] = "Поток прерван во время ожидания блокировки соединения с БД.";
    t[582] = "Conversion of interval failed";
    t[583] = "Не удалось преобразовать интервал.";
    t[584] = "Can''t infer the SQL type to use for an instance of {0}. Use setObject() with an explicit Types value to specify the type to use.";
    t[585] = "Не удалось вывести SQL-тип для объекта типа {0}. Вызовите setObject() с явным значением Types.";
    t[586] = "Enter SSL password: ";
    t[587] = "Введите пароль SSL: ";
    t[588] = "This SQLXML object has already been freed.";
    t[589] = "Этот объект SQLXML уже освобождён.";
    t[590] = "Could not find a java cryptographic algorithm: X.509 CertificateFactory not available.";
    t[591] = "Криптоалгоритм Java недоступен: CertificateFactory X.509 не найден.";
    t[594] = "Error during recover. flag={0}";
    t[595] = "Ошибка при восстановлении. flag={0}";
    t[600] = "Could not find a server with specified targetServerType: {0}";
    t[601] = "Не удалось найти сервер с указанным значением targetServerType: {0}";
    t[606] = "Zero bytes may not occur in identifiers.";
    t[607] = "Нулевой байт недопустим в идентификаторах.";
    t[608] = "free() was called on this LOB previously";
    t[609] = "Метод free() уже был вызван для этого LOB";
    t[612] = "Unable to parse URL {0}";
    t[613] = "Не удалось разобрать URL {0}";
    t[614] = "Could not read password for SSL key file by callbackhandler {0}.";
    t[615] = "Не удалось получить пароль для файла ключа SSL через callbackhandler {0}.";
    t[618] = "{0} function doesn''t take any argument.";
    t[619] = "Функция {0} не принимает аргументов.";
    t[624] = "Protocol error. Cancel Key should be 4 bytes for protocol version {0}, but received {1} bytes. Session setup failed.";
    t[625] = "Ошибка протокола. Для версии протокола {0} Cancel Key должен занимать 4 байта, получено: {1}. Не удалось установить сессию.";
    t[634] = "PostgreSQL LOBs can only index to: {0}";
    t[635] = "LOB в PostgreSQL поддерживает индексацию максимум до {0}";
    t[636] = "The server''s DateStyle parameter was changed to {0}. The JDBC driver requires DateStyle to begin with ISO for correct operation.";
    t[637] = "Параметр сервера DateStyle изменён на {0}. Для корректной работы JDBC-драйвера значение DateStyle должно начинаться с ISO.";
    t[638] = "Expected command status BEGIN, got {0}.";
    t[639] = "Ожидался статус команды BEGIN, но получен {0}.";
    t[640] = "Transaction control methods setAutoCommit, commit, rollback and setSavepoint are not allowed while an XA transaction is active.";
    t[641] = "Методы управления транзакциями (setAutoCommit, commit, rollback и setSavepoint) запрещены во время активной XA-транзакции.";
    t[646] = "This statement does not declare an OUT parameter.  Use '{' ?= call ... '}' to declare one.";
    t[647] = "В этом запросе не объявлен OUT-параметр.  Используйте '{' ?= call ... '}' для его объявления.";
    t[648] = "You must specify at least one column value to insert a row.";
    t[649] = "Для вставки строки укажите хотя бы одно значение столбца.";
    t[652] = "hstore key must not be null";
    t[653] = "Ключ hstore не может быть null";
    t[658] = "Large Objects may not be used in auto-commit mode.";
    t[659] = "Большие объекты нельзя использовать в режиме autoCommit.";
    t[660] = "Requested CopyOut but got {0}";
    t[661] = "Ожидался ответ CopyOut, а получен {0}";
    t[662] = "Current connection does not have an associated xid. prepare xid={0}";
    t[663] = "У текущего соединения нет связанного xid. prepare xid={0}";
    t[664] = "No certificates found for hostname {0}";
    t[665] = "Для хоста {0} не найдено ни одного сертификата";
    t[670] = "Cannot update the ResultSet because it is either before the start or after the end of the results.";
    t[671] = "Нельзя обновить ResultSet: позиция находится до первой строки или после последней.";
    t[674] = "The column name {0} was not found in this ResultSet.";
    t[675] = "Столбец {0} не найден в этом ResultSet.";
    t[680] = "Failed to convert binary xml data to encoding: {0}.";
    t[681] = "Не удалось преобразовать бинарные XML-данные в кодировку: {0}.";
    t[682] = "Detail: {0}";
    t[683] = "Подробности: {0}";
    t[684] = "oid type {0} not known and not a number";
    t[685] = "Тип OID {0} неизвестен и не является числом";
    t[686] = "Currently positioned before the start of the ResultSet.  You cannot call deleteRow() here.";
    t[687] = "Позиция находится перед началом ResultSet.  Здесь нельзя вызывать deleteRow().";
    t[692] = "Server name validation failed: certificate for host {0} dNSName entries subjectAltName, but none of them match. Assuming server name validation failed";
    t[693] = "Проверка имени сервера не прошла: в subjectAltName сертификата для хоста {0} есть записи dNSName, но ни одна не совпала.";
    t[696] = "This SQLXML object has not been initialized, so you cannot retrieve data from it.";
    t[697] = "Объект SQLXML не инициализирован, прочитать данные из него нельзя.";
    t[700] = "WARNING! Required to allocate {0} bytes, which exceeded possible heap memory size. Assigned {1} bytes as limit.";
    t[701] = "WARNING: запрошено {0} байт, что превышает доступный размер кучи. В качестве лимита установлено {1} байт.";
    t[702] = "Interrupted while attempting to connect.";
    t[703] = "Поток прерван во время подключения.";
    t[706] = "{0} returned no results";
    t[707] = "{0} не вернул результатов";
    t[712] = "Tried to break lock on database connection";
    t[713] = "Попытка снять блокировку соединения с БД";
    t[716] = "DataSource has been closed.";
    t[717] = "DataSource закрыт.";
    t[720] = "This large object has been closed.";
    t[721] = "Этот большой объект закрыт.";
    t[722] = "Returning autogenerated keys by column index is not supported.";
    t[723] = "Возврат автогенерируемых ключей по индексу столбца не поддерживается.";
    t[728] = "The sslfactoryarg property must start with the prefix file:, classpath:, env:, sys:, or -----BEGIN CERTIFICATE-----.";
    t[729] = "Значение sslfactoryarg должно начинаться с file:, classpath:, env:, sys: или -----BEGIN CERTIFICATE-----.";
    t[736] = "Unable to parse certificates for hostname {0}";
    t[737] = "Не удалось разобрать сертификаты для хоста {0}.";
    t[738] = "Invalid elements {0}";
    t[739] = "Неверные элементы {0}";
    t[740] = "Unable to find name datatype in the system catalogs.";
    t[741] = "В системных каталогах не найден тип данных name.";
    t[760] = "Unable to parse the count in command completion tag: {0}.";
    t[761] = "Не удалось разобрать число строк в теге завершения команды: {0}.";
    t[762] = "Transaction was already prepared on this connection. prepare xid={0}, preparedXid={1}";
    t[763] = "Транзакция уже подготовлена на этом соединении. prepare xid={0}, preparedXid={1}";
    t[766] = "The connection attempt failed.";
    t[767] = "Не удалось подключиться.";
    t[768] = "Added parameters index out of range: {0}, number of columns: {1}.";
    t[769] = "Индекс добавляемого параметра вне диапазона: {0}, число параметров: {1}.";
    t[774] = "Tried to cancel an inactive copy operation";
    t[775] = "Попытка отменить неактивную операцию COPY";
    t[778] = "Query timeout must be a value greater than or equals to 0.";
    t[779] = "Таймаут запроса должен быть больше или равен 0.";
    t[782] = "Cannot convert the column of type {0} to requested type {1}.";
    t[783] = "Невозможно преобразовать столбец типа {0} к запрошенному типу {1}.";
    t[786] = "Internal Query: {0}";
    t[787] = "Внутренний запрос: {0}";
    t[788] = "Unknown XML Source class: {0}";
    t[789] = "Неизвестный класс XML Source: {0}";
    t[794] = "The JVM claims not to support the encoding: {0}";
    t[795] = "JVM не поддерживает кодировку: {0}";
    t[798] = "Unexpected copydata from server for {0}";
    t[799] = "Неожиданные данные COPY от сервера для активной операции {0}.";
    t[802] = "Unknown type {0}.";
    t[803] = "Неизвестный тип {0}.";
    t[808] = "Cannot call updateRow() when on the insert row.";
    t[809] = "Нельзя вызывать updateRow() на строке вставки.";
    t[812] = "Server name validation failed: unable to extract common name from X509Certificate for hostname {0}";
    t[813] = "Проверка имени сервера не прошла: не удалось извлечь common name из X509Certificate для хоста {0}";
    t[814] = "Requested CopyDual but got {0}";
    t[815] = "Ожидался ответ CopyDual, а получен {0}";
    t[816] = "Missing expected error response to copy cancel request";
    t[817] = "Ожидался ответ с ошибкой на запрос отмены COPY, но он не получен";
    t[818] = "Cannot cast an instance of {0} to type {1}";
    t[819] = "Невозможно привести объект типа {0} к типу {1}";
    t[822] = "Invalid gssEncMode value: {0}";
    t[823] = "Неверное значение параметра gssEncMode: {0}";
    t[824] = "No hstore extension installed.";
    t[825] = "Расширение hstore не установлено.";
    t[830] = "Invalid timeout ({0}<0).";
    t[831] = "Значение таймаута должно быть неотрицательным: {0}.";
    t[832] = "Unable to create StAXResult for SQLXML";
    t[833] = "Не удалось создать StAXResult для SQLXML";
    t[836] = "Transaction isolation level {0} not supported.";
    t[837] = "Уровень изоляции транзакций {0} не поддерживается.";
    t[838] = "The HostnameVerifier class provided {0} could not be instantiated.";
    t[839] = "Не удалось создать HostnameVerifier из указанного класса {0}.";
    t[842] = "Unable to find resource {0} via class {1} ClassLoader {2}";
    t[843] = "Не удалось найти ресурс {0} через ClassLoader {2} класса {1}";
    t[844] = "An unexpected result was returned by a query.";
    t[845] = "Запрос вернул неожиданный результат.";
    t[846] = "One-phase commit called for xid {0} but connection was prepared with xid {1}";
    t[847] = "Однофазная фиксация запрошена для xid {0}, но соединение подготовлено с xid {1}";
    t[850] = "Could not read ACL permissions for private key file \"{0}\"";
    t[851] = "Не удалось прочитать ACL-права файла приватного ключа \"{0}\"";
    t[852] = "A CallableStatement was executed with an invalid number of parameters";
    t[853] = "CallableStatement выполнен с неверным числом параметров";
    t[854] = "Premature end of input stream, expected {0} bytes, but only read {1}.";
    t[855] = "Раннее завершение входного потока, ожидалось байт: {0}, но считано только {1}.";
    t[862] = "Database connection failed when canceling copy operation";
    t[863] = "Сбой соединения с БД при отмене операции COPY";
    t[866] = "Invalid authentication method: {0}";
    t[867] = "Неверный метод аутентификации: {0}";
    t[870] = "This copy stream is closed.";
    t[871] = "Поток COPY закрыт.";
    t[872] = "Failed to setup DataSource.";
    t[873] = "Не удалось настроить DataSource.";
    t[874] = "{0} function takes one and only one argument.";
    t[875] = "Функция {0} принимает ровно один аргумент.";
    t[876] = "Can''t use relative move methods while on the insert row.";
    t[877] = "Методы относительного перемещения недоступны на строке вставки.";
    t[880] = "Could not find a java cryptographic algorithm: {0}.";
    t[881] = "Криптоалгоритм Java {0} недоступен.";
    t[882] = "No eligible primary or unique key found for table {0}.";
    t[883] = "Для таблицы {0} не найден подходящий первичный или уникальный ключ.";
    t[890] = "Operation requires a scrollable ResultSet, but this ResultSet is FORWARD_ONLY.";
    t[891] = "Операция требует прокручиваемый ResultSet, но текущий ResultSet — FORWARD_ONLY.";
    t[892] = "Tried to read from inactive copy";
    t[893] = "Попытка чтения из неактивной операции COPY";
    t[898] = "A connection could not be made using the requested protocol {0}.";
    t[899] = "Не удалось установить соединение по запрошенному протоколу {0}.";
    t[902] = "The maximum field size must be a value greater than or equal to 0.";
    t[903] = "Максимальный размер поля должен быть больше или равен 0.";
    t[906] = "Invalid value for autoGeneratedKeys {0}";
    t[907] = "Неверное значение параметра autoGeneratedKeys: {0}";
    t[908] = "Could not open SSL root certificate file {0}.";
    t[909] = "Не удалось открыть файл корневого SSL-сертификата {0}.";
    t[910] = "Invalid protocol state requested. Attempted transaction interleaving is not supported. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[911] = "Чередование транзакций в одном соединении не поддерживается. Предыдущую транзакцию нужно завершить. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[912] = "Error loading default settings from driverconfig.properties";
    t[913] = "Не удалось загрузить настройки по умолчанию из driverconfig.properties.";
    t[914] = "{0} function takes two and only two arguments.";
    t[915] = "Функция {0} принимает ровно два аргумента.";
    t[918] = "Unknown ResultSet holdability setting: {0}.";
    t[919] = "Неизвестное значение holdability для ResultSet: {0}.";
    t[920] = "The JVM claims not to support the {0} encoding.";
    t[921] = "JVM не поддерживает кодировку {0}.";
    t[932] = "The server does not support SSL.";
    t[933] = "Сервер не поддерживает SSL.";
    t[934] = "Provided InputStream failed.";
    t[935] = "Чтение из переданного InputStream завершилось ошибкой.";
    t[946] = "No X509TrustManager found";
    t[947] = "X509TrustManager не найден";
    t[948] = "Connection attempt timed out.";
    t[949] = "Истекло время ожидания подключения.";
    t[950] = "A CallableStatement was declared, but no call to registerOutParameter(1, <some type>) was made.";
    t[951] = "CallableStatement объявлен, но registerOutParameter(1, <тип>) не был вызван.";
    t[954] = "Can not write data to large object {0}, requested write length: {1}";
    t[955] = "Не удалось записать данные в большой объект {0}, запрошенная длина записи: {1}";
    t[956] = "Can not read data from large object {0}, position: {1}, buffer size: {2}";
    t[957] = "Не удалось прочитать данные большого объекта {0}, позиция: {1}, размер буфера: {2}";
    t[958] = "Could not read SSL key file {0}.";
    t[959] = "Не удалось прочитать файл ключа SSL {0}.";
    t[964] = "ClientInfo property not supported.";
    t[965] = "Свойство ClientInfo не поддерживается.";
    t[966] = "Invalid SCRAM client initialization";
    t[967] = "Некорректная инициализация SCRAM-клиента";
    t[970] = "Unknown Response Type {0}.";
    t[971] = "Неизвестный тип ответа {0}.";
    t[976] = "Unable to find resource {0} via Thread contextClassLoader {1}";
    t[977] = "Не удалось найти ресурс {0} через Thread contextClassLoader {1}";
    t[986] = "Could not instantiate xmlFactoryFactory: {0}";
    t[987] = "Не удалось создать xmlFactoryFactory: {0}";
    t[988] = "Truncation of large objects is only implemented in 8.3 and later servers.";
    t[989] = "Усечение больших объектов поддерживается только на сервере 8.3 и новее.";
    t[996] = "Unsupported binary encoding of {0}.";
    t[997] = "Бинарное кодирование типа {0} не поддерживается.";
    t[998] = "Unexpected error writing large object to database.";
    t[999] = "Неожиданная ошибка при записи большого объекта в базу.";
    t[1004] = "Can''t refresh the insert row.";
    t[1005] = "Нельзя обновить строку вставки.";
    t[1008] = "ResultSet not positioned properly, perhaps you need to call next.";
    t[1009] = "ResultSet установлен в неверную позицию: возможно, нужно вызвать next.";
    t[1010] = "Private key file \"{0}\" has insecure permissions. Non-owner principal \"{1}\" has read access.";
    t[1011] = "У файла приватного ключа \"{0}\" небезопасные права: principal \"{1}\" (не владелец) имеет доступ на чтение.";
    t[1016] = "Server SQLState: {0}";
    t[1017] = "SQLState сервера: {0}";
    t[1022] = "Cannot call cancelRowUpdates() when on the insert row.";
    t[1023] = "Нельзя вызывать cancelRowUpdates() на строке вставки.";
    t[1024] = "Invalid channelBinding value: {0}";
    t[1025] = "Неверное значение параметра channelBinding: {0}";
    t[1032] = "The hostname {0} could not be verified by hostnameverifier {1}.";
    t[1033] = "Имя хоста {0} не прошло проверку через hostnameverifier {1}.";
    t[1034] = "{0} function takes two or three arguments.";
    t[1035] = "Функция {0} принимает два или три аргумента.";
    t[1044] = "Unable to determine a value for DefaultTransactionIsolation due to missing  entry in pg_catalog.pg_settings WHERE name='default_transaction_isolation'.";
    t[1045] = "Не удалось определить значение DefaultTransactionIsolation: в pg_catalog.pg_settings нет записи с name='default_transaction_isolation'.";
    t[1056] = "{0} must be a non-negative integer, but was: {1}";
    t[1057] = "Значение {0} должно быть неотрицательным целым числом, получено: {1}";
    t[1058] = "SHOW password_encryption returned null value";
    t[1059] = "SHOW password_encryption вернул значение null";
    t[1060] = "Invalid sslmode value: {0}";
    t[1061] = "Неверное значение параметра sslmode: {0}";
    t[1072] = "Object is too large to send over the protocol.";
    t[1073] = "Объект слишком велик для передачи по протоколу.";
    t[1076] = "Prepare must be issued on the connection that started the branch. Transaction interleaving is not supported. prepare xid={0}, currentXid={1}";
    t[1077] = "Prepare должен выполняться на том соединении, которое начало ветвь. Чередование транзакций не поддерживается. prepare xid={0}, currentXid={1}";
    t[1082] = "Invalid targetServerType value: {0}";
    t[1083] = "Неверное значение параметра targetServerType: {0}";
    t[1086] = "Cannot rollback when autoCommit is enabled.";
    t[1087] = "Нельзя вызывать rollback при включённом autoCommit.";
    t[1088] = "Fastpath call {0} - No result was returned and we expected a long.";
    t[1089] = "Вызов fastpath {0} ничего не вернул, а ожидался long.";
    t[1090] = "The password callback class provided {0} could not be instantiated.";
    t[1091] = "Не удалось создать password callback из указанного класса {0}.";
    t[1092] = "wasNull cannot be call before fetching a result.";
    t[1093] = "Метод wasNull нельзя вызывать до получения результата.";
    t[1094] = "One or more ClientInfo failed.";
    t[1095] = "Не удалось установить одно или несколько свойств ClientInfo.";
    t[1098] = "Network timeout must be a value greater than or equal to 0.";
    t[1099] = "Сетевой таймаут должен быть больше или равен 0.";
    t[1106] = "requireAuth cannot mix positive and negative authentication methods";
    t[1107] = "В свойстве requireAuth нельзя одновременно перечислять разрешённые и запрещённые методы аутентификации";
    t[1110] = "Conversion to type {0} failed: {1}.";
    t[1111] = "Ошибка при преобразовании к типу {0}: {1}.";
    t[1114] = "There are no rows in this ResultSet.";
    t[1115] = "ResultSet не содержит строк.";
    t[1116] = " (pgjdbc: autodetected server-encoding to be {0}, if the message is not readable, please check database logs and/or host, port, dbname, user, password, pg_hba.conf)";
    t[1117] = " (pgjdbc: кодировка сервера определена как {0}; если сообщение нечитаемо, проверьте логи сервера и параметры host, port, dbname, user, password, pg_hba.conf)";
    t[1124] = "Unable to convert bytea parameter at position {0} to literal";
    t[1125] = "Не удалось преобразовать bytea-параметр на позиции {0} в литерал";
    t[1126] = "Unable to instantiate SecBufferDesc, so SSPI is unavailable";
    t[1127] = "Не удалось создать SecBufferDesc, SSPI недоступен";
    t[1130] = "SSL error: {0}";
    t[1131] = "Ошибка SSL: {0}";
    t[1134] = "Protocol error. Cancel Key cannot be greater than 256 for protocol version {0}, but received {1} bytes. Session setup failed.";
    t[1135] = "Ошибка протокола. Для версии протокола {0} Cancel Key не может превышать 256 байт, получено: {1}. Не удалось установить сессию.";
    t[1136] = "Unable to close connection properly";
    t[1137] = "Не удалось корректно закрыть соединение";
    t[1138] = "Error committing prepared transaction. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[1139] = "Ошибка при фиксации подготовленной транзакции. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[1140] = "The server''s client_encoding parameter was changed to {0}. The JDBC driver requires client_encoding to be UTF8 for correct operation.";
    t[1141] = "Параметр сервера client_encoding изменён на {0}. Для корректной работы JDBC-драйвера значение client_encoding должно быть UTF8.";
    t[1144] = "Received CommandComplete ''{0}'' without an active copy operation";
    t[1145] = "Получен CommandComplete ''{0}'' без активной операции COPY";
    t[1146] = "Cannot convert an instance of {0} to type {1}";
    t[1147] = "Невозможно преобразовать объект типа {0} к типу {1}";
    t[1148] = "end() called without a matching start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[1149] = "Вызов end() без соответствующего вызова start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[1150] = "Can''t use query methods that take a query string on a PreparedStatement.";
    t[1151] = "У PreparedStatement нельзя вызывать методы, принимающие SQL-строку.";
    t[1152] = "ResultSets with concurrency CONCUR_READ_ONLY cannot be updated.";
    t[1153] = "ResultSet с уровнем concurrency CONCUR_READ_ONLY не обновляется.";
    t[1154] = "COPY commands are only supported using the CopyManager API.";
    t[1155] = "Команды COPY поддерживаются только через API CopyManager.";
    t[1158] = "One-phase commit with unknown xid. commit xid={0}, currentXid={1}";
    t[1159] = "Однофазная фиксация с неизвестным xid. commit xid={0}, currentXid={1}";
    t[1170] = "Connection has been closed.";
    t[1171] = "Соединение закрыто.";
    t[1172] = "The server requested SCRAM-based authentication, but no password was provided.";
    t[1173] = "Сервер запросил аутентификацию SCRAM, но пароль не указан.";
    t[1176] = "CopyIn copy direction can't receive data";
    t[1177] = "Операция CopyIn не может получать данные";
    t[1178] = "Channel Binding is required, but could not extract channel binding data from SSL session";
    t[1179] = "Требуется channel binding, но не удалось извлечь данные channel binding из SSL-сессии";
    t[1180] = "A CallableStatement was executed with nothing returned.";
    t[1181] = "CallableStatement выполнен, но ничего не вернул.";
    t[1190] = "Results cannot be retrieved from a CallableStatement before it is executed.";
    t[1191] = "Нельзя получить результаты CallableStatement до его выполнения.";
    t[1192] = "Loading the SSL root certificate {0} into a TrustManager failed.";
    t[1193] = "Не удалось загрузить корневой SSL-сертификат {0} в TrustManager.";
    t[1200] = "Error rolling back transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[1201] = "Ошибка при откате транзакции. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[1206] = "Failed to set ClientInfo property: {0}";
    t[1207] = "Не удалось установить свойство ClientInfo: {0}.";
    t[1208] = "Neither Subject.doAs (Java before 18) nor Subject.callAs (Java 18+) method found";
    t[1209] = "Не найдено ни метода Subject.doAs (Java до 18), ни Subject.callAs (Java 18+)";
    t[1214] = "Value is not an OID: {0}";
    t[1215] = "Значение не является OID: {0}";
    t[1216] = "Bad value for type {0} : {1}";
    t[1217] = "Некорректное значение для типа {0}: {1}";
    t[1218] = "Provided Reader failed.";
    t[1219] = "Чтение из переданного Reader завершилось ошибкой.";
    t[1222] = "Unable to find pkcs12 keystore.";
    t[1223] = "Не найден pkcs12-keystore.";
    t[1228] = "Returning autogenerated keys is not supported.";
    t[1229] = "Возврат автогенерируемых ключей не поддерживается.";
    t[1236] = "Cannot 2nd phase commit prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. commit xid={0}, transactionState={1}";
    t[1237] = "Невозможно выполнить вторую фазу фиксации подготовленной транзакции, пока на соединении выполняется локальная транзакция. Сначала зафиксируйте или откатите локальную транзакцию. commit xid={0}, transactionState={1}";
    t[1238] = "Error releasing savepoint";
    t[1239] = "Ошибка при освобождении точки сохранения";
    t[1240] = "Unsupported Types value: {0}";
    t[1241] = "Неподдерживаемая константа java.sql.Types: {0}";
    t[1242] = "The environment variable containing the server's SSL certificate must not be empty.";
    t[1243] = "Переменная окружения с SSL-сертификатом сервера не должна быть пустой.";
    t[1244] = "Unknown value for ResultSet holdability";
    t[1245] = "Неизвестное значение holdability для ResultSet";
    t[1246] = "Tried to obtain lock while already holding it";
    t[1247] = "Попытка захватить блокировку, которая уже удерживается";
    t[1250] = "Fastpath call {0} - No result was returned and we expected an integer.";
    t[1251] = "Вызов fastpath {0} ничего не вернул, а ожидался integer.";
    t[1254] = "Cannot retrieve the id of a named savepoint.";
    t[1255] = "Нельзя получить идентификатор именованной точки сохранения.";
    t[1256] = "Cannot commit when autoCommit is enabled.";
    t[1257] = "Нельзя вызывать commit при включённом autoCommit.";
    t[1260] = "Could not read SSL root certificate file {0}.";
    t[1261] = "Не удалось прочитать файл корневого SSL-сертификата {0}.";
    t[1270] = "Unsupported type conversion to {0}.";
    t[1271] = "Преобразование к типу {0} не поддерживается.";
    t[1272] = "Unable to translate data into the desired encoding.";
    t[1273] = "Не удалось преобразовать данные к нужной кодировке.";
    t[1274] = "Database cannot be null";
    t[1275] = "Параметр database не должен быть null";
    t[1276] = "PGStream is closed";
    t[1277] = "PGStream закрыт.";
    t[1282] = "An error occurred reading the certificate";
    t[1283] = "Ошибка при чтении сертификата";
    t[1286] = "Fastpath call {0} - No result was returned or wrong size while expecting an integer.";
    t[1287] = "Вызов fastpath {0} ничего не вернул либо вернул значение неверного размера; ожидался integer.";
    t[1290] = "Unsupported property name: {0}";
    t[1291] = "Свойство {0} не поддерживается.";
    t[1296] = "Received AuthenticationSASL message with 0 mechanisms!";
    t[1297] = "Получено сообщение AuthenticationSASL без перечня механизмов";
    t[1298] = "This replication stream has been closed.";
    t[1299] = "Поток репликации закрыт.";
    t[1300] = "Bad value for type timestamp/date/time: {0}";
    t[1301] = "Некорректное значение типа timestamp/date/time: {0}";
    t[1302] = "Invalid flags {0}";
    t[1303] = "Неверные флаги {0}";
    t[1306] = "Loading the SSL certificate {0} into a KeyManager failed.";
    t[1307] = "Не удалось загрузить SSL-сертификат {0} в KeyManager.";
    t[1308] = "commit() called before end(). commit xid={0}, state={1}";
    t[1309] = "commit() вызван до end(). commit xid={0}, state={1}";
    t[1310] = "Server does not support temporary replication slots";
    t[1311] = "Сервер не поддерживает временные слоты репликации";
    t[1312] = "GSS Authentication failed";
    t[1313] = "Аутентификация GSS не удалась";
    t[1316] = "Expected an EOF from server, got: {0}";
    t[1317] = "Неожиданный ответ от сервера. Ожидалось окончание потока, получен байт {0}.";
    t[1322] = "Could not open SSL certificate file {0}.";
    t[1323] = "Не удалось открыть файл SSL-сертификата {0}.";
    t[1324] = "{0} function takes three and only three arguments.";
    t[1325] = "Функция {0} принимает ровно три аргумента.";
    t[1328] = "Cannot write to copy a byte of value {0}";
    t[1329] = "Значение байта должно быть в диапазоне 0..255, передано: {0}";
    t[1330] = "An I/O error occurred while sending to the backend.";
    t[1331] = "Ошибка ввода/вывода при отправке бэкенду.";
    t[1334] = "Cannot rollback prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. rollback xid={0}, transactionState={1}";
    t[1335] = "Невозможно откатить подготовленную транзакцию, пока на соединении выполняется локальная транзакция. Сначала зафиксируйте или откатите локальную транзакцию. rollback xid={0}, transactionState={1}";
    t[1338] = "Multiple ResultSets were returned by the query.";
    t[1339] = "Запрос вернул несколько ResultSet.";
    t[1342] = "Cannot change transaction isolation level in the middle of a transaction.";
    t[1343] = "Нельзя изменить уровень изоляции в середине транзакции.";
    t[1352] = "Unable to load Authentication Plugin {0}";
    t[1353] = "Не удалось загрузить плагин аутентификации {0}";
    t[1354] = "The SocketFactory class provided {0} could not be instantiated.";
    t[1355] = "Не удалось создать SocketFactory из указанного класса {0}.";
    t[1356] = "2nd phase commit cannot be issued while an XA branch is active on this connection. commit xid={0}, currentXid={1}, state={2}";
    t[1357] = "Вторую фазу фиксации нельзя выполнить, пока на соединении активна XA-ветвь. commit xid={0}, currentXid={1}, state={2}";
    t[1358] = "Unable to create SAXResult for SQLXML.";
    t[1359] = "Не удалось создать SAXResult для SQLXML.";
    t[1360] = "Not on the insert row.";
    t[1361] = "Курсор не на строке вставки.";
    t[1362] = "Can not flush large object {0}";
    t[1363] = "Не удалось сбросить буфер большого объекта {0}";
    t[1368] = "This ResultSet is closed.";
    t[1369] = "ResultSet закрыт.";
    t[1370] = "An error occurred while setting up the GSS Encoded connection.";
    t[1371] = "Ошибка при установке GSS-соединения.";
    t[1374] = "PreparedStatement can have at most {0} parameters. Please consider using arrays, or splitting the query in several ones, or using COPY. Given query has {1} parameters";
    t[1375] = "PreparedStatement поддерживает не более {0} параметров. Используйте массивы, разбейте запрос на несколько или воспользуйтесь COPY. В переданном запросе параметров: {1}";
    t[1376] = "Database connection failed when ending copy";
    t[1377] = "Сбой соединения с БД при завершении COPY";
    t[1378] = "Can''t use executeWithFlags(int) on a Statement.";
    t[1379] = "У Statement нельзя вызывать executeWithFlags(int).";
    t[1380] = "ResultSet is not updateable.  The query that generated this result set must select only one table, and must select all primary keys from that table. See the JDBC 2.1 API Specification, section 5.6 for more details.";
    t[1381] = "ResultSet не обновляемый.  Запрос должен выбирать только из одной таблицы и включать все её первичные ключи. См. JDBC 2.1 API Specification, раздел 5.6.";
    t[1386] = "{0} parameter value must be an integer but was: {1}";
    t[1387] = "Значение параметра {0} должно быть целым числом, получено: {1}";
    t[1392] = "Cannot establish a savepoint in auto-commit mode.";
    t[1393] = "Нельзя создать точку сохранения в режиме autoCommit.";
    t[1396] = "Unable to find server array type for provided name {0}.";
    t[1397] = "Не найден тип массива на сервере по имени {0}.";
    t[1400] = "StreamWrapper leak detected StreamWrapper.close() was not called. ";
    t[1401] = "Обнаружена утечка StreamWrapper: метод StreamWrapper.close() не был вызван. ";
    t[1402] = "Tried to write to an inactive copy operation";
    t[1403] = "Попытка записи в неактивную операцию COPY";
    t[1404] = "Custom type maps are not supported.";
    t[1405] = "Пользовательские type maps не поддерживаются.";
    t[1406] = "Bind message length {0} too long.  This can be caused by very large or incorrect length specifications on InputStream parameters.";
    t[1407] = "Длина сообщения Bind {0} слишком велика.  Причиной может быть слишком большое или некорректное значение длины у параметров типа InputStream.";
    t[1412] = "Position: {0}";
    t[1413] = "Позиция: {0}";
    t[1414] = "Currently positioned after the end of the ResultSet.  You cannot call deleteRow() here.";
    t[1415] = "Позиция находится за концом ResultSet.  Здесь нельзя вызывать deleteRow().";
    t[1422] = "xid must not be null";
    t[1423] = "Аргумент xid не должен быть null";
    t[1426] = "Server name validation failed: hostname {0} does not match common name {1}";
    t[1427] = "Проверка имени сервера не прошла: имя хоста {0} не совпадает с common name {1}";
    t[1428] = "No IOException expected from StringBuffer or StringBuilder";
    t[1429] = "IOException от StringBuffer или StringBuilder не ожидается.";
    t[1430] = "An error occurred while trying to reset the socket timeout.";
    t[1431] = "Ошибка при попытке сбросить таймаут сокета.";
    t[1436] = "Unable to parse X509Certificate for hostname {0}";
    t[1437] = "Не удалось разобрать X509Certificate для хоста {0}";
    t[1438] = "Got CopyOutResponse from server during an active {0}";
    t[1439] = "Получен CopyOutResponse от сервера во время активной операции {0}";
    t[1440] = "A CallableStatement function was executed and the out parameter {0} was of type {1} however type {2} was registered.";
    t[1441] = "При вызове функции CallableStatement выходной параметр {0} имеет тип {1}, однако зарегистрирован тип {2}.";
    t[1442] = "Got {0} error responses to single copy cancel request";
    t[1443] = "На один запрос отмены COPY получено ответов с ошибкой: {0}";
    t[1460] = "Your security policy has prevented the connection from being attempted.  You probably need to grant the connect java.net.SocketPermission to the database server host and port that you wish to connect to.";
    t[1461] = "Политика безопасности заблокировала попытку соединения.  Выдайте java.net.SocketPermission с действием connect для хоста и порта целевой БД.";
    t[1462] = "Properties for the driver contains a non-string value for the key {0}";
    t[1463] = "Свойства драйвера содержат нестроковое значение для ключа {0}";
    t[1472] = "Leak detected: Connection.close() was not called";
    t[1473] = "Обнаружена утечка: метод Connection.close() не был вызван";
    t[1476] = "Cannot reference a savepoint after it has been released.";
    t[1477] = "Нельзя обращаться к точке сохранения после её освобождения.";
    t[1486] = "Unknown XML Result class: {0}";
    t[1487] = "Неизвестный класс XML Result: {0}";
    t[1490] = "Unable to determine a value for MaxIndexKeys due to missing system catalog data.";
    t[1491] = "Не удалось определить значение MaxIndexKeys: нет данных в системном каталоге.";
    table = t;
  }
  public java.lang.Object handleGetObject (java.lang.String msgid) throws java.util.MissingResourceException {
    int hash_val = msgid.hashCode() & 0x7fffffff;
    int idx = (hash_val % 751) << 1;
    {
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
    int incr = ((hash_val % 749) + 1) << 1;
    for (;;) {
      idx += incr;
      if (idx >= 1502)
        idx -= 1502;
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
  }
  public java.util.Enumeration getKeys () {
    return
      new java.util.Enumeration() {
        private int idx = 0;
        { while (idx < 1502 && table[idx] == null) idx += 2; }
        public boolean hasMoreElements () {
          return (idx < 1502);
        }
        public java.lang.Object nextElement () {
          java.lang.Object key = table[idx];
          do idx += 2; while (idx < 1502 && table[idx] == null);
          return key;
        }
      };
  }
  public java.util.ResourceBundle getParent () {
    return parent;
  }
}
