/* Automatically generated by GNU msgfmt.  Do not modify!  */
package org.postgresql.translation;
public class messages_zh_CN extends java.util.ResourceBundle {
  private static final java.lang.String[] table;
  static {
    java.lang.String[] t = new java.lang.String[1354];
    t[0] = "";
    t[1] = "Project-Id-Version: PostgreSQL JDBC Driver 8.3\nReport-Msgid-Bugs-To: \nPO-Revision-Date: 2008-01-31 14:34+0800\nLast-Translator: 郭朝益(ChaoYi, Kuo) <Kuo.ChaoYi@gmail.com>\nLanguage-Team: The PostgreSQL Development Team <Kuo.ChaoYi@gmail.com>\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Chinese\nX-Poedit-Country: CHINA\nX-Poedit-SourceCharset: utf-8\n";
    t[2] = "The environment variable containing the server's SSL certificate must not be empty.";
    t[3] = "指定服务端SSL证书的环境变量不能为空。";
    t[8] = "A CallableStatement was declared, but no call to registerOutParameter(1, <some type>) was made.";
    t[9] = "已经宣告 CallableStatement 函式，但是尚未呼叫 registerOutParameter (1, <some_type>) 。";
    t[10] = "Cannot reference a savepoint after it has been released.";
    t[11] = "无法参照已经被释放的储存点。";
    t[12] = "2nd phase commit cannot be issued while an XA branch is active on this connection. commit xid={0}, currentXid={1}, state={2}";
    t[13] = "在此连接上有 XA 分支处于活动状态时，无法发起二阶段提交。commit xid={0}, currentXid={1}, state={2}";
    t[14] = "Invalid flags {0}";
    t[15] = "无效的旗标 flags {0}";
    t[36] = "Bind message length {0} too long.  This can be caused by very large or incorrect length specifications on InputStream parameters.";
    t[37] = "绑定消息的长度({0})过长。这可能是由于InputStream的参数定义过大或定义不正确导致";
    t[38] = "Unable to create StAXResult for SQLXML";
    t[39] = "无法为SQLXML创建StAXResult";
    t[40] = "Could not read password for SSL key file, console is not available.";
    t[41] = "控制台不可用，无法为SSL密钥文件读取密码。";
    t[64] = "Prepare called before end(). prepare xid={0}, state={1}";
    t[65] = "在 end() 之前调用了 Prepare。prepare xid={0}, state={1}";
    t[66] = " (pgjdbc: autodetected server-encoding to be {0}, if the message is not readable, please check database logs and/or host, port, dbname, user, password, pg_hba.conf)";
    t[67] = "(pgjdbc: 自动检出服务端编码为{0}，如果消息不可读，请确认数据库日志或host, port, dbname, user, password, pg_hba.conf)";
    t[68] = "Cannot rollback when autoCommit is enabled.";
    t[69] = "无法在autoCommit有效时显式的回滚事务。";
    t[74] = "GSS Authentication failed";
    t[75] = "GSS认证失败";
    t[76] = "Got CopyInResponse from server during an active {0}";
    t[77] = "在{0}活动期间从服务端接收到CopyInResponse";
    t[80] = "Got CopyData without an active copy operation";
    t[81] = "在没有活动拷贝流的情况下收到了CopyData";
    t[82] = "Error rolling back transaction. rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[83] = "回滚事务时出错。rollback xid={0}, preparedXid={1}, currentXid={2}";
    t[84] = "Heuristic commit/rollback not supported. forget xid={0}";
    t[85] = "不支持启发式提交/回滚. forget xid={0}";
    t[86] = "Cannot cast an instance of {0} to type {1}";
    t[87] = "不能转换一个 {0} 实例到类型 {1}";
    t[88] = "Cannot tell if path is open or closed: {0}.";
    t[89] = "无法得知 path 是开启或关闭：{0}。";
    t[96] = "{0} function doesn''t take any argument.";
    t[97] = "{0} 函式无法取得任何的引数。";
    t[98] = "Zero bytes may not occur in string parameters.";
    t[99] = "字符参数不能有 0 个位元组。";
    t[100] = "Unable to convert DOMResult SQLXML data to a string.";
    t[101] = "无法将DOMResult的SQLXML数据转换为字符串。";
    t[110] = "Internal Position: {0}";
    t[111] = "内部位置：{0}";
    t[114] = "Error opening transaction. start xid={0}";
    t[115] = "开启事务时出错。start xid={0}";
    t[116] = "Internal Query: {0}";
    t[117] = "内部查询：{0}";
    t[118] = "Can''t refresh the insert row.";
    t[119] = "无法重读新增的数据列。";
    t[120] = "A connection could not be made using the requested protocol {0}.";
    t[121] = "无法以要求的通讯协定 {0} 建立连线。";
    t[126] = "Requested CopyIn but got {0}";
    t[127] = "向服务端请求的是CopyIn，但实际响应的是: {0}";
    t[130] = "Returning autogenerated keys is not supported.";
    t[131] = "不支持返回自动生成的键";
    t[132] = "One or more ClientInfo failed.";
    t[133] = "一个或一个以上的ClientInfo发生错误。";
    t[134] = "Unable to set network timeout.";
    t[135] = "无法设置网络超时时间。";
    t[142] = "Protocol error.  Session setup failed.";
    t[143] = "通讯协定错误，Session 初始化失败。";
    t[146] = "Cannot retrieve the id of a named savepoint.";
    t[147] = "无法取得已命名储存点的 id。";
    t[148] = "The fastpath function {0} is unknown.";
    t[149] = "不明的 fastpath 函式 {0}。";
    t[152] = "oid type {0} not known and not a number";
    t[153] = "未知且不是数值的oid类型: {0}";
    t[154] = "The SocketFactory class provided {0} could not be instantiated.";
    t[155] = "提供的SocketFactory类<<{0}>>无法被实例化。";
    t[158] = "Read from copy failed.";
    t[159] = "从拷贝流中读取数据失败。";
    t[160] = "The server''s standard_conforming_strings parameter was reported as {0}. The JDBC driver expected on or off.";
    t[161] = "这服务器的 standard_conforming_strings 参数已回报为 {0}，JDBC 驱动程序已预期开启或是关闭。";
    t[162] = "Unknown ResultSet holdability setting: {0}.";
    t[163] = "未知的 ResultSet 可适用的设置：{0}。";
    t[168] = "Cannot write to copy a byte of value {0}";
    t[169] = "无法向拷贝流中写入字节值{0}";
    t[176] = "Unsupported value for stringtype parameter: {0}";
    t[177] = "字符类型参数值未被支持：{0}";
    t[180] = "Conversion of interval failed";
    t[181] = "隔绝(Interval)转换失败。";
    t[184] = "The column name {0} was not found in this ResultSet.";
    t[185] = "ResultSet 中找不到栏位名称 {0}。";
    t[192] = "Could not initialize SSL context.";
    t[193] = "无法初始化SSL上下文。";
    t[196] = "A CallableStatement function was executed and the out parameter {0} was of type {1} however type {2} was registered.";
    t[197] = "一个 CallableStatement 执行函式后输出的参数类型为 {1} 值为 {0}，但是已注册的类型是 {2}。";
    t[202] = "Cannot call cancelRowUpdates() when on the insert row.";
    t[203] = "不能在新增的数据列上呼叫 cancelRowUpdates()。";
    t[210] = "Loading the SSL certificate {0} into a KeyManager failed.";
    t[211] = "无法将SSL证书{0}加载到KeyManager。";
    t[212] = "Got CopyBothResponse from server during an active {0}";
    t[213] = "在{0}活动期间从服务端接收到CopyBothResponse";
    t[216] = "Interrupted while attempting to connect.";
    t[217] = "连接尝试被中断。";
    t[218] = "Connection attempt timed out.";
    t[219] = "Connection 尝试逾时。";
    t[224] = "Premature end of input stream, expected {0} bytes, but only read {1}.";
    t[225] = "输入流过早结束，期待读取{0}个字节，但实际只读取到{1}个字节。";
    t[234] = "This PooledConnection has already been closed.";
    t[235] = "这个 PooledConnection 已经被关闭。";
    t[238] = "Cannot retrieve the name of an unnamed savepoint.";
    t[239] = "无法取得未命名储存点(Savepoint)的名称。";
    t[246] = "Failed to convert binary xml data to encoding: {0}.";
    t[247] = "无法将二进制xml编码数据转换为: {0}";
    t[250] = "A CallableStatement was executed with nothing returned.";
    t[251] = "一个 CallableStatement 执行函式后没有传回值。";
    t[262] = "Operation requires a scrollable ResultSet, but this ResultSet is FORWARD_ONLY.";
    t[263] = "操作要求可卷动的 ResultSet，但此 ResultSet 是 FORWARD_ONLY。";
    t[266] = "xid must not be null";
    t[267] = "xid不能为空";
    t[270] = "Tried to read from inactive copy";
    t[271] = "尝试从非活动的拷贝流中读取数据";
    t[272] = "Transaction control methods setAutoCommit, commit, rollback and setSavepoint are not allowed while an XA transaction is active.";
    t[273] = "在 XA 事务处于活动状态时，不允许调用 setAutoCommit、commit、rollback 和 setSavepoint 等事务控制方法。";
    t[278] = "Cannot cast to boolean: \"{0}\"";
    t[279] = "无法强制转换为boolean: \"{0}\"";
    t[286] = "No function outputs were registered.";
    t[287] = "未注册函数的输出参数类型。";
    t[290] = "{0} function takes two or three arguments.";
    t[291] = "{0} 函式取得二个或三个引数。";
    t[298] = "Current connection does not have an associated xid. prepare xid={0}";
    t[299] = "当前连接没有关联的 xid。prepare xid={0}";
    t[302] = "Failed to create object for: {0}.";
    t[303] = "为 {0} 建立对象失败。";
    t[304] = "Unknown Response Type {0}.";
    t[305] = "不明的回应类型 {0}。";
    t[316] = "Multiple ResultSets were returned by the query.";
    t[317] = "查询传回多个 ResultSet。";
    t[318] = "Truncation of large objects is only implemented in 8.3 and later servers.";
    t[319] = "大型对象的截断(Truncation)仅被实作执行在 8.3 和后来的服务器。";
    t[320] = "Tried to break lock on database connection";
    t[321] = "尝试在数据库连接上强制释放锁";
    t[324] = "hstore key must not be null";
    t[325] = "hstore的键不能为null";
    t[330] = "There are no rows in this ResultSet.";
    t[331] = "ResultSet 中找不到数据列。";
    t[334] = "Server name validation failed: unable to extract common name from X509Certificate for hostname {0}";
    t[335] = "服务器名验证失败: 无法从X509证书中提取主机名{0}的通用名。";
    t[336] = "Prepare must be issued on the connection that started the branch. Transaction interleaving is not supported. prepare xid={0}, currentXid={1}";
    t[337] = "Prepare 必须在启动该分支的连接上发起。不支持事务交错（transaction interleaving）。prepare xid={0}, currentXid={1}";
    t[338] = "The column index is out of range: {0}, number of columns: {1}.";
    t[339] = "栏位索引超过许可范围：{0}，栏位数：{1}。";
    t[340] = "Cannot call updateRow() when on the insert row.";
    t[341] = "不能在新增的数据列上呼叫 deleteRow()。";
    t[348] = "Unexpected copydata from server for {0}";
    t[349] = "从服务端接收到用于{0}的预期之外的CopyData";
    t[350] = "Requested CopyDual but got {0}";
    t[351] = "向服务端请求的是CopyDual，但实际响应的是: {0}";
    t[356] = "{0} function takes two and only two arguments.";
    t[357] = "{0} 函式取得二个且仅有二个引数。";
    t[370] = "Could not open SSL root certificate file {0}.";
    t[371] = "无法打开SSL根证书文件: {0}";
    t[376] = "Bad value for type {0} : {1}";
    t[377] = "不良的类型值 {0} : {1}";
    t[380] = "Cannot call deleteRow() when on the insert row.";
    t[381] = "不能在新增的数据上呼叫 deleteRow()。";
    t[384] = "Results cannot be retrieved from a CallableStatement before it is executed.";
    t[385] = "在CallableStatement执行之前无法获取结果";
    t[386] = "end() called without a matching start(). end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[387] = "调用 end() 时未匹配到对应的 start()。end xid={0}, currentXid={1}, state={2}, preparedXid={3}";
    t[390] = "Unexpected error writing large object to database.";
    t[391] = "将大型对象(large object)写入数据库时发生不明错误。";
    t[392] = "Could not read SSL key file {0}.";
    t[393] = "无法读取SSL密钥文件: {0}";
    t[394] = "Cannot change transaction read-only property in the middle of a transaction.";
    t[395] = "不能在事物交易过程中改变事物交易唯读属性。";
    t[398] = "Cannot commit when autoCommit is enabled.";
    t[399] = "无法在autoCommit有效时显式的提交事务。";
    t[408] = "No results were returned by the query.";
    t[409] = "查询没有传回任何结果。";
    t[432] = "Unknown Types value.";
    t[433] = "不明的类型值。";
    t[446] = "Copying from database failed: {0}";
    t[447] = "从数据库中拷贝失败: {0}";
    t[458] = "Missing expected error response to copy cancel request";
    t[459] = "缺少拷贝取消请求所对应的来自服务端的错误响应";
    t[460] = "Enter SSL password: ";
    t[461] = "请输入SSL密码: ";
    t[462] = "Can''t use query methods that take a query string on a PreparedStatement.";
    t[463] = "在 PreparedStatement 上不能使用获取查询字符的查询方法。";
    t[472] = "Could not find a server with specified targetServerType: {0}";
    t[473] = "无法通过targetServerType找到指定的服务器: {0}";
    t[476] = "Could not open SSL certificate file {0}.";
    t[477] = "无法打开SSL证书文件 {0}。";
    t[482] = "Location: File: {0}, Routine: {1}, Line: {2}";
    t[483] = "位置：文件：{0}，常式：{1}，行：{2}";
    t[484] = "Currently positioned before the start of the ResultSet.  You cannot call deleteRow() here.";
    t[485] = "不能在 ResultSet 的第一笔数据之前呼叫 deleteRow()。";
    t[496] = "Provided Reader failed.";
    t[497] = "提供的 Reader 已失败。";
    t[510] = "Got CopyOutResponse from server during an active {0}";
    t[511] = "在{0}活动期间从服务端接收到CopyOutResponse";
    t[518] = "Unable to find server array type for provided name {0}.";
    t[519] = "找不到{0}对应的的数据库数组类型。";
    t[522] = "COPY commands are only supported using the CopyManager API.";
    t[523] = "COPY命令只支持在CopyManager接口上使用。";
    t[526] = "Server SQLState: {0}";
    t[527] = "服务器 SQLState：{0}";
    t[528] = "No X509TrustManager found";
    t[529] = "找不到X509TrustManager";
    t[542] = "The server''s DateStyle parameter was changed to {0}. The JDBC driver requires DateStyle to begin with ISO for correct operation.";
    t[543] = "这服务器的 DateStyle 参数被更改成 {0}，JDBC 驱动程序请求需要 DateStyle 以 ISO 开头以正确工作。";
    t[548] = "Unable to parse certificates for hostname {0}";
    t[549] = "无法解析主机名{0}的证书";
    t[552] = "Requested CopyOut but got {0}";
    t[553] = "向服务端请求的是CopyOut，但实际响应的是: {0}";
    t[560] = "commit() called before end(). commit xid={0}, state={1}";
    t[561] = "在 end() 之前调用了 commit()。commit xid={0}, state={1}";
    t[562] = "Tried to end inactive copy";
    t[563] = "尝试结束非活动中的拷贝流";
    t[564] = "Server does not support temporary replication slots";
    t[565] = "服务端不支持临时的流复制槽";
    t[570] = "The password callback class provided {0} could not be instantiated.";
    t[571] = "无法实例化提供的密码回调类: {0}";
    t[582] = "Transaction was already prepared on this connection. prepare xid={0}, preparedXid={1}";
    t[583] = "此连接上的事务已被预备。prepare xid={0}, preparedXid={1}";
    t[588] = "Unexpected command status: {0}.";
    t[589] = "预期之外的CommandStatus: {0}。";
    t[590] = "Failed to setup DataSource.";
    t[591] = "DataSource配置失败。";
    t[594] = "Where: {0}";
    t[595] = "在位置：{0}";
    t[598] = "Fastpath call {0} - No result was returned and we expected an integer.";
    t[599] = "Fastpath 呼叫 {0} - 没有传回值，且应该传回一个整数。";
    t[602] = "Unable to decode xml data.";
    t[603] = "无法解码xml数据。";
    t[632] = "Database connection failed when starting copy";
    t[633] = "在开始拷贝操作时数据库连接发生错误";
    t[634] = "Could not close SSL certificate file {0}.";
    t[635] = "无法关闭SSL证书文件 {0}。";
    t[640] = "Cannot 2nd phase commit prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. commit xid={0}, transactionState={1}";
    t[641] = "在此连接上有本地事务正在进行时，无法对已预备的事务执行二阶段提交。请先提交或回滚该本地事务。commit xid={0}, transactionState={1}";
    t[646] = "PostgreSQL LOBs can only index to: {0}";
    t[647] = "PostgreSQL LOBs 仅能索引到：{0}";
    t[648] = "{0} function takes one and only one argument.";
    t[649] = "{0} 函式取得一个且仅有一个引数。";
    t[652] = "A result was returned when none was expected.";
    t[653] = "传回预期之外的结果。";
    t[654] = "Unable to get network timeout.";
    t[655] = "无法获取网络超时时间。";
    t[658] = "Can''t infer the SQL type to use for an instance of {0}. Use setObject() with an explicit Types value to specify the type to use.";
    t[659] = "无法推测实例{0}的SQL类型。使用setObject()时请明确指定要使用的类型。";
    t[660] = "Cannot change transaction isolation level in the middle of a transaction.";
    t[661] = "不能在事务交易过程中改变事物交易隔绝等级。";
    t[676] = "ClientInfo property not supported.";
    t[677] = "不支持ClientInfo属性。";
    t[678] = "Could not read password for SSL key file by callbackhandler {0}.";
    t[679] = "无法通过callbackhandler {0}为SSL密钥文件读取密码。";
    t[688] = "Something unusual has occurred to cause the driver to fail. Please report this exception.";
    t[689] = "不明的原因导致驱动程序造成失败，请回报这个例外。";
    t[696] = "Unexpected packet type during copy: {0}";
    t[697] = "拷贝时收到预期之外的数据包类型: {0}";
    t[698] = "Could not decrypt SSL key file {0}.";
    t[699] = "无法解密SSL密钥文件: {0}";
    t[704] = "No IOException expected from StringBuffer or StringBuilder";
    t[705] = "不应当有任何IOException从StringBuffer或StringBuilder中抛出";
    t[706] = "The sslfactoryarg property must start with the prefix file:, classpath:, env:, sys:, or -----BEGIN CERTIFICATE-----.";
    t[707] = "sslfactoryarg参数必须以file:, classpath:, env:, sys:,或-----BEGIN CERTIFICATE-----作为前缀。";
    t[708] = "Object is too large to send over the protocol.";
    t[709] = "发送对象过大，无法通过协议发送。";
    t[710] = "Connection has been closed.";
    t[711] = "Connection 已经被关闭。";
    t[712] = "Transaction isolation level {0} not supported.";
    t[713] = "不支援交易隔绝等级 {0} 。";
    t[722] = "Returning autogenerated keys by column index is not supported.";
    t[723] = "不支持按列索引返回自动生成的键。";
    t[724] = "Unable to determine a value for MaxIndexKeys due to missing system catalog data.";
    t[725] = "无法在缺少系统目录数据的情况下确定MaxIndexKeys的值";
    t[726] = "Tried to obtain lock while already holding it";
    t[727] = "尝试获取已经持有的锁";
    t[732] = "Can''t use relative move methods while on the insert row.";
    t[733] = "不能在新增的数据列上使用相对位置 move 方法。";
    t[738] = "LOB positioning offsets start at 1.";
    t[739] = "LOB的位置偏移从1开始。";
    t[742] = "CopyIn copy direction can't receive data";
    t[743] = "无法使用CopyIn接收数据";
    t[754] = "Error preparing transaction. prepare xid={0}";
    t[755] = "事务准备错误。准备事务的xid={0}";
    t[758] = "free() was called on this LOB previously";
    t[759] = "free()在LOB上已经被调用过";
    t[760] = "Tried to write to an inactive copy operation";
    t[761] = "尝试写入数据到一个非活动的拷贝流";
    t[762] = "The SSLSocketFactory class provided {0} could not be instantiated.";
    t[763] = "提供的SSLSocketFactory类<<{0}>>无法被实例化。";
    t[780] = "Invalid stream length {0}.";
    t[781] = "无效的串流长度 {0}.";
    t[786] = "Cannot update the ResultSet because it is either before the start or after the end of the results.";
    t[787] = "无法更新 ResultSet，可能在第一笔数据之前或最未笔数据之后。";
    t[794] = "Result set exceeded maxResultBuffer limit. Received:  {0}; Current limit: {1}";
    t[795] = "结果集超出了maxResultBuffer的限制。接收到: {0}; 当前限制: {1}";
    t[800] = "Unexpected packet type during replication: {0}";
    t[801] = "流复制过程中出现期待外的包类型: {0}";
    t[812] = "Database connection failed when writing to copy";
    t[813] = "在写入数据到拷贝流时数据库连接发生错误";
    t[814] = "Validating connection.";
    t[815] = "正在验证连接中。";
    t[818] = "Error loading default settings from driverconfig.properties";
    t[819] = "读取driverconfig.properties中的默认设置时发生错误";
    t[828] = "Query timeout must be a value greater than or equals to 0.";
    t[829] = "查询逾时等候时间必须大于或等于 0。";
    t[832] = "The maximum field size must be a value greater than or equal to 0.";
    t[833] = "最大栏位容量必须大于或等于 0。";
    t[842] = "You must specify at least one column value to insert a row.";
    t[843] = "必须为行插入操作指定至少一列数据。";
    t[844] = "The array index is out of range: {0}";
    t[845] = "阵列索引超过许可范围：{0}";
    t[846] = "DataSource has been closed.";
    t[847] = "DataSource 已经被关闭。";
    t[850] = "Hostname {0} is invalid";
    t[851] = "主机名{0}不可用";
    t[854] = "Conversion to type {0} failed: {1}.";
    t[855] = "转换类型 {0} 失败：{1}。";
    t[856] = "Connection has been closed automatically because a new connection was opened for the same PooledConnection or the PooledConnection has been closed.";
    t[857] = "Connection 已自动结束，因为一个新的  PooledConnection 连线被开启或者或 PooledConnection 已被关闭。";
    t[862] = "Invalid fetch direction constant: {0}.";
    t[863] = "无效的 fetch 方向常数：{0}。";
    t[878] = "The JVM claims not to support the {0} encoding.";
    t[879] = "JVM 声明并不支援 {0} 编码。";
    t[880] = "The array index is out of range: {0}, number of elements: {1}.";
    t[881] = "阵列索引超过许可范围：{0}，元素数量：{1}。";
    t[886] = "Got {0} error responses to single copy cancel request";
    t[887] = "单个拷贝取消请求收到了{0}个来自服务端的错误响应";
    t[892] = "Hint: {0}";
    t[893] = "建议：{0}";
    t[900] = "No hstore extension installed.";
    t[901] = "hstore扩展尚未安装。";
    t[906] = "Could not find a java cryptographic algorithm: {0}.";
    t[907] = "找不到java加密算法: {0}";
    t[908] = "Can''t use executeWithFlags(int) on a Statement.";
    t[909] = "无法在Statement对象上使用executeWithFlags(int)函数";
    t[912] = "Zero bytes may not occur in identifiers.";
    t[913] = "在标识识别符中不存在零位元组。";
    t[914] = "Expected command status BEGIN, got {0}.";
    t[915] = "期待的CommandStatus是BEGIN，实际却是 {0}。";
    t[918] = "This SQLXML object has already been initialized, so you cannot manipulate it further.";
    t[919] = "该SQLXML对象已经被初始化，无法再次执行初始化操作。";
    t[920] = "Parameter of type {0} was registered, but call to get{1} (sqltype={2}) was made.";
    t[921] = "已注册参数类型 {0}，但是又呼叫了get{1}(sqltype={2})。";
    t[924] = "Database connection failed when ending copy";
    t[925] = "在结束拷贝时数据库连接发生错误";
    t[926] = "Received CommandComplete ''{0}'' without an active copy operation";
    t[927] = "在没有活动中的拷贝流的情况下收到了CommandComplete消息''{0}''";
    t[936] = "Server name validation failed: hostname {0} does not match common name {1}";
    t[937] = "服务器名验证失败: 主机名{0}无法匹配通用名{1}";
    t[942] = "Invalid character data was found.  This is most likely caused by stored data containing characters that are invalid for the character set the database was created in.  The most common example of this is storing 8bit data in a SQL_ASCII database.";
    t[943] = "发现不合法的字元，可能的原因是欲储存的数据中包含数据库的字元集不支援的字码，其中最常见例子的就是将 8 位元数据存入使用 SQL_ASCII 编码的数据库中。";
    t[944] = "Position: {0}";
    t[945] = "位置：{0}";
    t[950] = "Unable to parse X509Certificate for hostname {0}";
    t[951] = "无法解析主机名{0}的X509证书";
    t[954] = "Error during one-phase commit. commit xid={0}";
    t[955] = "一阶段提交时发生错误。提交事务的xid={0}";
    t[966] = "Cannot establish a savepoint in auto-commit mode.";
    t[967] = "在自动确认事物交易模式无法建立储存点(Savepoint)。";
    t[968] = "One-phase commit must be issued on the connection that started the branch. commit xid={0}";
    t[969] = "一阶段提交必须在启动该分支的连接上发起。commit xid={0}";
    t[984] = "Too many update results were returned.";
    t[985] = "返回的更新结果过多。";
    t[986] = "Large Objects may not be used in auto-commit mode.";
    t[987] = "大型对象无法被使用在自动确认事物交易模式。";
    t[988] = "The hostname {0} could not be verified by hostnameverifier {1}.";
    t[989] = "主机名{0}无法通过HostnameVerifier {1}认证。";
    t[992] = "Unable to bind parameter values for statement.";
    t[993] = "无法为statement绑定参数";
    t[994] = "Ran out of memory retrieving query results.";
    t[995] = "获取查询结果时出现内存不足";
    t[998] = "Database connection failed when canceling copy operation";
    t[999] = "在取消拷贝操作时数据库连接发生错误";
    t[1004] = "Error committing prepared transaction. commit xid={0}, preparedXid={1}, currentXid={2}";
    t[1005] = "预备事务提交错误。提交事务的xid={0}, 已提交事务的xid={1},当前事务的Xid={2}";
    t[1006] = "Error releasing savepoint";
    t[1007] = "释放保存点时发生错误";
    t[1008] = "Interrupted while waiting to obtain lock on database connection";
    t[1009] = "在等待获取锁的过程中被中断";
    t[1010] = "The parameter index is out of range: {0}, number of parameters: {1}.";
    t[1011] = "参数索引超出许可范围：{0}，参数总数：{1}。";
    t[1014] = "The sslfactoryarg property may not be empty.";
    t[1015] = "Property属性sslfactoryarg不能为空。";
    t[1032] = "Custom type maps are not supported.";
    t[1033] = "不支持自定义的Map类型";
    t[1034] = "Unsupported Types value: {0}";
    t[1035] = "未被支持的类型值：{0}";
    t[1038] = "Cannot truncate LOB to a negative length.";
    t[1039] = "无法将LOB的长度设置为负值。";
    t[1044] = "{0} function takes four and only four argument.";
    t[1045] = "{0} 函式取得四个且仅有四个引数。";
    t[1052] = "Server name validation failed: certificate for hostname {0} has no DNS subjectAltNames, and it CommonName is missing as well";
    t[1053] = "服务器名验证失败: 主机名{0}的证书未包含DNS subjectAltNames和CommonName。";
    t[1056] = "Cannot convert an instance of {0} to type {1}";
    t[1057] = "无法转换 {0} 到类型 {1} 的实例";
    t[1066] = "Tried to cancel an inactive copy operation";
    t[1067] = "尝试取消一个非活动的拷贝操作";
    t[1068] = "This statement has been closed.";
    t[1069] = "这个 statement 已经被关闭。";
    t[1076] = "Cannot rollback prepared transaction while a local transaction is in progress on this connection. Commit or rollback the local transaction first. rollback xid={0}, transactionState={1}";
    t[1077] = "在此连接上有本地事务正在进行时，无法回滚已预备的事务。请先提交或回滚该本地事务。rollback xid={0}, transactionState={1}";
    t[1078] = "One-phase commit called for xid {0} but connection was prepared with xid {1}";
    t[1079] = "对 xid {0} 调用了一阶段提交，但该连接是用 xid {1} 进行预备的";
    t[1080] = "Provided InputStream failed.";
    t[1081] = "提供的 InputStream 已失败。";
    t[1086] = "Server name validation pass for {0}, subjectAltName {1}";
    t[1087] = "主机名{0}的服务器名验证通过, subjectAltName {1}";
    t[1092] = "ResultSets with concurrency CONCUR_READ_ONLY cannot be updated.";
    t[1093] = "ResultSets 与并发同作(Concurrency) CONCUR_READ_ONLY 不能被更新。";
    t[1098] = "No value specified for parameter {0}.";
    t[1099] = "未设定参数值 {0} 的内容。";
    t[1102] = "Malformed function or procedure escape syntax at offset {0}.";
    t[1103] = "不正确的函式或程序 escape 语法于 {0}。";
    t[1104] = "An unexpected result was returned by a query.";
    t[1105] = "传回非预期的查询结果。";
    t[1114] = "The JVM claims not to support the encoding: {0}";
    t[1115] = "JVM 声明并不支援编码：{0} 。";
    t[1126] = "Connection is already associated with an active XA branch. End the current branch before starting a new one. start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[1127] = "连接已与一个活动的 XA 分支关联。在开始新分支之前，请先结束当前分支。start xid={0}, currentXid={1}, state={2}, flags={3}";
    t[1130] = "wasNull cannot be call before fetching a result.";
    t[1131] = "wasNull无法在结果取得前被调用。";
    t[1132] = "SSL error: {0}";
    t[1133] = "SSL错误: {0}";
    t[1148] = "Suspend/resume not implemented";
    t[1149] = "尚未实现 Suspend/resume。";
    t[1156] = "Not on the insert row.";
    t[1157] = "不在新增的数据列上。";
    t[1162] = "The HostnameVerifier class provided {0} could not be instantiated.";
    t[1163] = "无法实例化提供的HostnameVerifier类: {0}";
    t[1166] = "Error during recover. flag={0}";
    t[1167] = "recover 过程中出错。flag={0}";
    t[1168] = "{0} function takes three and only three arguments.";
    t[1169] = "{0} 函式取得三个且仅有三个引数。";
    t[1172] = "Unknown XML Source class: {0}";
    t[1173] = "未知XML源类: {0}";
    t[1184] = "This statement does not declare an OUT parameter.  Use '{' ?= call ... '}' to declare one.";
    t[1185] = "这个 statement 未宣告 OUT 参数，使用 '{' ?= call ... '}' 宣告一个。";
    t[1186] = "This SQLXML object has not been initialized, so you cannot retrieve data from it.";
    t[1187] = "该SQLXML对象尚未初始化，无法从中检索数据。";
    t[1212] = "Method {0} is not yet implemented.";
    t[1213] = "这个 {0} 方法尚未被实作。";
    t[1214] = "Fetch size must be a value greater than or equal to 0.";
    t[1215] = "数据读取笔数(fetch size)必须大于或等于 0。";
    t[1216] = "Statement has been closed.";
    t[1217] = "Sstatement 已经被关闭。";
    t[1220] = "Your security policy has prevented the connection from being attempted.  You probably need to grant the connect java.net.SocketPermission to the database server host and port that you wish to connect to.";
    t[1221] = "您的连接被安全策略阻止。你可能需要将java.net.SocketPermission连接权限赋予给你希望连接的数据库服务器的host和port。";
    t[1226] = "Interval {0} not yet implemented";
    t[1227] = "隔绝 {0} 尚未被实作。";
    t[1232] = "The connection attempt failed.";
    t[1233] = "尝试连线已失败。";
    t[1244] = "Currently positioned after the end of the ResultSet.  You cannot call deleteRow() here.";
    t[1245] = "不能在 ResultSet 的最后一笔数据之后呼叫 deleteRow()。";
    t[1248] = "ResultSet not positioned properly, perhaps you need to call next.";
    t[1249] = "查询结果指标位置不正确，您也许需要呼叫 ResultSet 的 next() 方法。";
    t[1252] = "WARNING! Required to allocate {0} bytes, which exceeded possible heap memory size. Assigned {1} bytes as limit.";
    t[1253] = "警告！需要分配{0}字节，但这超出了最大可分配的堆内存空间。最大可分配的堆内存空间的上限为{1}字节";
    t[1254] = "Server name validation failed: certificate for host {0} dNSName entries subjectAltName, but none of them match. Assuming server name validation failed";
    t[1255] = "服务器名验证失败: 无法为主机{0}的证书匹配任何一个dNSName类型的subjectAltName扩展名。假定服务器名验证失败。";
    t[1258] = "Unable to translate data into the desired encoding.";
    t[1259] = "无法将数据转成目标编码。";
    t[1264] = "This ResultSet is closed.";
    t[1265] = "这个 ResultSet 已经被关闭。";
    t[1272] = "An error occurred while setting up the SSL connection.";
    t[1273] = "进行 SSL 连线时发生错误。";
    t[1276] = "Detail: {0}";
    t[1277] = "详细：{0}";
    t[1280] = "Unable to load the class {0} responsible for the datatype {1}";
    t[1281] = "无法为数据类型{1}加载类{0}";
    t[1290] = "Expected an EOF from server, got: {0}";
    t[1291] = "期待从服务端接收到EOF，实际接收到: {0}";
    t[1292] = "{0} parameter value must be an integer but was: {1}";
    t[1293] = "属性{0}的值应是integer类型，实际却是: {1}";
    t[1300] = "The authentication type {0} is not supported. Check that you have configured the pg_hba.conf file to include the client''s IP address or subnet, and that it is using an authentication scheme supported by the driver.";
    t[1301] = "不支援 {0} 验证类型。请核对您已经组态 pg_hba.conf 文件包含客户端的IP位址或网路区段，以及驱动程序所支援的验证架构模式已被支援。";
    t[1304] = "Unable to find name datatype in the system catalogs.";
    t[1305] = "在系统 catalog 中找不到名称数据类型(datatype)。";
    t[1308] = "ResultSet is not updateable.  The query that generated this result set must select only one table, and must select all primary keys from that table. See the JDBC 2.1 API Specification, section 5.6 for more details.";
    t[1309] = "不可更新的 ResultSet。用来产生这个 ResultSet 的 SQL 命令只能操作一个数据表，并且必需选择所有主键栏位，详细请参阅 JDBC 2.1 API 规格书 5.6 节。";
    t[1316] = "Database connection failed when reading from copy";
    t[1317] = "在从拷贝流中读取数据时数据库连接发生错误";
    t[1320] = "One-phase commit with unknown xid. commit xid={0}, currentXid={1}";
    t[1321] = "对未知 xid 的一阶段提交。commit xid={0}, currentXid={1}";
    t[1322] = "Conversion of money failed.";
    t[1323] = "money 转换失败。";
    t[1328] = "The system property containing the server's SSL certificate must not be empty.";
    t[1329] = "指定服务端SSL证书的系统属性不能为空。";
    t[1332] = "Invalid protocol state requested. Attempted transaction interleaving is not supported. xid={0}, currentXid={1}, state={2}, flags={3}";
    t[1333] = "事物交易隔绝(Transaction interleaving)未被实作。xid={0}, currentXid={1}, state={2}, flags={3}";
    t[1334] = "Could not find a java cryptographic algorithm: X.509 CertificateFactory not available.";
    t[1335] = "找不到java加密算法: X.509 CertificateFactory不可用。";
    t[1336] = "The server does not support SSL.";
    t[1337] = "服务器不支援 SSL 连线。";
    t[1346] = "Unknown type {0}.";
    t[1347] = "不明的类型 {0}";
    table = t;
  }
  public java.lang.Object handleGetObject (java.lang.String msgid) throws java.util.MissingResourceException {
    int hash_val = msgid.hashCode() & 0x7fffffff;
    int idx = (hash_val % 677) << 1;
    {
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
    int incr = ((hash_val % 675) + 1) << 1;
    for (;;) {
      idx += incr;
      if (idx >= 1354)
        idx -= 1354;
      java.lang.Object found = table[idx];
      if (found == null)
        return null;
      if (msgid.equals(found))
        return table[idx + 1];
    }
  }
  public java.util.Enumeration getKeys () {
    return
      new java.util.Enumeration() {
        private int idx = 0;
        { while (idx < 1354 && table[idx] == null) idx += 2; }
        public boolean hasMoreElements () {
          return (idx < 1354);
        }
        public java.lang.Object nextElement () {
          java.lang.Object key = table[idx];
          do idx += 2; while (idx < 1354 && table[idx] == null);
          return key;
        }
      };
  }
  public java.util.ResourceBundle getParent () {
    return parent;
  }
}
